(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    137908,       2930]
NotebookOptionsPosition[    123825,       2665]
NotebookOutlinePosition[    129820,       2789]
CellTagsIndexPosition[    129148,       2767]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Marcus Theory of Electron Transfer 1: Classical versus Semi-classical Models\
\>", "Title",
 CellChangeTimes->{
  3.8454670900760527`*^9, {3.845640524047583*^9, 3.845640532513638*^9}, {
   3.845647271613554*^9, 3.845647273367836*^9}, {3.846071987286268*^9, 
   3.846071987462803*^9}},ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-\
13c361826e91"],

Cell[TextData[{
 "Initialization Code",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Initialization Code", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"Provide any code that must be evaluated before the ", 
          StyleBox["Manipulate", "MRbig"], 
          ". This will automatically be built into the ", 
          StyleBox["Manipulate", "MRbig"], 
          " in the final notebook version. Never use a package that is not \
included in the default distribution of ", 
          StyleBox["Mathematica", FontSlant -> "Italic"], 
          ". To use a package, use the ", 
          StyleBox["Initialization", "MRbig"], " option (with ", 
          StyleBox["Get", "MRbig"], ", not ", 
          StyleBox["Needs", "MRbig"], ") in the ", 
          StyleBox["Manipulate", "MRbig"], 
          " itself, and use the full name of the function from the package. \
For example:\n", 
          StyleBox[
          "  Manipulate[\n  ...\n  ComputationalGeometry`ConvexHull[...]...\n \
 ...\n  Initialization :> Get[\"ComputationalGeometry`\"],\n  ...\n  ]", 
           "MR"], "\nIf you provide initialization code, include a ", 
          StyleBox["SaveDefinitions->True", "MRbig"], " option in the ", 
          StyleBox["Manipulate", "MRbig"], ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "81fde376-e763-44cf-83ed-5c52ec315067"]
}], "InitializationSection",
 CellTags->
  "Initialization \
Code",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Manipulate",
 Cell[BoxData[
  TemplateBox[{"Manipulate", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"This section contains the ", 
          StyleBox["Manipulate", "MRbig"], 
          " input cell and its evaluated output cell. Make all control labels \
or labels in the output as descriptive as possible, with only proper nouns \
and proper adjectives capitalized. More description of the controls can be \
provided in the Details section below, if necessary. If you change this ", 
          StyleBox["Manipulate", "MRbig"], 
          " after creating screenshots and/or thumbnails, use ", 
          StyleBox["Update Thumbnail & Snapshots", FontWeight -> "Bold"], 
          " in the toolbar to update any copies in later sections. You can \
control the Flash preview for the Demonstration with the ", 
          StyleBox["AutorunSequencing", "MRbig"], " option. Use ", 
          StyleBox["SaveDefinitions->True", "MRbig"], 
          " if you provided initialization code in the previous section."}], 
        "MoreInfoText"], Background -> GrayLevel[0.95], FrameMargins -> 20, 
       FrameStyle -> GrayLevel[0.9], RoundingRadius -> 5]], "MoreInfoText", 
     Deletable -> True, CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d12d57a6-93e6-4518-8a9c-9df2eb688354"]
}], "ManipulateSection",
 CellTags->
  "Manipulate",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Text", "@", 
    RowBox[{"Quiet", "[", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"KetSC", "=", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", 
                  "*", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"0.0000861733033", " ", 
                    RowBox[{"(", "LambdaS", ")"}], " ", "T"}], ")"}], 
                   "0.5"]}], ")"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[Pi]", 
                 RowBox[{"3", "/", "2"}]], "*", 
                SuperscriptBox[
                 RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
              SuperscriptBox["V", "2"], "*", 
              RowBox[{"(", 
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"m", "=", "0"}], "n"], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}]}]], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}], "^", 
                    "m"}]}], ")"}], "/", 
                    RowBox[{"m", "!"}]}], ")"}], "*", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"-", 
                    FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"DeltaG", "+", "LambdaS", "+", 
                    RowBox[{"m", "*", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], 
                    "2"], 
                    RowBox[{"4", "*", "0.0000861733033", "*", 
                    RowBox[{"(", "LambdaS", ")"}], " ", "T"}]]}]]}], ")"}]}], 
               ")"}]}], ")"}]}], ",", " ", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<= semi\[Hyphen]classical rate \>\"", ",", 
              SubscriptBox[
               RowBox[{"Style", "[", 
                RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}], "et"], ",", 
              "\"\<(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))\>\""}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"HR", "=", 
             RowBox[{"LambdaI", "/", 
              RowBox[{"(", 
               RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], ",", 
           " ", "\"\<= Huang-Rhys factor\>\""}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"FCWD", "=", 
             RowBox[{"(", 
              RowBox[{
               UnderoverscriptBox["\[Sum]", 
                RowBox[{"m", "=", "0"}], "n"], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}]}]], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}], "^", 
                    "m"}]}], ")"}], "/", 
                   RowBox[{"m", "!"}]}], ")"}], "*", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                   FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"DeltaG", "+", "LambdaS", "+", 
                    RowBox[{"m", "*", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], 
                    "2"], 
                    RowBox[{"4", "*", "0.0000861733033", "*", 
                    RowBox[{"(", "LambdaS", ")"}], " ", "T"}]]}]]}], ")"}]}], 
              ")"}]}], ")"}], ",", " ", 
           "\"\<= Franck-Condon weighted density of states\>\""}], "}"}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"KoptSC", "=", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", 
                  "*", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"0.0000861733033", " ", 
                    RowBox[{"(", "LambdaS", ")"}], " ", "T"}], ")"}], 
                   "0.5"]}], ")"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[Pi]", 
                 RowBox[{"3", "/", "2"}]], "*", 
                SuperscriptBox[
                 RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
              SuperscriptBox["V", "2"]}], ")"}]}], ",", " ", 
           "\"\<= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"KetC", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", 
                   "*", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"0.0000861733033", " ", 
                    RowBox[{"(", 
                    RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}], 
                    ")"}], "0.5"]}], ")"}]}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["\[Pi]", 
                  RowBox[{"3", "/", "2"}]], "*", 
                 SuperscriptBox[
                  RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
               SuperscriptBox["V", "2"], "*", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                 FractionBox[
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"DeltaG", "+", "LambdaS", "+", "LambdaI"}], ")"}],
                    "2"], 
                  RowBox[{"4", "*", "0.0000861733033", "*", 
                   RowBox[{"(", 
                    RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", 
                   "T"}]]}]]}], ")"}]}], ")"}], " ", ",", " ", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<= classical rate \>\"", ",", 
              SubscriptBox[
               RowBox[{"Style", "[", 
                RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}], "et"], ",", 
              "\"\<(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))\>\""}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"EAC", "=", 
            RowBox[{"(", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"DeltaG", "+", "LambdaS", "+", "LambdaI"}], ")"}], 
               "2"], 
              RowBox[{"4", "*", 
               RowBox[{"(", 
                RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " "}]], ")"}]}], 
           ",", " ", "\"\<= classical activation energy (eV)\>\""}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"KoptC", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", 
                   "*", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"0.0000861733033", " ", 
                    RowBox[{"(", 
                    RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}], 
                    ")"}], "0.5"]}], ")"}]}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["\[Pi]", 
                  RowBox[{"3", "/", "2"}]], "*", 
                 SuperscriptBox[
                  RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
               SuperscriptBox["V", "2"]}], ")"}]}], ")"}], " ", ",", " ", 
           
           "\"\<= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))\>\""}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"LambdaT", "=", " ", 
             RowBox[{"LambdaI", " ", "+", "LambdaS"}]}], ")"}], ",", " ", 
           "\"\<= total lambda (eV)\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"KBT", "=", " ", 
             RowBox[{"0.0000861733033", " ", "*", "T"}]}], ")"}], ",", " ", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<= \>\"", ",", 
              SubscriptBox[
               RowBox[{"Style", "[", 
                RowBox[{"\"\<K\>\"", ",", "Italic"}], "]"}], "b"], ",", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<T\>\"", ",", "Italic"}], "]"}], ",", 
              "\"\< (eV)\>\""}], "}"}], "]"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"ItemSize", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"14", ",", "All"}], "}"}], ",", "1.5"}], "}"}]}], ",", 
       RowBox[{"Alignment", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"Right", ",", "Left"}], "}"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Dividers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "False", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "False", ",", "False", ",", "False", ",", "False", ",", "True", 
            ",", "False", ",", "False", ",", "True"}], "}"}]}], "}"}]}]}], 
      "]"}], "\[IndentingNewLine]", "]"}]}], " ", ",", "\[IndentingNewLine]", 
   RowBox[{"Column", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\[CapitalDelta]\[ThinSpace]G\>\"", ",", "Italic"}], 
          "]"}], ",", "\"\< (eV)\>\""}], "}"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"DeltaG", ",", 
           RowBox[{"-", "1.537"}], ",", " ", "\"\<\>\""}], "}"}], ",", "1", 
         ",", 
         RowBox[{"-", "8"}], ",", "0.01", ",", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      "\"\<\\n\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)\>\"", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"LambdaS", ",", "0.237", ",", " ", "\"\<\>\""}], "}"}], ",",
          "0.00001", ",", "8", ",", "0.01", ",", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      "\"\<\\n\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)\>\"", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"LambdaI", ",", "0.3", ",", " ", "\"\<\>\""}], "}"}], ",", 
         "0.0001", ",", "2", ",", "0.01", ",", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", "\"\<\>\"", ",", "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<T\>\"", ",", "Italic"}], "]"}], ",", "\"\< (K)\>\""}], 
        "}"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"T", ",", "295", ",", " ", "\"\<\>\""}], "}"}], ",", "4", 
         ",", "1000", ",", "0.01", ",", " ", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      "\"\<\\nvibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\"", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"vib", ",", "1500", ",", " ", "\"\<\>\""}], "}"}], ",", "4",
          ",", "10000", ",", "0.001", ",", " ", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<\\nsummation factor \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<n\>\"", ",", "Italic"}], "]"}]}], "}"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", "50", ",", " ", "\"\<\>\""}], "}"}], ",", "0", 
         ",", "500", ",", "0.01", ",", " ", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<\\nelectronic coupling \>\"", " ", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<V\>\"", ",", "Italic"}], "]"}], ",", 
         "\"\< (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"V", ",", "6", ",", " ", "\"\<\>\""}], "}"}], ",", "0.005", 
         ",", "8066", ",", "0.01", ",", " ", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Spacer", "[", "140", "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8456421501126127`*^9, 3.8456421609794273`*^9}, 
   3.845642252944289*^9, 3.8456423030721073`*^9, {3.845645065829426*^9, 
   3.845645121024015*^9}, {3.845645155000463*^9, 3.845645224730733*^9}, 
   3.845645269438683*^9, {3.845645309405168*^9, 3.845645411863632*^9}, 
   3.845645467004471*^9, {3.845645518509691*^9, 3.845645563512116*^9}, {
   3.8456516986262302`*^9, 3.845651732723078*^9}, {3.8456518973039*^9, 
   3.845651947271801*^9}, {3.845652002627442*^9, 3.845652143924704*^9}, {
   3.845652204270443*^9, 3.845652209147485*^9}, {3.8456522927251787`*^9, 
   3.8456524240546513`*^9}, {3.845652488853965*^9, 3.845652529877707*^9}, {
   3.845652564298211*^9, 3.845652678098679*^9}, {3.845652785797573*^9, 
   3.845652835438287*^9}, 3.845652902725328*^9, {3.845923077645211*^9, 
   3.845923140578961*^9}},
 CellLabel->"In[6]:=",
 CellID->2071835132,ExpressionUUID->"ebecb9f0-1d25-4711-89cd-7223315dbb49"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -1.537, $CellContext`LambdaI$$ = 
    0.3, $CellContext`LambdaS$$ = 0.237, $CellContext`n$$ = 
    50, $CellContext`T$$ = 295, $CellContext`V$$ = 6, $CellContext`vib$$ = 
    1500, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`DeltaG$$], -1.537, ""}, 1, -8, 0.01}, {{
       Hold[$CellContext`LambdaS$$], 0.237, ""}, 0.00001, 8, 0.01}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`T$$], 295, ""}, 4, 1000, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 10000, 0.001}, {{
       Hold[$CellContext`n$$], 50, ""}, 0, 500, 0.01}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 8066, 0.01}, {
      Hold[
       Column[{
         Row[{
           Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
         Manipulate`Place[1], 
         "\n\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
         Manipulate`Place[2], 
         "\n\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
         Manipulate`Place[3], "", 
         Row[{
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         "\nvibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[5], 
         Row[{"\nsummation factor ", 
           Style["n", Italic]}], 
         Manipulate`Place[6], 
         Row[{"\nelectronic coupling ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[7], 
         Spacer[140]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {379., {96., 101.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`LambdaI$$ = 
        0.3, $CellContext`LambdaS$$ = 0.237, $CellContext`n$$ = 
        50, $CellContext`T$$ = 295, $CellContext`V$$ = 6, $CellContext`vib$$ = 
        1500}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Text[
        Quiet[
         Grid[{{$CellContext`KetSC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
             Sum[((E^(-($CellContext`LambdaI$$/(
                    0.000123985 $CellContext`vib$$))) \
($CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$))^$CellContext`m)/
                Factorial[$CellContext`m]) 
               E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                    0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            Row[{"= semi\[Hyphen]classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`HR = \
$CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$), 
            "= Huang-Rhys factor"}, {$CellContext`FCWD = 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            "= Franck-Condon weighted density of states"}, \
{$CellContext`KoptSC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
            "= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))"}, {$CellContext`KetC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
                0.000123985^2)) $CellContext`V$$^2) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                  0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
            Row[{"= classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`EAC = \
($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
             4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
            "= classical activation energy (eV)"}, {$CellContext`KoptC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2, 
            "= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}, {$CellContext`LambdaT = \
$CellContext`LambdaI$$ + $CellContext`LambdaS$$, 
            "= total lambda (eV)"}, {$CellContext`KBT = 
            0.0000861733033 $CellContext`T$$, 
            Row[{"= ", 
              Subscript[
               Style["K", Italic], $CellContext`b], 
              Style["T", Italic], " (eV)"}]}}, ItemSize -> {{14, All}, 1.5}, 
          Alignment -> {{Right, Left}}, 
          Dividers -> {{False}, {
            False, False, False, False, True, False, False, True}}]]], 
      "Specifications" :> {{{$CellContext`DeltaG$$, -1.537, ""}, 1, -8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`LambdaS$$, 0.237, ""}, 0.00001, 8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 295, ""}, 4, 1000, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`vib$$, 1500, ""}, 4, 10000, 0.001, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`n$$, 50, ""}, 0, 500, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`V$$, 6, ""}, 0.005, 8066, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Column[{
          Row[{
            Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
          Manipulate`Place[1], 
          "\n\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
          Manipulate`Place[2], 
          "\n\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
          Manipulate`Place[3], "", 
          Row[{
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          "\nvibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[5], 
          Row[{"\nsummation factor ", 
            Style["n", Italic]}], 
          Manipulate`Place[6], 
          Row[{"\nelectronic coupling ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[7], 
          Spacer[140]}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{577., {210., 216.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.845923082156583*^9, 3.8459230869316597`*^9}, {
  3.845923121884675*^9, 3.8459231415910883`*^9}},
 CellLabel->"Out[6]=",
 CellID->1533594167,ExpressionUUID->"c15cd21c-1f36-421d-be51-942e9fc8dd58"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Caption",
 Cell[BoxData[
  TemplateBox[{"Caption", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "The caption provides all the information needed to understand the \
Demonstration. It should be between three and five sentences long, but \
clarity is more important than length. Include only text in this section \
\[LongDash] no code, graphics, etc. Do not change the cell style or copy \
cells from other sections. Do not copy text from books or the web. Write your \
ideas in your own words. If you want to refer to something on the web, link \
to it in the Details.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "a97b5d36-1c59-4018-b3f0-6bfc71662d3d"]
}], "ManipulateCaptionSection",
 CellTags->"Caption",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4"],

Cell[TextData[{
 "Nobel Prize winner Rudolph Marcus developed the theory of electron transfer \
[1]. The classical Marcus equation (CME) is based on two simultaneous \
quadratic relations, involving the driving force (",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[ThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"919cc0fe-1f96-42c5-a4b5-bde1331d5b07"],
 "), the internal and external (solvent) reorganization energy (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", 
    StyleBox["I",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "2236485d-ab2f-4186-b0e9-1ac386fb8040"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", 
    StyleBox["S",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "4a660713-3e7d-4e3b-aad7-6fde31694275"],
 ") and the electronic coupling (",
 Cell[BoxData[
  FormBox["V", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7045ef64-ed25-4c0f-8b40-963dd8271fe8"],
 "). The CME underestimates the electron transfer rate in the inverted region \
[2, 3]. This Demonstration compares rates predicted by the classical Marcus \
model with those using the semi-classical Marcus model (also called Marcus\
\[Dash]Levich\[Dash]Jortner Theory, MLJ) . The starting values are from the \
so-called Closs and Miller data [4], which provided the first experimental \
proof of the inverted region. We illustrate this with the isooctane data in \
Snapshot 1."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}, {
   3.845485857029244*^9, 3.845486214421936*^9}, {3.845486288761991*^9, 
   3.8454863548722887`*^9}, 3.8454864032678127`*^9, {3.845486705510519*^9, 
   3.84548671040314*^9}, {3.845486903198655*^9, 3.845486904092573*^9}, 
   3.845525356127366*^9, {3.845526497969751*^9, 3.845526501112731*^9}, {
   3.845527676293848*^9, 3.845527694435413*^9}, {3.845527725918661*^9, 
   3.845527726567141*^9}, {3.845642386083975*^9, 3.8456424733745813`*^9}, 
   3.845642512829173*^9, {3.845645841098516*^9, 3.845645843527162*^9}, {
   3.845647290666231*^9, 3.8456473450417233`*^9}, {3.8456473847060213`*^9, 
   3.845647389365912*^9}, {3.8456477682030687`*^9, 3.84564797253769*^9}, {
   3.845648048410379*^9, 3.845648049285551*^9}, {3.84564812553232*^9, 
   3.845648264491376*^9}, {3.845648312989109*^9, 3.845648383824232*^9}, {
   3.8460725220111523`*^9, 3.846072522426863*^9}, {3.8460725730200443`*^9, 
   3.8460725733735104`*^9}, {3.8463329158542595`*^9, 3.846332927023787*^9}},
 CellID->2005410859,ExpressionUUID->"10d06e69-f1e7-4610-b520-424965ba4617"],

Cell[TextData[{
 "We apply the semi-classical Marcus expression to the inverted region. If ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[ThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"0cbe8dfb-c16d-42dc-b798-c49e17b536ec"],
 " is much larger than the total ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Lambda]", "=", 
    RowBox[{
     SubscriptBox["\[Lambda]", 
      StyleBox["I",
       FontSlant->"Plain"]], "+", 
     SubscriptBox["\[Lambda]", 
      StyleBox["S",
       FontSlant->"Plain"]]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"dc4c12e7-dd7d-4a5e-be23-403047eb0dbb"],
 ", then inverted region effects are apparent. The enhanced rate (extra rate \
relative to CME) in the inverted region is related to the overlap of \
vibrational wavefunctions that contribute to the Franck\[Dash]Condon weighted \
density of states (the Franck\[Dash]Condon factor). The Huang\[Dash]Rhys \
factor is related to the vibronic coupling, also called the electron-phonon \
coupling (often represented by the symbol S in the MLJ equation)."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.845398006879942*^9, 3.845398138772657*^9}, {
   3.845486768639637*^9, 3.845486847878462*^9}, {3.845486944303318*^9, 
   3.84548699043965*^9}, {3.8454870774326*^9, 3.845487077737661*^9}, {
   3.845488197525855*^9, 3.8454882623098383`*^9}, {3.84552545068823*^9, 
   3.845525479985098*^9}, {3.845525567767469*^9, 3.845525589291168*^9}, {
   3.8455277692478237`*^9, 3.845527797208523*^9}, {3.845527941069654*^9, 
   3.8455279413244753`*^9}, {3.845642898151327*^9, 3.845642999133505*^9}, {
   3.8456484029905853`*^9, 3.8456485170031557`*^9}, {3.845650593136702*^9, 
   3.84565059385633*^9}, {3.845650650354578*^9, 3.845650659022091*^9}, {
   3.846072739398058*^9, 3.846072745427127*^9}},
 CellID->86693020,ExpressionUUID->"90730535-7fb3-41ca-9c8b-4d6ded77ff8d"],

Cell[TextData[{
 "In Snapshot 2 (C60[3]TMPD-Tol-CR), the total ",
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8828809f-0fe8-4f41-aed6-5a0650ef8e16"],
 " is about ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "4"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "70bd40b2-0001-45ca-b32b-454c7dcdb569"],
 " of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[ThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"6d00561d-5282-4b1e-8e90-0a16a9610ee5"],
 ". The rate predicted by the CME is much too low. With the semi-classical \
equation, we can approach the measured rates [5] by adjusting the vibration \
that mediates the electron transfer (or by adjusting the electronic \
coupling). The other snapshots show C60[11]DMA in ",
 StyleBox["benzonitrile", "TI"],
 " for charge separation (Snapshot 3) and charge recombination (Snapshot 4). \
\"Initial setting\" is based on Closs and Miller compounds (Snapshot 1)."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.845398006879942*^9, 3.845398275984207*^9}, {
   3.845399056704618*^9, 3.8453991166189203`*^9}, {3.845399160300664*^9, 
   3.845399184860959*^9}, {3.8454866351330347`*^9, 3.8454866384585123`*^9}, {
   3.8454882984875507`*^9, 3.845488300869893*^9}, {3.8455256348616123`*^9, 
   3.845525704614236*^9}, {3.845526426223998*^9, 3.845526465725134*^9}, {
   3.8455291576993237`*^9, 3.845529164194769*^9}, 3.845530104394269*^9, {
   3.845530332586508*^9, 3.8455303509203587`*^9}, {3.8456430137821007`*^9, 
   3.8456430350219517`*^9}, {3.84565101819884*^9, 3.845651116577362*^9}, {
   3.845651150660925*^9, 3.845651162936602*^9}, 3.846072784955554*^9, {
   3.846072834467929*^9, 3.84607287553512*^9}},
 CellID->250327041,ExpressionUUID->"82d1a36f-be33-4236-ad66-761baa545d1f"],

Cell[TextData[{
 "Fit-values bell curve MTHF of Closs and Miller:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["S",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.75`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a2805ecf-dd99-4733-84d4-d73b59eb11b3"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["I",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.45`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"05db11bd-8811-45c9-97af-e6e6ebeee0a4"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"vibration", "=", 
    RowBox[{"1500", 
     SuperscriptBox["cm", 
      RowBox[{"-", "1"}]]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7a1d9a19-e7e8-4949-9c91-d400b3cda23e"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", "6.2`"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "c95acfdd-fe37-4c91-aa43-303926e6c7e6"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"296", " ", 
     StyleBox["K",
      FontSlant->"Plain"]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "c560a9f1-b4e5-44c3-8654-36da7eee705c"],
 ",\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "6.97`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"7ae6b68a-8c39-41cc-b05e-71392a5fbdcb"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1.406`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"d58a6e2a-4bb9-4501-969f-915a53a8ba88"]
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9},
 CellID->1438951199,ExpressionUUID->"021b0a42-5790-405a-bc6d-6382b91cdaca"],

Cell[TextData[{
 "Fit-values bell curve isooctane of Closs and Miller:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["S",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.15`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"efd8c355-77f2-4a21-96f3-9137f55b2a77"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["I",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.45`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"2ac99d28-2e59-42ac-9303-3c919061f751"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"vibration", "=", 
    RowBox[{"1500", 
     SuperscriptBox["cm", 
      RowBox[{"-", "1"}]]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "45b113da-aafc-4f28-8c09-ae58a4fd3e7f"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", "6.2`"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "cc2e8219-2640-4f11-992f-260a760fd2ed"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"296", " ", 
     StyleBox["K",
      FontSlant->"Plain"]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "4bceb0c8-d457-4ad6-857c-6f0afc994adc"],
 ",\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "1.962`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"f742406f-5c4a-4882-8c3e-7e0daf109298"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1.4029`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"799d65de-5652-4389-9544-aee00e5faafe"]
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}},
 CellID->1072432135,ExpressionUUID->"e54540e6-ab3c-4b08-b7d8-9de76c22c7de"],

Cell[TextData[{
 "The variable ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4332105f-b2ee-409f-84d0-5d49d51f6153"],
 " is in the summation factor, determining how many transfer channels \
contribute to the total rate [3]. The output interface also plays a role. \
Additional information on Marcus theory and electron transfer is available in \
references [6\[Dash]9]."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}},
 CellID->518981415,ExpressionUUID->"d5a6d1d8-eef8-42c6-b890-2e5901687fb0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Thumbnail",
 Cell[BoxData[
  TemplateBox[{"Thumbnail", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "To create the thumbnail, copy and paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section and adjust the controls to the most visually appealing \
setting. Do not convert it to a bitmap. The thumbnail is what visitors see \
when browsing the Demonstrations site and while the Flash preview loads.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "5363174b-397a-4e31-b8e5-95e1af887bc9"]
}], "ThumbnailSection",
 CellTags->"Thumbnail",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -1.329, $CellContext`LambdaI$$ = 
    0.3000000000000173, $CellContext`LambdaS$$ = 0.04, $CellContext`n$$ = 
    50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
    100.85, $CellContext`vib$$ = 3372, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`DeltaG$$], -1.329, ""}, 1, -8, 0.01}, {{
       Hold[$CellContext`LambdaS$$], 0.04, ""}, 0.00001, 8, 0.01}, {{
       Hold[$CellContext`LambdaI$$], 0.3000000000000173, ""}, 0.0001, 2, 
      0.01}, {{
       Hold[$CellContext`T$$], 295.0000000000191, ""}, 4, 1000, 0.01}, {{
       Hold[$CellContext`vib$$], 3372, ""}, 4, 10000, 0.001}, {{
       Hold[$CellContext`n$$], 50, ""}, 0, 500, 0.01}, {{
       Hold[$CellContext`V$$], 100.85, ""}, 0.005, 8066, 0.01}, {
      Hold[
       Column[{
         Row[{
           Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
         Manipulate`Place[1], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
         Manipulate`Place[2], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
         Manipulate`Place[3], 
         Row[{
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[5], 
         Row[{"summation factor ", 
           Style["n", Italic]}], 
         Manipulate`Place[6], 
         Row[{"electronic coupling ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[7], 
         Spacer[140]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {379., {96., 101.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.329, $CellContext`LambdaI$$ = 
        0.3000000000000173, $CellContext`LambdaS$$ = 0.04, $CellContext`n$$ = 
        50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
        100.85, $CellContext`vib$$ = 3372}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Text[
        Quiet[
         Grid[{{$CellContext`KetSC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
             Sum[((E^(-($CellContext`LambdaI$$/(
                    0.000123985 $CellContext`vib$$))) \
($CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$))^$CellContext`m)/
                Factorial[$CellContext`m]) 
               E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                    0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            Row[{"= semi\[Hyphen]classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`HR = \
$CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$), 
            "= Huang-Rhys factor"}, {$CellContext`FCWD = 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            
            "= Franck-Condon weighted density of states"}, \
{$CellContext`KoptSC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
            "= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))"}, {$CellContext`KetC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
                0.000123985^2)) $CellContext`V$$^2) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                  0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
            Row[{"= classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`EAC = \
($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
             4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
            "= classical activation energy (eV)"}, {$CellContext`KoptC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2, 
            "= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}, {$CellContext`LambdaT = \
$CellContext`LambdaI$$ + $CellContext`LambdaS$$, 
            "= total lambda (eV)"}, {$CellContext`KBT = 
            0.0000861733033 $CellContext`T$$, 
            Row[{"= ", 
              Subscript[
               Style["K", Italic], $CellContext`b], 
              Style["T", Italic], " (eV)"}]}}, ItemSize -> {{14, All}, 1.5}, 
          Alignment -> {{Right, Left}}, 
          Dividers -> {{False}, {
            False, False, False, False, True, False, False, True}}]]], 
      "Specifications" :> {{{$CellContext`DeltaG$$, -1.329, ""}, 1, -8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`LambdaS$$, 0.04, ""}, 0.00001, 8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`LambdaI$$, 0.3000000000000173, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 295.0000000000191, ""}, 4, 1000, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`vib$$, 3372, ""}, 4, 10000, 0.001, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`n$$, 50, ""}, 0, 500, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`V$$, 100.85, ""}, 0.005, 8066, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Column[{
          Row[{
            Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
          Manipulate`Place[1], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
          Manipulate`Place[2], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
          Manipulate`Place[3], 
          Row[{
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[5], 
          Row[{"summation factor ", 
            Style["n", Italic]}], 
          Manipulate`Place[6], 
          Row[{"electronic coupling ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[7], 
          Spacer[140]}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{577., {157., 163.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->1064870666,ExpressionUUID->"da7b36b8-dc80-4405-b5f5-b91fdfa46950"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Snapshots",
 Cell[BoxData[
  TemplateBox[{"Snapshots", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"To create snapshots, paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section in this section at least three times, and adjust the \
controls of each copy to show a range of interesting settings. Do not convert \
the screenshots to bitmaps. Optional captions for the screenshots may be \
included in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d854de0f-efbb-449a-8b04-a7b3ca5773d5"]
}], "SnapshotsSection",
 CellTags->"Snapshots",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -1.537, $CellContext`LambdaI$$ = 
    0.3, $CellContext`LambdaS$$ = 0.237, $CellContext`n$$ = 
    50, $CellContext`T$$ = 295, $CellContext`V$$ = 6, $CellContext`vib$$ = 
    1500, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`DeltaG$$], -1.537, ""}, 1, -8, 0.01}, {{
       Hold[$CellContext`LambdaS$$], 0.237, ""}, 0.00001, 8, 0.01}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`T$$], 295, ""}, 4, 1000, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 10000, 0.001}, {{
       Hold[$CellContext`n$$], 50, ""}, 0, 500, 0.01}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 8066, 0.01}, {
      Hold[
       Column[{
         Row[{
           Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
         Manipulate`Place[1], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
         Manipulate`Place[2], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
         Manipulate`Place[3], 
         Row[{
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[5], 
         Row[{"summation factor ", 
           Style["n", Italic]}], 
         Manipulate`Place[6], 
         Row[{"electronic coupling ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[7], 
         Spacer[140]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {379., {96., 101.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`LambdaI$$ = 
        0.3, $CellContext`LambdaS$$ = 0.237, $CellContext`n$$ = 
        50, $CellContext`T$$ = 295, $CellContext`V$$ = 6, $CellContext`vib$$ = 
        1500}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Text[
        Quiet[
         Grid[{{$CellContext`KetSC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
             Sum[((E^(-($CellContext`LambdaI$$/(
                    0.000123985 $CellContext`vib$$))) \
($CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$))^$CellContext`m)/
                Factorial[$CellContext`m]) 
               E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                    0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            Row[{"= semi\[Hyphen]classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`HR = \
$CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$), 
            "= Huang-Rhys factor"}, {$CellContext`FCWD = 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            "= Franck-Condon weighted density of states"}, \
{$CellContext`KoptSC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
            "= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))"}, {$CellContext`KetC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
                0.000123985^2)) $CellContext`V$$^2) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                  0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
            Row[{"= classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`EAC = \
($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
             4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
            "= classical activation energy (eV)"}, {$CellContext`KoptC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2, 
            "= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}, {$CellContext`LambdaT = \
$CellContext`LambdaI$$ + $CellContext`LambdaS$$, 
            "= total lambda (eV)"}, {$CellContext`KBT = 
            0.0000861733033 $CellContext`T$$, 
            Row[{"= ", 
              Subscript[
               Style["K", Italic], $CellContext`b], 
              Style["T", Italic], " (eV)"}]}}, ItemSize -> {{14, All}, 1.5}, 
          Alignment -> {{Right, Left}}, 
          Dividers -> {{False}, {
            False, False, False, False, True, False, False, True}}]]], 
      "Specifications" :> {{{$CellContext`DeltaG$$, -1.537, ""}, 1, -8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`LambdaS$$, 0.237, ""}, 0.00001, 8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 295, ""}, 4, 1000, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`vib$$, 1500, ""}, 4, 10000, 0.001, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`n$$, 50, ""}, 0, 500, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`V$$, 6, ""}, 0.005, 8066, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Column[{
          Row[{
            Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
          Manipulate`Place[1], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
          Manipulate`Place[2], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
          Manipulate`Place[3], 
          Row[{
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[5], 
          Row[{"summation factor ", 
            Style["n", Italic]}], 
          Manipulate`Place[6], 
          Row[{"electronic coupling ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[7], 
          Spacer[140]}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{577., {157., 163.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->152569364,ExpressionUUID->"4b4a3b03-1d48-46a5-b6b5-c49673e11ccb"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -1.329, $CellContext`LambdaI$$ = 
    0.3000000000000173, $CellContext`LambdaS$$ = 0.04, $CellContext`n$$ = 
    50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
    100.85, $CellContext`vib$$ = 3372, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`DeltaG$$], -1.329, ""}, 1, -8, 0.01}, {{
       Hold[$CellContext`LambdaS$$], 0.04, ""}, 0.00001, 8, 0.01}, {{
       Hold[$CellContext`LambdaI$$], 0.3000000000000173, ""}, 0.0001, 2, 
      0.01}, {{
       Hold[$CellContext`T$$], 295.0000000000191, ""}, 4, 1000, 0.01}, {{
       Hold[$CellContext`vib$$], 3372, ""}, 4, 10000, 0.001}, {{
       Hold[$CellContext`n$$], 50, ""}, 0, 500, 0.01}, {{
       Hold[$CellContext`V$$], 100.85, ""}, 0.005, 8066, 0.01}, {
      Hold[
       Column[{
         Row[{
           Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
         Manipulate`Place[1], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
         Manipulate`Place[2], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
         Manipulate`Place[3], 
         Row[{
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[5], 
         Row[{"summation factor ", 
           Style["n", Italic]}], 
         Manipulate`Place[6], 
         Row[{"electronic coupling ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[7], 
         Spacer[140]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {379., {96., 101.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.329, $CellContext`LambdaI$$ = 
        0.3000000000000173, $CellContext`LambdaS$$ = 0.04, $CellContext`n$$ = 
        50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
        100.85, $CellContext`vib$$ = 3372}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Text[
        Quiet[
         Grid[{{$CellContext`KetSC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
             Sum[((E^(-($CellContext`LambdaI$$/(
                    0.000123985 $CellContext`vib$$))) \
($CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$))^$CellContext`m)/
                Factorial[$CellContext`m]) 
               E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                    0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            Row[{"= semi\[Hyphen]classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`HR = \
$CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$), 
            "= Huang-Rhys factor"}, {$CellContext`FCWD = 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            
            "= Franck-Condon weighted density of states"}, \
{$CellContext`KoptSC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
            "= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))"}, {$CellContext`KetC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
                0.000123985^2)) $CellContext`V$$^2) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                  0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
            Row[{"= classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`EAC = \
($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
             4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
            "= classical activation energy (eV)"}, {$CellContext`KoptC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2, 
            "= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}, {$CellContext`LambdaT = \
$CellContext`LambdaI$$ + $CellContext`LambdaS$$, 
            "= total lambda (eV)"}, {$CellContext`KBT = 
            0.0000861733033 $CellContext`T$$, 
            Row[{"= ", 
              Subscript[
               Style["K", Italic], $CellContext`b], 
              Style["T", Italic], " (eV)"}]}}, ItemSize -> {{14, All}, 1.5}, 
          Alignment -> {{Right, Left}}, 
          Dividers -> {{False}, {
            False, False, False, False, True, False, False, True}}]]], 
      "Specifications" :> {{{$CellContext`DeltaG$$, -1.329, ""}, 1, -8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`LambdaS$$, 0.04, ""}, 0.00001, 8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`LambdaI$$, 0.3000000000000173, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 295.0000000000191, ""}, 4, 1000, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`vib$$, 3372, ""}, 4, 10000, 0.001, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`n$$, 50, ""}, 0, 500, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`V$$, 100.85, ""}, 0.005, 8066, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Column[{
          Row[{
            Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
          Manipulate`Place[1], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
          Manipulate`Place[2], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
          Manipulate`Place[3], 
          Row[{
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[5], 
          Row[{"summation factor ", 
            Style["n", Italic]}], 
          Manipulate`Place[6], 
          Row[{"electronic coupling ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[7], 
          Spacer[140]}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{577., {157., 163.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->137826230,ExpressionUUID->"1f083aa4-8601-4cc3-b7a5-87baa262ae86"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -0.47, $CellContext`LambdaI$$ = 
    0.3000000000000173, $CellContext`LambdaS$$ = 0.9, $CellContext`n$$ = 
    50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
    43, $CellContext`vib$$ = 490, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`DeltaG$$], -0.47, ""}, 1, -8, 0.01}, {{
       Hold[$CellContext`LambdaS$$], 0.9, ""}, 0.00001, 8, 0.01}, {{
       Hold[$CellContext`LambdaI$$], 0.3000000000000173, ""}, 0.0001, 2, 
      0.01}, {{
       Hold[$CellContext`T$$], 295.0000000000191, ""}, 4, 1000, 0.01}, {{
       Hold[$CellContext`vib$$], 490, ""}, 4, 10000, 0.001}, {{
       Hold[$CellContext`n$$], 50, ""}, 0, 500, 0.01}, {{
       Hold[$CellContext`V$$], 43, ""}, 0.005, 8066, 0.01}, {
      Hold[
       Column[{
         Row[{
           Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
         Manipulate`Place[1], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
         Manipulate`Place[2], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
         Manipulate`Place[3], 
         Row[{
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[5], 
         Row[{"summation factor ", 
           Style["n", Italic]}], 
         Manipulate`Place[6], 
         Row[{"electronic coupling ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[7], 
         Spacer[140]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {379., {96., 101.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -0.47, $CellContext`LambdaI$$ = 
        0.3000000000000173, $CellContext`LambdaS$$ = 0.9, $CellContext`n$$ = 
        50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
        43, $CellContext`vib$$ = 490}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Text[
        Quiet[
         Grid[{{$CellContext`KetSC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
             Sum[((E^(-($CellContext`LambdaI$$/(
                    0.000123985 $CellContext`vib$$))) \
($CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$))^$CellContext`m)/
                Factorial[$CellContext`m]) 
               E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                    0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            Row[{"= semi\[Hyphen]classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`HR = \
$CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$), 
            "= Huang-Rhys factor"}, {$CellContext`FCWD = 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            
            "= Franck-Condon weighted density of states"}, \
{$CellContext`KoptSC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
            "= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))"}, {$CellContext`KetC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
                0.000123985^2)) $CellContext`V$$^2) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                  0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
            Row[{"= classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`EAC = \
($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
             4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
            "= classical activation energy (eV)"}, {$CellContext`KoptC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2, 
            "= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}, {$CellContext`LambdaT = \
$CellContext`LambdaI$$ + $CellContext`LambdaS$$, 
            "= total lambda (eV)"}, {$CellContext`KBT = 
            0.0000861733033 $CellContext`T$$, 
            Row[{"= ", 
              Subscript[
               Style["K", Italic], $CellContext`b], 
              Style["T", Italic], " (eV)"}]}}, ItemSize -> {{14, All}, 1.5}, 
          Alignment -> {{Right, Left}}, 
          Dividers -> {{False}, {
            False, False, False, False, True, False, False, True}}]]], 
      "Specifications" :> {{{$CellContext`DeltaG$$, -0.47, ""}, 1, -8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`LambdaS$$, 0.9, ""}, 0.00001, 8, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`LambdaI$$, 0.3000000000000173, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 295.0000000000191, ""}, 4, 1000, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`vib$$, 490, ""}, 4, 10000, 0.001, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`n$$, 50, ""}, 0, 500, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`V$$, 43, ""}, 0.005, 8066, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Column[{
          Row[{
            Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
          Manipulate`Place[1], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
          Manipulate`Place[2], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
          Manipulate`Place[3], 
          Row[{
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[5], 
          Row[{"summation factor ", 
            Style["n", Italic]}], 
          Manipulate`Place[6], 
          Row[{"electronic coupling ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[7], 
          Spacer[140]}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{577., {157., 163.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->1458076144,ExpressionUUID->"896f5efb-6e12-434a-8ce9-5faba03538f8"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -1.29, $CellContext`LambdaI$$ = 
    0.3000000000000173, $CellContext`LambdaS$$ = 0.9, $CellContext`n$$ = 
    50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
    0.14, $CellContext`vib$$ = 490, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`DeltaG$$], -1.29, ""}, 1, -8, 0.01}, {{
       Hold[$CellContext`LambdaS$$], 0.9, ""}, 0.00001, 8, 0.01}, {{
       Hold[$CellContext`LambdaI$$], 0.3000000000000173, ""}, 0.0001, 2, 
      0.01}, {{
       Hold[$CellContext`T$$], 295.0000000000191, ""}, 4, 1000, 0.01}, {{
       Hold[$CellContext`vib$$], 490, ""}, 4, 10000, 0.001}, {{
       Hold[$CellContext`n$$], 50, ""}, 0, 500, 0.01}, {{
       Hold[$CellContext`V$$], 0.14, ""}, 0.005, 8066, 0.01}, {
      Hold[
       Column[{
         Row[{
           Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
         Manipulate`Place[1], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
         Manipulate`Place[2], 
         "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
         Manipulate`Place[3], 
         Row[{
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[5], 
         Row[{"summation factor ", 
           Style["n", Italic]}], 
         Manipulate`Place[6], 
         Row[{"electronic coupling ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[7], 
         Spacer[140]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {379., {96., 101.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.29, $CellContext`LambdaI$$ = 
        0.3000000000000173, $CellContext`LambdaS$$ = 0.9, $CellContext`n$$ = 
        50, $CellContext`T$$ = 295.0000000000191, $CellContext`V$$ = 
        0.14, $CellContext`vib$$ = 490}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Text[
        Quiet[
         Grid[{{$CellContext`KetSC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
             Sum[((E^(-($CellContext`LambdaI$$/(
                    0.000123985 $CellContext`vib$$))) \
($CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$))^$CellContext`m)/
                Factorial[$CellContext`m]) 
               E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                    0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            Row[{"= semi\[Hyphen]classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`HR = \
$CellContext`LambdaI$$/(0.000123985 $CellContext`vib$$), 
            "= Huang-Rhys factor"}, {$CellContext`FCWD = 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
            
            "= Franck-Condon weighted density of states"}, \
{$CellContext`KoptSC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
            "= pre\[Hyphen]exponential factor (\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))"}, {$CellContext`KetC = (((1/(
                4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                   0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
                0.000123985^2)) $CellContext`V$$^2) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                  0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
            Row[{"= classical rate ", 
              Subscript[
               Style["k", Italic], $CellContext`et], 
              "(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {$CellContext`EAC = \
($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
             4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
            "= classical activation energy (eV)"}, {$CellContext`KoptC = ((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2, 
            "= classical pre\[Hyphen]exponential factor \
(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}, {$CellContext`LambdaT = \
$CellContext`LambdaI$$ + $CellContext`LambdaS$$, 
            "= total lambda (eV)"}, {$CellContext`KBT = 
            0.0000861733033 $CellContext`T$$, 
            Row[{"= ", 
              Subscript[
               Style["K", Italic], $CellContext`b], 
              Style["T", Italic], " (eV)"}]}}, ItemSize -> {{14, All}, 1.5}, 
          Alignment -> {{Right, Left}}, 
          Dividers -> {{False}, {
            False, False, False, False, True, False, False, True}}]]], 
      "Specifications" :> {{{$CellContext`DeltaG$$, -1.29, ""}, 1, -8, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`LambdaS$$, 0.9, ""}, 0.00001, 8, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`LambdaI$$, 0.3000000000000173, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 295.0000000000191, ""}, 4, 1000, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`vib$$, 490, ""}, 4, 10000, 0.001, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`n$$, 50, ""}, 0, 500, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`V$$, 0.14, ""}, 0.005, 8066, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Column[{
          Row[{
            Style["\[CapitalDelta]\[ThinSpace]G", Italic], " (eV)"}], 
          Manipulate`Place[1], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\) (eV)", 
          Manipulate`Place[2], 
          "\!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) (eV)", 
          Manipulate`Place[3], 
          Row[{
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[5], 
          Row[{"summation factor ", 
            Style["n", Italic]}], 
          Manipulate`Place[6], 
          Row[{"electronic coupling ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[7], 
          Spacer[140]}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{577., {157., 163.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->949856291,ExpressionUUID->"96f99a4e-e424-487f-9a21-4ff4176a4f2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Details",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Details", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "This optional section is for a more detailed description of the \
Demonstration than the caption, but it should still be as concise as \
possible. This section may also include numbered snapshot captions (e.g., \
Snapshot 1: phrase or sentence without an initial capital and without a \
period, unless more than one sentence is used) and explanations of the ", 
          StyleBox["Manipulate", "MRbig"], 
          " control labels. Define any symbols undefined so far. Include only \
text in this section \[LongDash] no code, graphics, etc. Do not change the \
cell style or copy cells from other sections. \n\nA book reference uses this \
format: \n    L. D. Schmidt, ", 
          StyleBox[
          "The Engineering of Chemical Reactions", FontSlant -> "Italic"], 
          ", New York: Oxford University Press, 1998. \n\nAn article \
reference uses this format: \n    D. Pearson, \"A Polynomial-Time Algorithm \
for the Change-Making Problem,\" ", 
          StyleBox["Operations Research Letters", FontSlant -> "Italic"], 
          ", ", 
          StyleBox["33", FontWeight -> "Bold"], 
          "(3), 2005 pp. 231\[Dash]234."}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b42cafa3-93cc-45b2-9bce-00512b05ae14"]
}], "DetailsSection",
 CellTags->"Details",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa"],

Cell["\<\
Snapshot 1: Data of the first experimental proof of the inverted region \
(focused here on the isooctane data), based on the work of Closs and Miller.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8456115064967422`*^9, 3.845611564835387*^9}, {
   3.845643267621779*^9, 3.845643271142377*^9}, 3.8456475282428007`*^9, {
   3.846083698731824*^9, 3.846083702288703*^9}},
 CellID->1916642021,ExpressionUUID->"ac9000f0-68a0-41f1-b91b-d8af5158d498"],

Cell[TextData[{
 "Snapshot 2: Data on charge recombination of the compound C60[3]TMPD in \
toluene as solvent. The total lambda is about ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "4"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "19a92d18-19a2-496e-ae12-1e4196c88fba"],
 " of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[ThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"b5c4dc16-96bb-4672-ae73-d03fa9be0700"],
 ". The semi-classical rate is correlated with the experimental rate. The \
rate predicted by the CME is much too low (~2 times per second)."
}], "DetailNotes",
 CellChangeTimes->{{3.8456116065695763`*^9, 3.845611701014373*^9}, {
   3.845612098076188*^9, 3.8456120986279507`*^9}, {3.8456121491502647`*^9, 
   3.845612171276599*^9}, {3.845612233256858*^9, 3.8456122497917347`*^9}, {
   3.845612359938695*^9, 3.845612361211669*^9}, {3.845643300359337*^9, 
   3.845643321802299*^9}, {3.845647569975853*^9, 3.8456475699768353`*^9}, {
   3.845650961244471*^9, 3.845650968727614*^9}, 3.8460836881768064`*^9, {
   3.8460891068940334`*^9, 3.846089107294937*^9}},
 CellID->834068748,ExpressionUUID->"1c7669b7-26c5-4457-bf08-b1963b653014"],

Cell["\<\
Snapshot 3: Data on charge separation for the compound C60[11]DMA in \
benzonitrile as solvent, correlated with the experimental rate.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8456115064967422`*^9, 3.84561156293749*^9}, {
   3.845611741522642*^9, 3.845611833539466*^9}, {3.84561186845566*^9, 
   3.8456118689735527`*^9}, 3.8456121372135487`*^9, {3.845612587813384*^9, 
   3.845612590634036*^9}, {3.845643331343248*^9, 3.845643331961357*^9}, {
   3.846083712027378*^9, 3.8460837191594234`*^9}},
 CellID->1964462950,ExpressionUUID->"7a4d790d-dbc0-4caa-bfb7-dcbff0296394"],

Cell["\<\
Snapshot 4: Data on charge recombination for the compound C60[11]DMA in \
benzonitrile as solvent, correlated with the experimental rate.\
\>", "DetailNotes",
 CellChangeTimes->{
  3.845611750025838*^9, {3.845611952423215*^9, 3.845611955071247*^9}, {
   3.8456125970744753`*^9, 3.8456126006186666`*^9}, {3.845643340332329*^9, 
   3.845643340837866*^9}, {3.8460837218283386`*^9, 3.846083729984131*^9}},
 CellID->717664063,ExpressionUUID->"1877e7e1-64c0-4b55-bf65-a9e6ff00dc54"],

Cell["\<\
The output of this Demonstration was checked against the R-package [10] that \
runs in the statistical software package R [11] for computing and graphics.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8456126683725033`*^9, 3.845612668372724*^9}, {
   3.845612876110281*^9, 3.845612908862957*^9}, 3.845612946161022*^9, {
   3.845612982526473*^9, 3.845613038754218*^9}, {3.8456132424621964`*^9, 
   3.84561332984474*^9}, {3.845643347577729*^9, 3.845643384287578*^9}, {
   3.845643416273468*^9, 3.845643456000475*^9}, 3.8459232301552773`*^9},
 CellID->1798314378,ExpressionUUID->"5091f79f-6ebb-4d3d-865b-e72b5897e7f5"],

Cell["References", "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
  3.845486484235264*^9, 3.845486484236615*^9}},
 CellID->1520831482,ExpressionUUID->"1a86496d-dec7-4fde-804e-4c2644e80cf8"],

Cell[TextData[{
 "[1] R. A. Marcus, \"Electron Transfer Reactions in Chemistry: Theory and \
Experiment (Nobel Lecture),\" ",
 StyleBox["Angewandte Chemie International Edition",
  FontSlant->"Italic"],
 ", ",
 StyleBox["32",
  FontWeight->"Bold"],
 "(8), 1993 pp. 1111\[Dash]1121. ",
 ButtonBox["doi:10.1002/anie.199311113",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1002/anie.199311113"], None},
  ButtonNote->"https://doi.org/10.1002/anie.199311113"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
   3.845486485563533*^9, 3.8454865155028973`*^9}, {3.845487592619128*^9, 
   3.8454876364889593`*^9}, {3.845487667796479*^9, 3.8454876737310143`*^9}, {
   3.845487788050535*^9, 3.8454878088794947`*^9}, {3.845487859066869*^9, 
   3.8454878996227083`*^9}, 3.8454879903912582`*^9, {3.845488646583804*^9, 
   3.845488646849061*^9}, {3.845643465159183*^9, 3.8456434782941628`*^9}, {
   3.845643763608822*^9, 3.845643772552966*^9}, {3.8460839528897514`*^9, 
   3.8460839544787807`*^9}},
 CellID->1044342058,ExpressionUUID->"21e2b6a3-e106-4c32-938f-e4e177edefe5"],

Cell[TextData[{
 "[2] S. Chaudhuri, S. Hedstr\[ODoubleDot]m, D. D. M\[EAcute]ndez-Hern\
\[AAcute]ndez, H. P. Hendrickson, K. A. Jung, J. Ho and V. S. Batista, \
\"Electron Transfer Assisted by Vibronic Coupling from Multiple Modes,\" ",
 StyleBox["Journal of Chemical Theory and Computation",
  FontSlant->"Italic"],
 ", ",
 StyleBox["13",
  FontWeight->"Bold"],
 "(12), 2017 pp. 6000\[Dash]6009. ",
 ButtonBox["doi:10.1021/acs.jctc.7b00513.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/acs.jctc.7b00513"], None},
  ButtonNote->"https://doi.org/10.1021/acs.jctc.7b00513"]
}], "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
  3.845486485563533*^9, 3.845486494542997*^9}, {3.845487520953878*^9, 
  3.845487520958171*^9}},
 CellID->2075423495,ExpressionUUID->"69bacdf3-83ed-45d9-8c1a-83faca702e43"],

Cell[TextData[{
 "[3] P. F. Barbara, T. J. Meyer, M. A. Ratner, \"Contemporary Issues in \
Electron Transfer Research\", ",
 StyleBox["Journal of Physical Chemistry",
  FontSlant->"Italic"],
 ", ",
 StyleBox["100",
  FontWeight->"Bold"],
 "(31), 1996 pp. 13148\[Dash]13168. ",
 ButtonBox["doi:10.1021/jp9605663",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/jp9605663"], None},
  ButtonNote->"https://doi.org/10.1021/jp9605663"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845487945501761*^9, 3.845487945501944*^9}, {
  3.845488000437199*^9, 3.845488004909089*^9}, {3.8454884267223167`*^9, 
  3.8454884287459173`*^9}, {3.8454884770455217`*^9, 3.8454885081092777`*^9}, {
  3.8454885599836283`*^9, 3.8454885807988997`*^9}, {3.845488614203888*^9, 
  3.8454886412650547`*^9}, {3.845488675008108*^9, 3.845488703037126*^9}, {
  3.8456439141278267`*^9, 3.845643929079504*^9}},
 CellID->1362205661,ExpressionUUID->"78c35d1e-b6a4-407f-b097-fdc4f5243817"],

Cell[TextData[{
 "[4] G. L. Closs and J. R. Miller, \"Intramolecular Long-Distance Electron \
Transfer in Organic Molecules,\" ",
 StyleBox["Science",
  FontSlant->"Italic"],
 ", ",
 StyleBox["240",
  FontWeight->"Bold"],
 "(4851), 1988 pp. 440\[Dash]447. ",
 ButtonBox["doi:10.1126/science.240.4851.440",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1126/science.240.4851.440"], None},
  ButtonNote->"https://doi.org/10.1126/science.240.4851.440"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845488847135751*^9, 3.845488847936137*^9}, 
   3.84548892908597*^9, {3.8454889707375813`*^9, 3.845488986639029*^9}, {
   3.845489962649474*^9, 3.8454900049219027`*^9}, {3.845490036544503*^9, 
   3.8454900669925137`*^9}, {3.845490162753018*^9, 3.845490169252675*^9}, {
   3.8454901999758673`*^9, 3.845490199979129*^9}, {3.845529422901569*^9, 
   3.845529423364011*^9}, {3.845643995119815*^9, 3.845644017491386*^9}},
 CellID->267383760,ExpressionUUID->"1f0eec4f-b40a-4182-b182-b1f4260285a2"],

Cell[TextData[{
 "[5] P. Hudhomme and R. M. Williams, \"Energy and Electron Transfer in \
Photo- and Electro-active Fullerene Dyads,\" ",
 StyleBox["Handbook of Carbon Nano Materials",
  FontSlant->"Italic"],
 " (F. D'Souza and K. M. Kadish, eds.), Hackensack, NJ: World Scientific, \
2011 pp. 545\[Dash]591. ",
 ButtonBox["doi:10.1142/9789814327824_0017",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1142/9789814327824_0017"], None},
  ButtonNote->"https://doi.org/10.1142/9789814327824_0017"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8454685041663237`*^9, 3.8454685192133703`*^9}, {
   3.8454879287150793`*^9, 3.845487937930896*^9}, 3.8454889355990353`*^9, {
   3.845488975277957*^9, 3.8454889821674137`*^9}, {3.845489063987767*^9, 
   3.845489146995013*^9}, {3.845489195356243*^9, 3.8454891953597*^9}, {
   3.845529189934093*^9, 3.845529213918605*^9}, {3.845529391166643*^9, 
   3.8455294155160303`*^9}, {3.845529450779456*^9, 3.8455294536519737`*^9}, {
   3.845529669926862*^9, 3.845529735627886*^9}, {3.8455298100216913`*^9, 
   3.845529810024806*^9}, {3.845644090038953*^9, 3.8456440975309877`*^9}, {
   3.845644135546042*^9, 3.845644164110743*^9}, {3.8456442064346952`*^9, 
   3.8456442778070173`*^9}, {3.8456443227864027`*^9, 3.845644326352326*^9}, {
   3.845645904073799*^9, 3.845645904314596*^9}},
 CellID->240524787,ExpressionUUID->"96232d05-d21a-4d41-ba87-654257b71f8e"],

Cell[TextData[{
 StyleBox["[6] ",
  FontSize->12],
 "R. M. Williams. \"Introduction to Electron Transfer,\" (Nov 11, 2021) ",
 ButtonBox["doi:10.13140/RG.2.2.16547.30244",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.13140/RG.2.2.16547.30244"], None},
  ButtonNote->"http://dx.doi.org/10.13140/RG.2.2.16547.30244"],
 StyleBox[".",
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685041663237`*^9, 3.8454685192133703`*^9}, {
   3.8454879287150793`*^9, 3.845487937930896*^9}, 3.8454889355990353`*^9, {
   3.845488975277957*^9, 3.8454889821674137`*^9}, {3.845489063987767*^9, 
   3.845489146995013*^9}, {3.845489195356243*^9, 3.8454891953597*^9}, {
   3.845529189934093*^9, 3.845529190429112*^9}, {3.845644345129858*^9, 
   3.845644401336515*^9}, {3.846086978538337*^9, 3.846086989377143*^9}, {
   3.846087101643921*^9, 3.8460871065877995`*^9}, {3.84608726893346*^9, 
   3.8460872696295996`*^9}, {3.846087339892658*^9, 3.8460873405009985`*^9}},
 CellID->207080162,ExpressionUUID->"2d666b08-3ede-44f0-8b21-d9ffc14a4c44"],

Cell[TextData[{
 StyleBox["[7] R. M. Williams. ",
  FontSize->12],
 StyleBox["Photoinduced Electron Transfer - The Classical Marcus Theory",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[" [Video]. (Nov 11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["youtu.be/YFzeMMOvhl0.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/YFzeMMOvhl0"], None},
  ButtonNote->"https://youtu.be/YFzeMMOvhl0"],
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525743612856*^9, 
   3.845525748675395*^9}, {3.845525805979796*^9, 3.845525811505554*^9}, {
   3.8455291931505547`*^9, 3.845529193581238*^9}, {3.845568465269396*^9, 
   3.845568471122637*^9}, 3.845568562033774*^9, {3.8455686095676327`*^9, 
   3.8455686095709*^9}, {3.8455757747280197`*^9, 3.8455758492973747`*^9}, 
   3.845575934939269*^9, {3.845644455407284*^9, 3.845644502295288*^9}, {
   3.845644545217039*^9, 3.845644568012081*^9}, 3.8460871822998037`*^9},
 CellID->197499548,ExpressionUUID->"868ee2b0-29ef-4445-a8cd-02e8afe5e3d8"],

Cell[TextData[{
 "[8] R. M. Williams. ",
 StyleBox["Photoinduced Electron Transfer - The Semi-classical \
Marcus\[Dash]Levich\[Dash]Jortner Theory",
  FontSlant->"Italic"],
 " [Video]. (Nov 11, 2021) ",
 ButtonBox["youtu.be/GnPIbH6nM9o",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/GnPIbH6nM9o"], None},
  ButtonNote->"https://youtu.be/GnPIbH6nM9o"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525743612856*^9, 
   3.845525751479699*^9}, {3.845525863247136*^9, 3.8455258691488123`*^9}, {
   3.845529195627624*^9, 3.8455291961570797`*^9}, {3.8455682980810432`*^9, 
   3.845568307911862*^9}, 3.845568351711124*^9, {3.845568383495428*^9, 
   3.845568410984956*^9}, {3.84556844741706*^9, 3.845568447420724*^9}, 
   3.845575765263617*^9, {3.845575801398431*^9, 3.84557582464923*^9}, {
   3.8455758561374407`*^9, 3.845575870098317*^9}, {3.845644596969239*^9, 
   3.84564465818088*^9}, {3.846087195092207*^9, 3.8460872087805185`*^9}},
 CellID->1811878752,ExpressionUUID->"f407f29f-6eb7-444f-b1c7-e89295ac444c"],

Cell[TextData[{
 StyleBox["[9] R. M. Williams. University of Amsterdam. (Nov 11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html"], 
    None},
  ButtonNote->
   "https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html"],
  FontSize->12],
 StyleBox[".",
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525754345191*^9, 
   3.8455257548248997`*^9}, {3.845529199062029*^9, 3.845529199475919*^9}, {
   3.845568650686081*^9, 3.845568674871126*^9}, {3.8455687135594*^9, 
   3.845568713562624*^9}, {3.8455759013240013`*^9, 3.845575902270748*^9}, {
   3.8456447049949293`*^9, 3.8456447390402117`*^9}, {3.845644780968061*^9, 
   3.8456447889895372`*^9}},
 CellID->367075982,ExpressionUUID->"99b6ef86-260a-4a00-a39a-d06594ead657"],

Cell[TextData[{
 "[10] J. Id\[EAcute] and G. Raos. \"ChargeTransport: Charge Transfer Rates \
and Charge Carrier Mobilities.\" (Nov 11, 2021) ",
 ButtonBox["CRAN.R-project.org/package=ChargeTransport",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://CRAN.R-project.org/package=ChargeTransport"], None},
  ButtonNote->"https://CRAN.R-project.org/package=ChargeTransport"],
 ". "
}], "DetailNotes",
 CellChangeTimes->{{3.845643396226883*^9, 3.845643396790044*^9}, {
  3.845644810984469*^9, 3.845644819601562*^9}, {3.845644879116131*^9, 
  3.845644917493957*^9}},
 CellID->532304254,ExpressionUUID->"446132c9-9d69-4ff3-bb34-261dad05ea71"],

Cell[TextData[{
 "[11] \"What Is R?\" The R Foundation. (Nov 11, 2021) ",
 ButtonBox["www.r-project.org/about.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.r-project.org/about.html"], None},
  ButtonNote->"https://www.r-project.org/about.html"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845643431678576*^9, 3.8456434368069973`*^9}, {
  3.845644968028158*^9, 3.845645039456131*^9}},
 CellID->688505634,ExpressionUUID->"10becdcd-6a21-40ba-ac86-52a7b526a1ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Control Suggestions",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Control Suggestions", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Check the boxes beside items that are appropriate control \
suggestions for this Demonstration. For more information, see the ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          " page.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "f1fe398c-f37e-4aca-9161-633bae63965a"]
}], "ControlSuggestionsSection",
 CellTags->
  "Control Suggestions",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-\
9fec786547ab"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"fcee1195-e255-4dbd-8863-4af840debdbd"]}],
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\""]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "df0b52c8-7325-4803-bb1e-958545cedfd1"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" on Mac) and drag up and down to zoom.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"61b2b2a8-69c4-4012-b6da-8923112012e2"]}],
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "8e06b60e-3149-4a23-ab31-0a8ab2f5ceaf"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"98a81657-e34e-4dab-ac86-\
717d7eff050a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Slider Zoom",ExpressionUUID->"c8d377e3-56fc-4adc-88e3-cf7642fb3181"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" to make ever finer adjustments.\""}]]], "ControlSuggestions",
 CellChangeTimes->{{3.8454684656711335`*^9, 3.845468465796104*^9}},
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "1fbb5ded-9a1c-4ba0-a087-0d1c0be219ce"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\""]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ec8a5240-77b9-42a0-8b9e-365efb47dfeb"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "5bdb2812-7da3-4bb1-a7fc-436054c40542"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Search Terms",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Search Terms", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide words and phrases that people might search for, with each \
one in a separate cell. Categories are added after the Demonstration is \
submitted, so the best things to enter here are terms (including any \
synonyms) that refer to specific parts of the Demonstration. Do not \
capitalize words unless they are proper names or proper adjectives.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b8b4550c-a7c1-4c5e-acf4-64f68ac8ea51"]
}], "SearchTermsSection",
 CellTags->
  "Search Terms",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b"],

Cell["charge separation", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634545063831*^9}},
 CellID->2129058965,ExpressionUUID->"5b0f8ff9-f928-461f-8dd2-e42a25032219"],

Cell["charge recombination", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.8456345498627834`*^9}},
 CellID->309789228,ExpressionUUID->"317f6e93-9300-4a19-8d37-0f303a35778f"],

Cell["photo-induced electron transfer", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.8456345553917937`*^9}},
 CellID->292502039,ExpressionUUID->"dfeff995-689a-410a-88ed-8c0bf1d5c8fb"],

Cell["Rudolph Marcus", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634560437248*^9}},
 CellID->116661474,ExpressionUUID->"d5b61c72-5561-4480-84a0-f45692f7d060"],

Cell["electron transfer theory", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634565522756*^9}},
 CellID->80983373,ExpressionUUID->"09fa06ef-6408-4b41-9c14-51a7f415b66d"],

Cell["Marcus-Levich-Jortner", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634570790687*^9}},
 CellID->412622865,ExpressionUUID->"985bd04a-df82-42b9-925b-0a185b1572c1"],

Cell["Huang-Rhys factor", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634577528832*^9}},
 CellID->262018152,ExpressionUUID->"3b6b0a34-5874-40ec-9fbe-bade7e6b6af9"],

Cell["electron phonon coupling ", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634577002655*^9}},
 CellID->588225219,ExpressionUUID->"7b6878f4-e6f0-4015-ac31-7bfa12512633"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Related Links",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Related Links", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide hyperlinks (not just bare URLs) to any relevant wolfram.com \
pages, with the page title as the linked text. Links to ", 
          ButtonBox[
          "NKS | Online", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://www.wolframscience.com/nks"], None}], 
          " should use the section title, not a page number. Links to \
non-Wolfram sites go in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d5b26c0d-c135-41cd-9d97-dc9003b05c57"]
}], "RelatedLinksSection",
 CellTags->
  "Related Links",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe"],

Cell[TextData[ButtonBox["Marcus Theory of Electron-Transfer Reactions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransferReactions/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/MarcusTheoryOfElectronTransferReactions/\
"]], "RelatedLinks",
 CellChangeTimes->{{3.8454684380554533`*^9, 3.8454684380554533`*^9}},
 CellID->2070922,ExpressionUUID->"c5cfbfe8-e939-4aac-a0a4-7527af53c5dd"],

Cell[TextData[ButtonBox["Marcus Theory for Electron Transfer in Photosystem \
II",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryForElectronTransferInPhotosystemII/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
MarcusTheoryForElectronTransferInPhotosystemII/"]], "RelatedLinks",
 CellChangeTimes->{{3.845468460694504*^9, 3.845468460694504*^9}},
 CellID->261318040,ExpressionUUID->"e89389a3-503b-43e6-bc3d-5d03804f72cb"],

Cell[TextData[ButtonBox["Quantum Harmonic Oscillator Tunneling into \
Classically Forbidden Regions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
QuantumHarmonicOscillatorTunnelingIntoClassicallyForbiddenRe/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
QuantumHarmonicOscillatorTunnelingIntoClassicallyForbiddenRe/"]], \
"RelatedLinks",
 CellChangeTimes->{{3.8455692825477*^9, 3.845569282548484*^9}, 
   3.845569402798053*^9, {3.8455694420813303`*^9, 3.845569442085705*^9}},
 CellID->1621482253,ExpressionUUID->"28e5ce1c-1776-4163-bc51-7fc8297805e3"],

Cell[TextData[ButtonBox["Franck-Condon Principle in Vibronic Transitions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
FranckCondonPrincipleInVibronicTransitions/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
FranckCondonPrincipleInVibronicTransitions/"]], "RelatedLinks",
 CellChangeTimes->{
  3.8455694768741217`*^9, {3.8455695138231163`*^9, 3.8455695138271093`*^9}},
 CellID->684745741,ExpressionUUID->"4c48e8fc-b2cc-4ca6-b21d-597ac16c531b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Authoring Information",
 Cell[BoxData[
  TemplateBox[{"Authoring Information", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "'Contributed by: John Smith' for single authors; 'Contributed by: \
John Smith, Robert Ford, and Jane Doe' for multiple authors. To credit people \
other than Demonstrations authors, please see the detailed ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "990970f3-a922-4bea-919a-d6fa2da1f6d5"]
}], "AuthorSection",
 CellTags->
  "Authoring \
Information",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a"],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Ren\[EAcute] M. Williams",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://demonstrations.wolfram.com/author.html?author=Ren%C3%A9+M.+\
Williams"], None},
  ButtonNote->
   "https://demonstrations.wolfram.com/author.html?author=Ren%C3%A9+M.+\
Williams"]
}], "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, 
   3.8454681949497166`*^9, {3.8454683873276196`*^9, 
   3.8454683873276196`*^9}},ExpressionUUID->"e6a077c9-f528-4852-97e7-\
764f2f3a1895"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"DemonstrationSource",
WindowSize->{997, 596},
WindowMargins->{{2, Automatic}, {Automatic, 34}},
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.10.2121", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3, "$ApplicationName" -> "Pubs", "$LinkBase" -> "Pubs", 
    "$ApplicationDirectory" -> "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\Documentation\\English\\", 
    "$UseNewPageDialog" -> "False", "$CondensedBlogMenus" -> "True"}, 
  "PresenterSettings" -> {
   "OutlineThumbnails" -> {"1" -> "Thumbnail"}, 
    "OutlinePalette" -> {"Thumbnails" -> {}, "ThumbnailMagnification" -> 0.8},
     "SideNotesPalette" -> {"PaletteNumber" -> 0}}, "BlogsDirectory" -> 
  "\\\\wrisync02.wri.wolfram.com\\backup$\\jayw\\My \
Documents\\jaywstasks\\BlogTools\\Blogs\\", "ChatNotebookID" -> 
  "fef9786d-4748-42a0-a328-5496e837f205", "Originator" -> 
  "chatframework@wolfram.com", "ScreenName" -> "", "ChatCreationDate" -> 
  "DateObject[{2018, 6, 18, 13, 5, 54.5673134}, Instant, Gregorian, -5.]", 
  "CustomWindowTitle" -> "None", "ChatNotebookDate" -> "18 Jun 2018 13:05:54",
   "ChatNotebookWindowTitle" -> "chatframework's Chat - (18 Jun 2018 13:05)", 
  "Participants" -> {"chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "AllParticipants" -> {
   "chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "Contacts" -> {
   "andre@wolfram.com", "bradym@wolfram.com", "brianv@wolfram.com", 
    "jayw@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "EmailListData" -> {0, 0, 0, 0, 1}, "ScrollLock" -> False, "Terminated" -> 
  True, "QuestionState" -> "Timeup", 
  "AttachedCells" -> {
   "Initialization Code" -> None, "Manipulate" -> None, "Caption" -> None, 
    "Snapshots" -> None, "Details" -> None, "Related Links" -> None, 
    "Search Terms" -> None, "Control Suggestions" -> None, "Thumbnail" -> 
    CellObject[25521], "Authoring Information" -> None}},
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (June 19, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"4db397c2-e743-4658-bbb4-82bebfc41392"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initialization Code"->{
  Cell[934, 31, 1833, 39, 67, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
   CellTags->"Initialization Code"]},
 "Manipulate"->{
  Cell[2792, 74, 1524, 30, 67, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
   CellTags->"Manipulate"]},
 "Caption"->{
  Cell[29957, 679, 1138, 24, 67, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
   CellTags->"Caption"]},
 "Thumbnail"->{
  Cell[44943, 1000, 1005, 22, 67, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
   CellTags->"Thumbnail"]},
 "Snapshots"->{
  Cell[54794, 1197, 1018, 22, 67, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
   CellTags->"Snapshots"]},
 "Details"->{
  Cell[90877, 1901, 1796, 36, 67, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
   CellTags->"Details"]},
 "Control Suggestions"->{
  Cell[107379, 2259, 1131, 28, 67, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
   CellTags->"Control Suggestions"]},
 "ResizeImages"->{
  Cell[108513, 2289, 407, 9, 25, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[108923, 2300, 783, 19, 25, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[109709, 2321, 435, 12, 25, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[110147, 2335, 739, 18, 25, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[110889, 2355, 1011, 24, 25, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[111903, 2381, 469, 11, 25, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[112375, 2394, 1564, 33, 25, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[113942, 2429, 1008, 23, 25, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
   CellTags->"BookmarkAnimation"]},
 "Search Terms"->{
  Cell[114987, 2457, 1073, 24, 67, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
   CellTags->"Search Terms"]},
 "Related Links"->{
  Cell[118774, 2534, 1191, 28, 67, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
   CellTags->"Related Links"]},
 "Authoring Information"->{
  Cell[122080, 2616, 1158, 28, 67, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
   CellTags->"Authoring Information"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initialization Code", 126184, 2710},
 {"Manipulate", 126349, 2713},
 {"Caption", 126499, 2716},
 {"Thumbnail", 126657, 2719},
 {"Snapshots", 126810, 2722},
 {"Details", 126961, 2725},
 {"Control Suggestions", 127120, 2728},
 {"ResizeImages", 127296, 2731},
 {"RotateAndZoomIn3D", 127461, 2734},
 {"DragLocators", 127627, 2737},
 {"CreateAndDeleteLocators", 127799, 2740},
 {"SliderZoom", 127969, 2743},
 {"GamepadControls", 128132, 2746},
 {"AutomaticAnimation", 128302, 2749},
 {"BookmarkAnimation", 128475, 2752},
 {"Search Terms", 128642, 2755},
 {"Related Links", 128805, 2758},
 {"Authoring Information", 128978, 2761}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 351, 7, 156, "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],
Cell[934, 31, 1833, 39, 67, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
 CellTags->"Initialization Code"],
Cell[CellGroupData[{
Cell[2792, 74, 1524, 30, 67, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
 CellTags->"Manipulate"],
Cell[CellGroupData[{
Cell[4341, 108, 16745, 395, 954, "Input",ExpressionUUID->"ebecb9f0-1d25-4711-89cd-7223315dbb49",
 CellID->2071835132],
Cell[21089, 505, 8819, 168, 438, "Output",ExpressionUUID->"c15cd21c-1f36-421d-be51-942e9fc8dd58",
 CellID->1533594167]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29957, 679, 1138, 24, 67, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
 CellTags->"Caption"],
Cell[31098, 705, 2993, 53, 99, "ManipulateCaption",ExpressionUUID->"10d06e69-f1e7-4610-b520-424965ba4617",
 CellID->2005410859],
Cell[34094, 760, 2256, 40, 68, "ManipulateCaption",ExpressionUUID->"90730535-7fb3-41ca-9c8b-4d6ded77ff8d",
 CellID->86693020],
Cell[36353, 802, 2181, 38, 79, "ManipulateCaption",ExpressionUUID->"82d1a36f-be33-4236-ad66-761baa545d1f",
 CellID->250327041],
Cell[38537, 842, 2410, 62, 133, "ManipulateCaption",ExpressionUUID->"021b0a42-5790-405a-bc6d-6382b91cdaca",
 CellID->1438951199],
Cell[40950, 906, 2503, 64, 133, "ManipulateCaption",ExpressionUUID->"e54540e6-ab3c-4b08-b7d8-9de76c22c7de",
 CellID->1072432135],
Cell[43456, 972, 1450, 23, 38, "ManipulateCaption",ExpressionUUID->"d5a6d1d8-eef8-42c6-b890-2e5901687fb0",
 CellID->518981415]
}, Open  ]],
Cell[CellGroupData[{
Cell[44943, 1000, 1005, 22, 67, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
 CellTags->"Thumbnail"],
Cell[45951, 1024, 8806, 168, 332, "Output",ExpressionUUID->"da7b36b8-dc80-4405-b5f5-b91fdfa46950",
 CellID->1064870666]
}, Open  ]],
Cell[CellGroupData[{
Cell[54794, 1197, 1018, 22, 67, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
 CellTags->"Snapshots"],
Cell[55815, 1221, 8648, 165, 332, "Output",ExpressionUUID->"4b4a3b03-1d48-46a5-b6b5-c49673e11ccb",
 CellID->152569364],
Cell[64466, 1388, 8805, 168, 332, "Output",ExpressionUUID->"1f083aa4-8601-4cc3-b7a5-87baa262ae86",
 CellID->137826230],
Cell[73274, 1558, 8778, 168, 332, "Output",ExpressionUUID->"896f5efb-6e12-434a-8ce9-5faba03538f8",
 CellID->1458076144],
Cell[82055, 1728, 8785, 168, 332, "Output",ExpressionUUID->"96f99a4e-e424-487f-9a21-4ff4176a4f2f",
 CellID->949856291]
}, Open  ]],
Cell[CellGroupData[{
Cell[90877, 1901, 1796, 36, 67, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
 CellTags->"Details"],
Cell[92676, 1939, 449, 7, 37, "DetailNotes",ExpressionUUID->"ac9000f0-68a0-41f1-b91b-d8af5158d498",
 CellID->1916642021],
Cell[93128, 1948, 1193, 22, 48, "DetailNotes",ExpressionUUID->"1c7669b7-26c5-4457-bf08-b1963b653014",
 CellID->834068748],
Cell[94324, 1972, 581, 9, 22, "DetailNotes",ExpressionUUID->"7a4d790d-dbc0-4caa-bfb7-dcbff0296394",
 CellID->1964462950],
Cell[94908, 1983, 486, 8, 22, "DetailNotes",ExpressionUUID->"1877e7e1-64c0-4b55-bf65-a9e6ff00dc54",
 CellID->717664063],
Cell[95397, 1993, 622, 9, 37, "DetailNotes",ExpressionUUID->"5091f79f-6ebb-4d3d-865b-e72b5897e7f5",
 CellID->1798314378],
Cell[96022, 2004, 224, 3, 22, "DetailNotes",ExpressionUUID->"1a86496d-dec7-4fde-804e-4c2644e80cf8",
 CellID->1520831482],
Cell[96249, 2009, 1130, 24, 37, "DetailNotes",ExpressionUUID->"21e2b6a3-e106-4c32-938f-e4e177edefe5",
 CellID->1044342058],
Cell[97382, 2035, 862, 19, 52, "DetailNotes",ExpressionUUID->"69bacdf3-83ed-45d9-8c1a-83faca702e43",
 CellID->2075423495],
Cell[98247, 2056, 978, 22, 37, "DetailNotes",ExpressionUUID->"78c35d1e-b6a4-407f-b097-fdc4f5243817",
 CellID->1362205661],
Cell[99228, 2080, 1010, 22, 37, "DetailNotes",ExpressionUUID->"1f0eec4f-b40a-4182-b182-b1f4260285a2",
 CellID->267383760],
Cell[100241, 2104, 1414, 25, 37, "DetailNotes",ExpressionUUID->"96232d05-d21a-4d41-ba87-654257b71f8e",
 CellID->240524787],
Cell[101658, 2131, 1056, 20, 22, "DetailNotes",ExpressionUUID->"2d666b08-3ede-44f0-8b21-d9ffc14a4c44",
 CellID->207080162],
Cell[102717, 2153, 1187, 24, 22, "DetailNotes",ExpressionUUID->"868ee2b0-29ef-4445-a8cd-02e8afe5e3d8",
 CellID->197499548],
Cell[103907, 2179, 1206, 23, 37, "DetailNotes",ExpressionUUID->"f407f29f-6eb7-444f-b1c7-e89295ac444c",
 CellID->1811878752],
Cell[105116, 2204, 1089, 22, 22, "DetailNotes",ExpressionUUID->"99b6ef86-260a-4a00-a39a-d06594ead657",
 CellID->367075982],
Cell[106208, 2228, 646, 13, 37, "DetailNotes",ExpressionUUID->"446132c9-9d69-4ff3-bb34-261dad05ea71",
 CellID->532304254],
Cell[106857, 2243, 485, 11, 22, "DetailNotes",ExpressionUUID->"10becdcd-6a21-40ba-ac86-52a7b526a1ef",
 CellID->688505634]
}, Open  ]],
Cell[CellGroupData[{
Cell[107379, 2259, 1131, 28, 67, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
 CellTags->"Control Suggestions"],
Cell[108513, 2289, 407, 9, 25, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
 CellTags->"ResizeImages"],
Cell[108923, 2300, 783, 19, 25, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
 CellTags->"RotateAndZoomIn3D"],
Cell[109709, 2321, 435, 12, 25, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
 CellTags->"DragLocators"],
Cell[110147, 2335, 739, 18, 25, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
 CellTags->"CreateAndDeleteLocators"],
Cell[110889, 2355, 1011, 24, 25, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
 CellTags->"SliderZoom"],
Cell[111903, 2381, 469, 11, 25, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
 CellTags->"GamepadControls"],
Cell[112375, 2394, 1564, 33, 25, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
 CellTags->"AutomaticAnimation"],
Cell[113942, 2429, 1008, 23, 25, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114987, 2457, 1073, 24, 67, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
 CellTags->"Search Terms"],
Cell[116063, 2483, 328, 4, 24, "SearchTerms",ExpressionUUID->"5b0f8ff9-f928-461f-8dd2-e42a25032219",
 CellID->2129058965],
Cell[116394, 2489, 332, 4, 24, "SearchTerms",ExpressionUUID->"317f6e93-9300-4a19-8d37-0f303a35778f",
 CellID->309789228],
Cell[116729, 2495, 343, 4, 24, "SearchTerms",ExpressionUUID->"dfeff995-689a-410a-88ed-8c0bf1d5c8fb",
 CellID->292502039],
Cell[117075, 2501, 324, 4, 24, "SearchTerms",ExpressionUUID->"d5b61c72-5561-4480-84a0-f45692f7d060",
 CellID->116661474],
Cell[117402, 2507, 333, 4, 24, "SearchTerms",ExpressionUUID->"09fa06ef-6408-4b41-9c14-51a7f415b66d",
 CellID->80983373],
Cell[117738, 2513, 331, 4, 24, "SearchTerms",ExpressionUUID->"985bd04a-df82-42b9-925b-0a185b1572c1",
 CellID->412622865],
Cell[118072, 2519, 327, 4, 24, "SearchTerms",ExpressionUUID->"3b6b0a34-5874-40ec-9fbe-bade7e6b6af9",
 CellID->262018152],
Cell[118402, 2525, 335, 4, 24, "SearchTerms",ExpressionUUID->"7b6878f4-e6f0-4015-ac31-7bfa12512633",
 CellID->588225219]
}, Open  ]],
Cell[CellGroupData[{
Cell[118774, 2534, 1191, 28, 67, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
 CellTags->"Related Links"],
Cell[119968, 2564, 465, 9, 24, "RelatedLinks",ExpressionUUID->"c5cfbfe8-e939-4aac-a0a4-7527af53c5dd",
 CellID->2070922],
Cell[120436, 2575, 488, 10, 24, "RelatedLinks",ExpressionUUID->"e89389a3-503b-43e6-bc3d-5d03804f72cb",
 CellID->261318040],
Cell[120927, 2587, 610, 12, 24, "RelatedLinks",ExpressionUUID->"28e5ce1c-1776-4163-bc51-7fc8297805e3",
 CellID->1621482253],
Cell[121540, 2601, 503, 10, 24, "RelatedLinks",ExpressionUUID->"4c48e8fc-b2cc-4ca6-b21d-597ac16c531b",
 CellID->684745741]
}, Open  ]],
Cell[CellGroupData[{
Cell[122080, 2616, 1158, 28, 67, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
 CellTags->"Authoring Information"],
Cell[123241, 2646, 556, 15, 24, "Author",ExpressionUUID->"e6a077c9-f528-4852-97e7-764f2f3a1895"]
}, Open  ]]
}, Open  ]]
}
]
*)

