(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    213774,       4332]
NotebookOptionsPosition[    194890,       3993]
NotebookOutlinePosition[    200916,       4117]
CellTagsIndexPosition[    200244,       4095]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Marcus Theory of Electron Transfer 2: Semiclassical Marcus Equation in Three \
Dimensions\
\>", "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],

Cell[TextData[{
 "Initialization Code",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Initialization Code",Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"Provide any code that must be evaluated before the ", 
          StyleBox["Manipulate", "MRbig"], 
          ". This will automatically be built into the ", 
          StyleBox["Manipulate", "MRbig"], 
          " in the final notebook version. Never use a package that is not \
included in the default distribution of ", 
          StyleBox["Mathematica", FontSlant -> "Italic"], 
          ". To use a package, use the ", 
          StyleBox["Initialization", "MRbig"], " option (with ", 
          StyleBox["Get", "MRbig"], ", not ", 
          StyleBox["Needs", "MRbig"], ") in the ", 
          StyleBox["Manipulate", "MRbig"], 
          " itself, and use the full name of the function from the package. \
For example:\n", 
          StyleBox[
          "  Manipulate[\n  ...\n  ComputationalGeometry`ConvexHull[...]...\n \
 ...\n  Initialization :> Get[\"ComputationalGeometry`\"],\n  ...\n  ]", 
           "MR"], "\nIf you provide initialization code, include a ", 
          StyleBox["SaveDefinitions->True", "MRbig"], " option in the ", 
          StyleBox["Manipulate", "MRbig"], ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "81fde376-e763-44cf-83ed-5c52ec315067"]
}], "InitializationSection",
 CellTags->
  "Initialization \
Code",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Manipulate",
 Cell[BoxData[
  TemplateBox[{"Manipulate",Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"This section contains the ", 
          StyleBox["Manipulate", "MRbig"], 
          " input cell and its evaluated output cell. Make all control labels \
or labels in the output as descriptive as possible, with only proper nouns \
and proper adjectives capitalized. More description of the controls can be \
provided in the Details section below, if necessary. If you change this ", 
          StyleBox["Manipulate", "MRbig"], 
          " after creating screenshots and/or thumbnails, use ", 
          StyleBox["Update Thumbnail & Snapshots", FontWeight -> "Bold"], 
          " in the toolbar to update any copies in later sections. You can \
control the Flash preview for the Demonstration with the ", 
          StyleBox["AutorunSequencing", "MRbig"], " option. Use ", 
          StyleBox["SaveDefinitions->True", "MRbig"], 
          " if you provided initialization code in the previous section."}], 
        "MoreInfoText"], Background -> GrayLevel[0.95], FrameMargins -> 20, 
       FrameStyle -> GrayLevel[0.9], RoundingRadius -> 5]], "MoreInfoText", 
     Deletable -> True, CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d12d57a6-93e6-4518-8a9c-9df2eb688354"]
}], "ManipulateSection",
 CellTags->
  "Manipulate",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Quiet", "[", 
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{"z", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], "  ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"0.0000861733033", " ", "y", " ", "T"}], ")"}], 
             "0.5"]}], ")"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Pi]", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], " ", 
        SuperscriptBox["V", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"m", "=", "0"}], "n"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"-", "LambdaI"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"0.000123985", " ", "vib"}], ")"}]}]], " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"LambdaI", "/", 
                   RowBox[{"(", 
                    RowBox[{"0.000123985", " ", "vib"}], ")"}]}], ")"}], "^", 
                 "m"}]}], ")"}], "/", 
              RowBox[{"m", "!"}]}], ")"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x", "+", "y", "+", 
                  RowBox[{"m", " ", 
                   RowBox[{"(", 
                    RowBox[{"0.000123985", " ", "vib"}], ")"}]}]}], ")"}], 
                "2"], 
               RowBox[{
               "4", " ", "0.0000861733033", " ", "y", " ", "T"}]]}]]}], 
           ")"}]}], ")"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "b", ",", "c"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "e"}], "}"}], ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"10", "^", "a"}]}], "}"}]}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", 
       RowBox[{"{", "f", "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<\[CapitalDelta]\>\"", ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<G\>\"", ",", "Italic"}], "]"}], ",", 
            "\"\< (eV)\>\""}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"\"\<\[Lambda]\>\"", ",", "\"\<S\>\""}], "]"}], ",", 
            "\"\< (eV)\>\""}], "}"}], "]"}], ",", " ", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<rate (\>\"", ",", 
            RowBox[{"Superscript", "[", 
             RowBox[{"\"\<s\>\"", ",", "\"\<-1\>\""}], "]"}], ",", 
            "\"\<)\>\""}], "}"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
      ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"420", ",", "420"}], "}"}]}], ",", 
      RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
      RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", " ", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "2", ",", "0.6"}], "}"}]}]}], "]"}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
      "\"\<internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \
\(I\)]\) (eV)\>\"", ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"LambdaI", ",", "0.3", ",", " ", "\"\<\>\""}], "}"}], ",", 
          "0.0001", ",", "2", ",", "0.01", ",", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       "\"\<vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\"",
        ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"vib", ",", "1500", ",", " ", "\"\<\>\""}], "}"}], ",", 
          "4", ",", "5000", ",", "0.1", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<electronic coupling, \>\"", " ", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<V\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"V", ",", "6", ",", " ", "\"\<\>\""}], "}"}], ",", "0.005",
           ",", "1000", ",", "0.1", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<temperature, \>\"", ",", " ", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<T\>\"", ",", "Italic"}], "]"}], ",", "\"\< (K)\>\""}],
          "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"T", ",", "296", ",", " ", "\"\<\>\""}], "}"}], ",", "4", 
          ",", "1000", ",", "1", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<summation factor \>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<m\>\"", ",", "Italic"}], "]"}]}], "}"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"n", ",", "5", ",", " ", "\"\<\>\""}], "}"}], ",", "0", 
          ",", "50", ",", "1", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<a\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< (axis, log \>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<z\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< maximum (log \>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}], ",", "\"\<))\>\""}], 
         "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a", ",", "10", ",", " ", "\"\<\>\""}], "}"}], ",", "6", 
          ",", "18", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<b\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< (axis, \>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< minimum (\[CapitalDelta]\>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<G\>\"", ",", "Italic"}], "]"}], ",", "\"\<))\>\""}], 
         "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"b", ",", 
            RowBox[{"-", "2.5"}], ",", " ", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"-", "0.1"}], ",", 
          RowBox[{"-", "5"}], ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<c\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< (axis, \>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< maximum (\[CapitalDelta]\>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<G\>\"", ",", "Italic"}], "]"}], ",", "\"\<))\>\""}], 
         "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"c", ",", "0.1", ",", " ", "\"\<\>\""}], "}"}], ",", "0", 
          ",", "5", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<e\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< (axis, \>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<y\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))\>\""}], 
         "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"e", ",", "0.75", ",", " ", "\"\<\>\""}], "}"}], ",", 
          "0.0001", ",", "5", ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<f\>\"", ",", "Italic"}], "]"}], ",", 
          "\"\< (number of points to plot (graph))\>\""}], "}"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"f", ",", "20", ",", " ", "\"\<\>\""}], "}"}], ",", "20", 
          ",", "120", ",", "1", ",", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"HR", ",", 
            RowBox[{"LambdaI", "/", 
             RowBox[{"(", 
              RowBox[{"0.000123985", " ", "vib"}], ")"}]}], ",", " ", 
            "\"\<Huang\[Dash]Rhys, S =\>\""}], "}"}], ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Control", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"KbT", ",", " ", 
            RowBox[{"0.0000861733033", "  ", "T"}], ",", " ", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}], ",", 
                 "\"\<B\>\""}], "]"}], ",", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<T\>\"", ",", "Italic"}], "]"}], ",", 
               "\"\< (eV)\>\""}], "}"}], "]"}]}], "}"}], ",", " ", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
          RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
     RowBox[{"Dividers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "True", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "True", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
          "False", ",", "True", ",", "False", ",", "True", ",", "False", ",", 
          "True", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
          "False", ",", "True", ",", "False", ",", "True", ",", "False", ",", 
          "True", ",", "False", ",", "True", ",", "True", ",", "True"}], 
         "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"Spacer", "[", "140", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", "2", "}"}]}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8456421501126127`*^9, 3.8456421609794273`*^9}, 
   3.845642252944289*^9, 3.8456423030721073`*^9, {3.845645065829426*^9, 
   3.845645121024015*^9}, {3.845645155000463*^9, 3.845645224730733*^9}, 
   3.845645269438683*^9, {3.845645309405168*^9, 3.845645411863632*^9}, 
   3.845645467004471*^9, {3.845645518509691*^9, 3.845645563512116*^9}, {
   3.8456516986262302`*^9, 3.845651732723078*^9}, {3.8456518973039*^9, 
   3.845651947271801*^9}, {3.845652002627442*^9, 3.845652143924704*^9}, {
   3.845652204270443*^9, 3.845652209147485*^9}, {3.8456522927251787`*^9, 
   3.8456524240546513`*^9}, {3.845652488853965*^9, 3.845652529877707*^9}, {
   3.845652564298211*^9, 3.845652678098679*^9}, {3.845652785797573*^9, 
   3.845652835438287*^9}, 3.845652902725328*^9, {3.845923077645211*^9, 
   3.845923140578961*^9}, 3.8462531920176992`*^9, 3.846441006593148*^9, {
   3.846441393785243*^9, 3.846441395200766*^9}, {3.8464416451403008`*^9, 
   3.846441645568571*^9}, {3.846442926118512*^9, 3.846442931046156*^9}, 
   3.846443020964512*^9, {3.846443061398192*^9, 3.8464430641450443`*^9}, {
   3.8464432407576723`*^9, 3.846443249241961*^9}, 3.8464433244298887`*^9, 
   3.846443445764574*^9, 3.846445447408203*^9, {3.846445782721054*^9, 
   3.8464458022627707`*^9}, 3.8464459064810047`*^9, {3.846446429888742*^9, 
   3.846446453090958*^9}, {3.846446619745788*^9, 3.84644664079045*^9}, {
   3.846494157467437*^9, 3.8464941781661797`*^9}, {3.8464943312791567`*^9, 
   3.8464943401156473`*^9}, {3.8464944407611713`*^9, 3.846494526408736*^9}, {
   3.846495125082925*^9, 3.8464951271185617`*^9}, {3.846495525670055*^9, 
   3.846495538283978*^9}, {3.846495612215329*^9, 3.846495635960668*^9}, {
   3.846495915321149*^9, 3.846495916901635*^9}, {3.846495955727384*^9, 
   3.84649598508489*^9}, 3.8464963832871513`*^9, {3.8464967467881308`*^9, 
   3.846496751230843*^9}, {3.846496908534627*^9, 3.8464969211810617`*^9}, {
   3.846502544334588*^9, 3.8465025872556467`*^9}, {3.846502782051407*^9, 
   3.846502782806283*^9}, {3.846503422385763*^9, 3.846503423236127*^9}, {
   3.846503492692501*^9, 3.846503502524785*^9}, {3.846503560260908*^9, 
   3.846503564441367*^9}, {3.846503669136878*^9, 3.846503680884674*^9}, 
   3.846503813074452*^9, 3.846513782974387*^9, {3.846513851517116*^9, 
   3.846513851865859*^9}, {3.846514399643641*^9, 3.84651441043038*^9}, {
   3.846514779454865*^9, 3.846514800443441*^9}, {3.8465148475097933`*^9, 
   3.846514859032618*^9}, {3.846515041871031*^9, 3.846515042691107*^9}, {
   3.8465153693172207`*^9, 3.846515389284811*^9}, {3.8465163486043463`*^9, 
   3.8465163489088984`*^9}, {3.846517515631769*^9, 3.846517545371876*^9}, {
   3.8465238616545687`*^9, 3.846523867654031*^9}, {3.8465239616968393`*^9, 
   3.846523995534775*^9}, 3.846524216268577*^9, {3.846524361000094*^9, 
   3.846524363822249*^9}, {3.8465243991466627`*^9, 3.846524412685824*^9}, {
   3.846524594166284*^9, 3.846524624302278*^9}, {3.8465248015261173`*^9, 
   3.84652482334094*^9}, {3.846524901676255*^9, 3.846524912795079*^9}, 
   3.8465249915359173`*^9, {3.846525053000894*^9, 3.846525054110577*^9}, 
   3.846525417080975*^9, {3.8465267211761827`*^9, 3.846526722859412*^9}, 
   3.846526913864994*^9, 3.846527061694521*^9, {3.846527141664578*^9, 
   3.846527149268159*^9}, {3.8465272920362177`*^9, 3.84652729639394*^9}, {
   3.846527483842057*^9, 3.846527489487692*^9}, {3.846527812191803*^9, 
   3.84652781326377*^9}, {3.846596328971612*^9, 3.8465963345899806`*^9}, {
   3.846596380420156*^9, 3.846596384869797*^9}, {3.8465964185201554`*^9, 
   3.8465964459860363`*^9}, {3.846608875961899*^9, 3.8466088836263657`*^9}, {
   3.8466092145431643`*^9, 3.846609324182022*^9}, {3.846609356553199*^9, 
   3.846609391207157*^9}, {3.84660942358414*^9, 3.846609461927836*^9}, 
   3.846609623134819*^9, {3.8466098162378063`*^9, 3.8466098486422787`*^9}, {
   3.846610076017212*^9, 3.8466100763376923`*^9}, 3.846610119492023*^9, 
   3.84661022897898*^9, {3.846610287702201*^9, 3.846610289232188*^9}, {
   3.8466104445894833`*^9, 3.8466104450049677`*^9}, {3.846610830041741*^9, 
   3.846610858868456*^9}, {3.846610938141398*^9, 3.8466109521338367`*^9}, 
   3.8466111665906763`*^9, {3.846706515532642*^9, 3.846706527607346*^9}, {
   3.8467066106146*^9, 3.8467066578204203`*^9}, 3.84670677235299*^9, {
   3.8467084689884377`*^9, 3.846708526135602*^9}, {3.8467085712126093`*^9, 
   3.8467085717247066`*^9}, {3.8467086345713673`*^9, 3.8467086638876333`*^9}, 
   3.846708767874137*^9, {3.846708853820199*^9, 3.846708855116927*^9}, {
   3.846708888163376*^9, 3.846708898902781*^9}, {3.846709067068572*^9, 
   3.8467091190666027`*^9}, {3.8467092042106657`*^9, 3.846709210468601*^9}, {
   3.84670931573566*^9, 3.8467093305012083`*^9}, {3.846709372306047*^9, 
   3.846709404843878*^9}, {3.846709539617579*^9, 3.846709546534275*^9}, 
   3.846710094392766*^9, {3.8467101625041437`*^9, 3.846710176431075*^9}, {
   3.846710240081993*^9, 3.8467102467740602`*^9}, {3.846710287713825*^9, 
   3.846710304480522*^9}, {3.8467103544690733`*^9, 3.846710357399201*^9}, {
   3.846710389737378*^9, 3.8467104167625513`*^9}, {3.846710530377062*^9, 
   3.846710536457156*^9}, {3.8467105935922413`*^9, 3.846710595366028*^9}, {
   3.846710679957114*^9, 3.846710688059781*^9}, 3.846710757184112*^9, {
   3.8467107995706043`*^9, 3.846710802573842*^9}, {3.846710909453085*^9, 
   3.8467109129420233`*^9}, {3.846710992564581*^9, 3.846710995892824*^9}, {
   3.846711038158845*^9, 3.8467110505160513`*^9}, {3.846778396204019*^9, 
   3.846778469256266*^9}, 3.846778651282282*^9, {3.846778825139927*^9, 
   3.84677884321041*^9}, {3.8467789055135593`*^9, 3.846778908415209*^9}, {
   3.846778976778866*^9, 3.846778987370582*^9}, 3.846779095266789*^9, 
   3.84677918415174*^9, {3.846779236014667*^9, 3.846779236960457*^9}, {
   3.8467793066062927`*^9, 3.846779398219223*^9}, {3.846779446218772*^9, 
   3.846779448890046*^9}, {3.846779488156268*^9, 3.846779488794026*^9}, {
   3.8467795207781477`*^9, 3.846779524221552*^9}, {3.846779554236959*^9, 
   3.8467795813448353`*^9}, {3.8467796441863956`*^9, 3.846779678240539*^9}, 
   3.846779730158807*^9, 3.846779890188097*^9, {3.846779939151572*^9, 
   3.8467799561962337`*^9}, {3.8467800213351727`*^9, 3.846780041696371*^9}, {
   3.8467801033351583`*^9, 3.84678010687752*^9}, {3.846780503962124*^9, 
   3.846780546751677*^9}, {3.846780581927075*^9, 3.846780584905076*^9}, {
   3.8467806700219517`*^9, 3.846780673336548*^9}, {3.846780748761928*^9, 
   3.846780779207492*^9}, {3.846780809584489*^9, 3.8467808330946207`*^9}, 
   3.846780868434184*^9, 3.846780928773078*^9, {3.8467809812855387`*^9, 
   3.846780988188375*^9}, {3.846781080106937*^9, 3.8467810842332563`*^9}, {
   3.846781149475005*^9, 3.846781190617271*^9}, {3.8467812379703217`*^9, 
   3.846781238294694*^9}, 3.8467814190406446`*^9, {3.846786674107326*^9, 
   3.846786678037565*^9}, {3.8467869965663023`*^9, 3.846787034237505*^9}, {
   3.846787197063056*^9, 3.846787200013886*^9}, {3.8468366618958406`*^9, 
   3.8468366764357567`*^9}, {3.846839460104141*^9, 3.846839470629459*^9}, {
   3.8468395818199043`*^9, 3.8468395831275682`*^9}, {3.846999777009426*^9, 
   3.846999783022045*^9}, {3.8471991947286463`*^9, 3.8471992223083167`*^9}, {
   3.847209835618743*^9, 3.84720993823799*^9}, {3.847210326963006*^9, 
   3.847210340497764*^9}, {3.8472103756451817`*^9, 3.847210618649158*^9}, 
   3.847210705671442*^9, 3.847210753338883*^9, 3.847210783883737*^9, {
   3.847210826296982*^9, 3.8472109047997*^9}, {3.847210963033292*^9, 
   3.847210977848434*^9}, 3.847211127143032*^9, 3.8472111838322153`*^9, {
   3.847211220698997*^9, 3.847211253874845*^9}, {3.847212641064883*^9, 
   3.8472126667564*^9}, {3.847212718667653*^9, 3.8472128386826572`*^9}, 
   3.847213420905765*^9, {3.847215218932283*^9, 3.847215236297967*^9}, {
   3.847215271200275*^9, 3.847215290053213*^9}, {3.8472153205427713`*^9, 
   3.847215322769988*^9}, {3.847215387991335*^9, 3.847215403919634*^9}, {
   3.847215456009529*^9, 3.8472154656628036`*^9}, {3.8472155901269608`*^9, 
   3.847215643895513*^9}, {3.847215724011126*^9, 3.847215914760395*^9}, {
   3.847270118388357*^9, 3.847270125551393*^9}, 3.847270297128592*^9, {
   3.847273853959293*^9, 3.8472739243615837`*^9}, 3.847273986648159*^9, {
   3.847735925881246*^9, 3.847735940919281*^9}, {3.847735982844858*^9, 
   3.8477360520768623`*^9}, {3.8477360976855593`*^9, 3.847736109823872*^9}, {
   3.847736257912126*^9, 3.847736273471348*^9}},
 CellLabel->"In[3]:=",
 CellID->2071835132,ExpressionUUID->"ebecb9f0-1d25-4711-89cd-7223315dbb49"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 
    10, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
    0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
    8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 
    0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
    0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 296, $CellContext`V$$ = 
    6, $CellContext`vib$$ = 1500, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 5000, 0.1}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 1000, 0.1}, {{
       Hold[$CellContext`T$$], 296, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`n$$], 5, ""}, 0, 50, 1}, {{
       Hold[$CellContext`a$$], 10, ""}, 6, 18}, {{
       Hold[$CellContext`b$$], -2.5, ""}, -0.1, -5}, {{
       Hold[$CellContext`c$$], 0.1, ""}, 0, 5}, {{
       Hold[$CellContext`e$$], 0.75, ""}, 0.0001, 5}, {{
       Hold[$CellContext`f$$], 20, ""}, 20, 120, 1}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "Huang\[Dash]Rhys, S ="}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       Row[{
         Subscript[
          Style["k", Italic], "B"], 
         Style["T", Italic], " (eV)"}]}}, {
      Hold[
       Column[{
        "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
         Manipulate`Place[1], 
         "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[2], 
         Row[{"electronic coupling, ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[3], 
         Row[{"temperature, ", 
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         Row[{"summation factor ", 
           Style["m", Italic]}], 
         Manipulate`Place[5], 
         Row[{
           Style["a", Italic], " (axis, log ", 
           Style["z", Italic], " maximum (log ", 
           Style["k", Italic], "))"}], 
         Manipulate`Place[6], 
         Row[{
           Style["b", Italic], " (axis, ", 
           Style["x", Italic], " minimum (\[CapitalDelta]", 
           Style["G", Italic], "))"}], 
         Manipulate`Place[7], 
         Row[{
           Style["c", Italic], " (axis, ", 
           Style["x", Italic], " maximum (\[CapitalDelta]", 
           Style["G", Italic], "))"}], 
         Manipulate`Place[8], 
         Row[{
           Style["e", Italic], " (axis, ", 
           Style["y", Italic], 
           " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
         Manipulate`Place[9], 
         Row[{
           Style["f", Italic], " (number of points to plot (graph))"}], 
         Manipulate`Place[10], "", "", 
         Manipulate`Place[11], 
         Manipulate`Place[12]}, Alignment -> Left, 
        Dividers -> {{True}, {
          True, False, True, False, True, False, True, False, True, False, 
           True, False, True, False, True, False, True, False, True, False, 
           True, False, True, True, True}}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Spacer[140]], Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    420., {207., 213.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 
        10, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
        0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
        0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 296, $CellContext`V$$ = 
        6, $CellContext`vib$$ = 1500}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Plot3D[$CellContext`z = (((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`y) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
             0.000123985^2)) $CellContext`V$$^2) 
          Sum[((E^((-$CellContext`LambdaI$$)/(
                0.000123985 $CellContext`vib$$)) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`x + $CellContext`y + $CellContext`m (
                   0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`y) $CellContext`T$$))), \
{$CellContext`m, 
             0, $CellContext`n$$}], {$CellContext`x, $CellContext`b$$, \
$CellContext`c$$}, {$CellContext`y, 0, $CellContext`e$$}, 
         PlotRange -> {0, 10^$CellContext`a$$}, 
         PlotPoints -> {$CellContext`f$$}, AxesLabel -> {
           Row[{"\[CapitalDelta]", 
             Style["G", Italic], " (eV)"}], 
           Row[{
             Subscript["\[Lambda]", "S"], " (eV)"}], 
           Row[{"rate (", 
             Superscript["s", "-1"], ")"}]}, ImageSize -> {420, 420}, Mesh -> 
         False, MaxRecursion -> 1, ViewPoint -> {-1, 2, 0.6}]], 
      "Specifications" :> {{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`vib$$, 1500, ""}, 4, 5000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`V$$, 6, ""}, 0.005, 1000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 296, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`n$$, 5, ""}, 0, 50, 1, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`a$$, 10, ""}, 6, 18, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`b$$, -2.5, ""}, -0.1, -5, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`c$$, 0.1, ""}, 0, 5, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`e$$, 0.75, ""}, 0.0001, 5, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`f$$, 20, ""}, 20, 120, 1, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         10}, {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "Huang\[Dash]Rhys, S ="}, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         11}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          Row[{
            Subscript[
             Style["k", Italic], "B"], 
            Style["T", Italic], " (eV)"}]}, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 12}, 
        Column[{
         "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
          Manipulate`Place[1], 
          "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[2], 
          Row[{"electronic coupling, ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[3], 
          Row[{"temperature, ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          Row[{"summation factor ", 
            Style["m", Italic]}], 
          Manipulate`Place[5], 
          Row[{
            Style["a", Italic], " (axis, log ", 
            Style["z", Italic], " maximum (log ", 
            Style["k", Italic], "))"}], 
          Manipulate`Place[6], 
          Row[{
            Style["b", Italic], " (axis, ", 
            Style["x", Italic], " minimum (\[CapitalDelta]", 
            Style["G", Italic], "))"}], 
          Manipulate`Place[7], 
          Row[{
            Style["c", Italic], " (axis, ", 
            Style["x", Italic], " maximum (\[CapitalDelta]", 
            Style["G", Italic], "))"}], 
          Manipulate`Place[8], 
          Row[{
            Style["e", Italic], " (axis, ", 
            Style["y", Italic], 
            " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
          Manipulate`Place[9], 
          Row[{
            Style["f", Italic], " (number of points to plot (graph))"}], 
          Manipulate`Place[10], "", "", 
          Manipulate`Place[11], 
          Manipulate`Place[12]}, Alignment -> Left, 
         Dividers -> {{True}, {
           True, False, True, False, True, False, True, False, True, False, 
            True, False, True, False, True, False, True, False, True, False, 
            True, False, True, True, True}}], 
        Spacer[140]}, 
      "Options" :> {
       ContinuousAction -> False, AutorunSequencing -> {2}, ControlPlacement -> 
        Left}, "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{664., {260., 266.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>($CellContext`z = 1.3100334655397701`*^10; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.847736134040743*^9, 3.8477361633942204`*^9}, 
   3.847736274377433*^9},
 CellLabel->"Out[3]=",
 CellID->2135287576,ExpressionUUID->"4cf375b7-eb20-449e-a77d-276321055a33"]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Caption",
 Cell[BoxData[
  TemplateBox[{"Caption",Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "The caption provides all the information needed to understand the \
Demonstration. It should be between three and five sentences long, but \
clarity is more important than length. Include only text in this section \
\[LongDash] no code, graphics, etc. Do not change the cell style or copy \
cells from other sections. Do not copy text from books or the web. Write your \
ideas in your own words. If you want to refer to something on the web, link \
to it in the Details.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "a97b5d36-1c59-4018-b3f0-6bfc71662d3d"]
}], "ManipulateCaptionSection",
 CellTags->"Caption",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4"],

Cell[TextData[{
 "This Demonstration describes the semiclassical Marcus model (also called \
Marcus\[Dash]Levich\[Dash]Jortner Theory, MLJ) in three dimensions. The rate ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "fccf31c5-07f9-4f9c-9b80-5d5a59e28a3f"],
 " on the ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineMath",ExpressionUUID->
  "b3d83eac-faa7-4974-a461-f9f9dbadd280"],
 " axis is plotted as a function of the Gibbs free energy change ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[VeryThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"a4e6bb66-f792-4d67-8e9d-17a7623efc42"],
 " and the solvent reorganization energy ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", 
    StyleBox["S",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7acbe72d-3481-40f3-ba90-7a883176025f"],
 " on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "6a56b248-6636-4f53-bfd1-577da3bd9593"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "718f6e67-af90-435b-b976-bed9b137c4be"],
 " axes. This is a linear plot; often ",
 Cell[BoxData[
  FormBox[
   RowBox[{"log", " ", "k"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "2e7079fd-90b1-442b-8ea0-a6c00d99cca6"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "plots are used in this application."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}, {
   3.845485857029244*^9, 3.845486214421936*^9}, {3.845486288761991*^9, 
   3.8454863548722887`*^9}, 3.8454864032678127`*^9, {3.845486705510519*^9, 
   3.84548671040314*^9}, {3.845486903198655*^9, 3.845486904092573*^9}, 
   3.845525356127366*^9, {3.845526497969751*^9, 3.845526501112731*^9}, {
   3.845527676293848*^9, 3.845527694435413*^9}, {3.845527725918661*^9, 
   3.845527726567141*^9}, {3.845642386083975*^9, 3.8456424733745813`*^9}, 
   3.845642512829173*^9, {3.845645841098516*^9, 3.845645843527162*^9}, {
   3.845647290666231*^9, 3.8456473450417233`*^9}, {3.8456473847060213`*^9, 
   3.845647389365912*^9}, {3.8456477682030687`*^9, 3.84564797253769*^9}, {
   3.845648048410379*^9, 3.845648049285551*^9}, {3.84564812553232*^9, 
   3.845648264491376*^9}, {3.845648312989109*^9, 3.845648383824232*^9}, {
   3.8460725220111523`*^9, 3.846072522426863*^9}, {3.8460725730200443`*^9, 
   3.8460725733735104`*^9}, {3.8464417116859293`*^9, 3.846441888328968*^9}, {
   3.8464419471734324`*^9, 3.846442111024125*^9}, {3.846442223317444*^9, 
   3.846442223317789*^9}, {3.846612758561133*^9, 3.846612758951322*^9}, {
   3.846781345777413*^9, 3.846781363172307*^9}, {3.846789797245977*^9, 
   3.846789807759284*^9}, {3.846836968557784*^9, 3.846836976877596*^9}, {
   3.846839076165195*^9, 3.8468390869408712`*^9}, {3.8469616307063847`*^9, 
   3.846961692827239*^9}, {3.8470801696154423`*^9, 3.8470801707282343`*^9}, {
   3.847080262272187*^9, 3.847080272385119*^9}, {3.8472724569569263`*^9, 
   3.8472724902700443`*^9}, {3.847272521226645*^9, 3.847272529056576*^9}, {
   3.847273656827281*^9, 3.847273661787737*^9}, {3.847285251209317*^9, 
   3.847285255340516*^9}, {3.8472854173080463`*^9, 3.847285544452159*^9}, {
   3.8472855805895777`*^9, 3.847285584231554*^9}, {3.847736173783627*^9, 
   3.847736173953321*^9}, {3.847736315721147*^9, 3.84773639039027*^9}, 
   3.847736903801847*^9},
 CellID->2005410859,ExpressionUUID->"10d06e69-f1e7-4610-b520-424965ba4617"],

Cell[TextData[{
 "Nobel Prize winner Rudolph Marcus developed the theory of electron transfer \
[1]. The classical Marcus equation (CME) is based on two simultaneous \
quadratic relations involving the driving force ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "\[CapitalDelta]"}], "\[VeryThinSpace]", "G"}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "c12830ef-fe63-4b83-a74d-80a55244a79a"],
 ", the internal and external (solvent) reorganization energies ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", 
    StyleBox["I",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "f6437f2a-d6c6-4e71-ad6c-b6351af1c510"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", 
    StyleBox["S",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "de6dbf6e-2c7b-45c0-9152-95783896a544"],
 " and the electronic coupling ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8a6e2cf8-c618-4c0f-9eb6-e73cffa6e68a"],
 ". The CME underestimates the electron transfer rate in the inverted region \
[2, 3]. Therefore we need the MLJ equation:"
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}, {
   3.845485857029244*^9, 3.845486214421936*^9}, {3.845486288761991*^9, 
   3.8454863548722887`*^9}, 3.8454864032678127`*^9, {3.845486705510519*^9, 
   3.84548671040314*^9}, {3.845486903198655*^9, 3.845486904092573*^9}, 
   3.845525356127366*^9, {3.845526497969751*^9, 3.845526501112731*^9}, {
   3.845527676293848*^9, 3.845527694435413*^9}, {3.845527725918661*^9, 
   3.845527726567141*^9}, {3.845642386083975*^9, 3.8456424733745813`*^9}, 
   3.845642512829173*^9, {3.845645841098516*^9, 3.845645843527162*^9}, {
   3.845647290666231*^9, 3.8456473450417233`*^9}, {3.8456473847060213`*^9, 
   3.845647389365912*^9}, {3.8456477682030687`*^9, 3.84564797253769*^9}, {
   3.845648048410379*^9, 3.845648049285551*^9}, {3.84564812553232*^9, 
   3.845648264491376*^9}, {3.845648312989109*^9, 3.845648383824232*^9}, {
   3.8460725220111523`*^9, 3.846072522426863*^9}, {3.8460725730200443`*^9, 
   3.8460725733735104`*^9}, {3.8464417116859293`*^9, 3.846441888328968*^9}, {
   3.8464419471734324`*^9, 3.846442111024125*^9}, {3.846442223317444*^9, 
   3.846442223317789*^9}, {3.846612758561133*^9, 3.846612758951322*^9}, {
   3.846781345777413*^9, 3.846781363172307*^9}, {3.846789797245977*^9, 
   3.84678980580639*^9}, {3.846837047319706*^9, 3.8468370802885313`*^9}, {
   3.846961155059142*^9, 3.8469611556861353`*^9}, {3.847080197945608*^9, 
   3.847080197945773*^9}, 3.847080245608575*^9, {3.84727251314788*^9, 
   3.847272515027897*^9}, {3.847272551962844*^9, 3.847272580820483*^9}, 
   3.847273705855259*^9, 3.847285841154718*^9, {3.847286396878777*^9, 
   3.847286396879054*^9}, {3.847736207709382*^9, 3.847736208038547*^9}, {
   3.847736400957005*^9, 3.8477364138849916`*^9}},
 CellID->837612789,ExpressionUUID->"deba3ab5-0412-40f6-98c5-57cfc3ab7688"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", "ET"], "=", 
    RowBox[{
     SqrtBox[
      FractionBox["\[Pi]", 
       RowBox[{
        SuperscriptBox["\[HBar]", "2"], " ", 
        SubscriptBox["\[Lambda]", 
         StyleBox["S",
          FontSlant->"Plain"]], 
        SubscriptBox["k", 
         StyleBox["B",
          FontSlant->"Plain"]], "T"}]]], 
     SuperscriptBox["V", "2"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"m", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["e", 
          RowBox[{"-", "S"}]], 
         SuperscriptBox["S", "m"]}], 
        RowBox[{"m", "!"}]], 
       RowBox[{"exp", "(", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[CapitalDelta]", "\[VeryThinSpace]", "G"}], "+", 
             SubscriptBox["\[Lambda]", 
              StyleBox["S",
               FontSlant->"Plain"]], "+", 
             RowBox[{"m", " ", "\[HBar]", " ", "\[Omega]"}]}], ")"}], "2"], 
          RowBox[{"4", 
           SubscriptBox["\[Lambda]", 
            StyleBox["S",
             FontSlant->"Plain"]], 
           SubscriptBox["k", 
            StyleBox["B",
             FontSlant->"Plain"]], "T"}]]}], ")"}]}]}]}]}], TraditionalForm]],
   "InlineMath",ExpressionUUID->"e75e5650-969c-4b23-a78f-d7c88d00256d"],
 ","
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}, {
   3.845485857029244*^9, 3.845486214421936*^9}, {3.845486288761991*^9, 
   3.8454863548722887`*^9}, 3.8454864032678127`*^9, {3.845486705510519*^9, 
   3.84548671040314*^9}, {3.845486903198655*^9, 3.845486904092573*^9}, 
   3.845525356127366*^9, {3.845526497969751*^9, 3.845526501112731*^9}, {
   3.845527676293848*^9, 3.845527694435413*^9}, {3.845527725918661*^9, 
   3.845527726567141*^9}, {3.845642386083975*^9, 3.8456424733745813`*^9}, 
   3.845642512829173*^9, {3.845645841098516*^9, 3.845645843527162*^9}, {
   3.845647290666231*^9, 3.8456473450417233`*^9}, {3.8456473847060213`*^9, 
   3.845647389365912*^9}, {3.8456477682030687`*^9, 3.84564797253769*^9}, {
   3.845648048410379*^9, 3.845648049285551*^9}, {3.84564812553232*^9, 
   3.845648264491376*^9}, {3.845648312989109*^9, 3.845648383824232*^9}, {
   3.8460725220111523`*^9, 3.846072522426863*^9}, {3.8460725730200443`*^9, 
   3.8460725733735104`*^9}, {3.8464417116859293`*^9, 3.846441888328968*^9}, {
   3.8464419471734324`*^9, 3.846442111024125*^9}, {3.846442223317444*^9, 
   3.846442223317789*^9}, {3.846612758561133*^9, 3.846612758951322*^9}, {
   3.846781345777413*^9, 3.846781363172307*^9}, {3.846789797245977*^9, 
   3.84678980580639*^9}, {3.846837047319706*^9, 3.8468370802885313`*^9}, {
   3.846961155059142*^9, 3.8469611556861353`*^9}, {3.847080197945608*^9, 
   3.847080197945773*^9}, 3.847080245608575*^9, {3.84727251314788*^9, 
   3.847272515027897*^9}, {3.847272551962844*^9, 3.847272580820483*^9}, 
   3.847273705855259*^9, 3.847285841154718*^9, {3.847286402637398*^9, 
   3.8472866413468*^9}, {3.847286775791658*^9, 3.847286999466207*^9}, {
   3.847736181687756*^9, 3.847736182698103*^9}, {3.847736457029006*^9, 
   3.847736465004401*^9}, {3.850303038933709*^9, 3.850303039340309*^9}, {
   3.850303078528417*^9, 3.8503031346298113`*^9}},
 CellID->128144587,ExpressionUUID->"7ad90eec-1676-414b-9cad-e77098c78b8d"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"S", "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", 
       StyleBox["I",
        FontSlant->"Plain"]], "/", "\[HBar]"}], " ", "\[Omega]"}]}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "a90d0fa4-3ce5-4149-9754-7612a89afb0c"],
 "."
}], "ManipulateCaption",
 CellChangeTimes->{{3.847285717602974*^9, 3.84728573463087*^9}, 
   3.8472857670751038`*^9, {3.8472859357969427`*^9, 3.847285977307157*^9}, {
   3.8472863017121887`*^9, 3.847286360436*^9}},
 CellID->731237523,ExpressionUUID->"c73766c7-fc54-421e-9e2a-1f1cb1318d36"],

Cell["\<\
You can change the axis in the Manipulate sliders. You can also change the \
number of plot points, giving the graph more detail, but at the cost of \
slowing the computation. Use Ctrl+Return on the graph for a front view and \
rotate. With Shift+Return you control size. The starting point is a back view \
of the graph, which highlights the bell-shaped Marcus curve.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}, {
   3.845485857029244*^9, 3.845486214421936*^9}, {3.845486288761991*^9, 
   3.8454863548722887`*^9}, 3.8454864032678127`*^9, {3.845486705510519*^9, 
   3.84548671040314*^9}, {3.845486903198655*^9, 3.845486904092573*^9}, 
   3.845525356127366*^9, {3.845526497969751*^9, 3.845526501112731*^9}, {
   3.845527676293848*^9, 3.845527694435413*^9}, {3.845527725918661*^9, 
   3.845527726567141*^9}, {3.845642386083975*^9, 3.8456424733745813`*^9}, 
   3.845642512829173*^9, {3.845645841098516*^9, 3.845645843527162*^9}, {
   3.845647290666231*^9, 3.8456473450417233`*^9}, {3.8456473847060213`*^9, 
   3.845647389365912*^9}, {3.8456477682030687`*^9, 3.84564797253769*^9}, {
   3.845648048410379*^9, 3.845648049285551*^9}, {3.84564812553232*^9, 
   3.845648264491376*^9}, {3.845648312989109*^9, 3.845648383824232*^9}, {
   3.8460725220111523`*^9, 3.846072522426863*^9}, {3.8460725730200443`*^9, 
   3.8460725733735104`*^9}, {3.8464417116859293`*^9, 3.846441888328968*^9}, {
   3.8464419471734324`*^9, 3.846442111024125*^9}, {3.84644222451576*^9, 
   3.8464422983180304`*^9}, {3.84644237925706*^9, 3.846442381704986*^9}, {
   3.846612342285864*^9, 3.846612392467186*^9}, {3.846612434117147*^9, 
   3.846612471862814*^9}, {3.846612509741522*^9, 3.84661252644739*^9}, {
   3.846612661088069*^9, 3.8466126964786654`*^9}, {3.846612731183929*^9, 
   3.8466127431118526`*^9}, {3.846612809938163*^9, 3.8466128202644672`*^9}, {
   3.846781447723749*^9, 3.846781449595215*^9}, {3.8467815181439533`*^9, 
   3.846781518302436*^9}, {3.846790294348321*^9, 3.846790296949485*^9}, {
   3.8472725950529613`*^9, 3.847272642462492*^9}, {3.847287061664466*^9, 
   3.847287139643886*^9}, {3.847736481954705*^9, 3.847736564449326*^9}, {
   3.847817024635476*^9, 3.847817060054738*^9}},
 CellID->2026902308,ExpressionUUID->"ba0285fe-84a0-4730-860f-5c18077533c9"],

Cell["\<\
The starting values are from the so-called Closs and Miller data [4], which \
provided the first experimental proof of the inverted region. We illustrate \
this with the isooctane data in Snapshot 1.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}, {
   3.845485857029244*^9, 3.845486214421936*^9}, {3.845486288761991*^9, 
   3.8454863548722887`*^9}, 3.8454864032678127`*^9, {3.845486705510519*^9, 
   3.84548671040314*^9}, {3.845486903198655*^9, 3.845486904092573*^9}, 
   3.845525356127366*^9, {3.845526497969751*^9, 3.845526501112731*^9}, {
   3.845527676293848*^9, 3.845527694435413*^9}, {3.845527725918661*^9, 
   3.845527726567141*^9}, {3.845642386083975*^9, 3.8456424733745813`*^9}, 
   3.845642512829173*^9, {3.845645841098516*^9, 3.845645843527162*^9}, {
   3.845647290666231*^9, 3.8456473450417233`*^9}, {3.8456473847060213`*^9, 
   3.845647389365912*^9}, {3.8456477682030687`*^9, 3.84564797253769*^9}, {
   3.845648048410379*^9, 3.845648049285551*^9}, {3.84564812553232*^9, 
   3.845648264491376*^9}, {3.845648312989109*^9, 3.845648383824232*^9}, {
   3.8460725220111523`*^9, 3.846072522426863*^9}, {3.8460725730200443`*^9, 
   3.8460725733735104`*^9}, {3.8464417116859293`*^9, 3.84644179529473*^9}, 
   3.846612751280548*^9, 3.84728716716304*^9},
 CellID->794880798,ExpressionUUID->"628a19fb-840d-489e-95e3-ccc53df21a5b"],

Cell[TextData[{
 "We apply the semiclassical Marcus expression to the inverted region. If ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[VeryThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"0fba9ac8-9a5d-448d-87b2-ca40383bacdc"],
 " is much larger than the total ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Lambda]", "=", 
    RowBox[{
     SubscriptBox["\[Lambda]", 
      StyleBox["I",
       FontSlant->"Plain"]], "+", 
     SubscriptBox["\[Lambda]", 
      StyleBox["S",
       FontSlant->"Plain"]]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"66eddda9-fb60-43f0-82a7-2968c4c71a22"],
 ", then inverted region effects are apparent. The enhanced rate (relative to \
CME) in the inverted region is related to the overlap of vibrational \
wavefunctions that contribute to the Franck\[Dash]Condon weighted density of \
states (the Franck\[Dash]Condon factor, FCWD). The Huang\[Dash]Rhys factor is \
related to the vibronic coupling, which is electron-phonon coupling \
(represented by the symbol ",
 Cell[BoxData[
  FormBox[
   RowBox[{"S", "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "i"], "/", "\[HBar]"}], " ", "\[Omega]"}]}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "679190b2-39ac-445b-bbdc-33e4e033e20a"],
 " in the MLJ equation). The vibrational energy shows up in the spacing of \
the spikes in the graph at low solvent reorganization energy ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", 
    StyleBox["S",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "97d865f8-d465-46fd-9f82-8a7b4c056db0"],
 "."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.845398006879942*^9, 3.845398138772657*^9}, {
   3.845486768639637*^9, 3.845486847878462*^9}, {3.845486944303318*^9, 
   3.84548699043965*^9}, {3.8454870774326*^9, 3.845487077737661*^9}, {
   3.845488197525855*^9, 3.8454882623098383`*^9}, {3.84552545068823*^9, 
   3.845525479985098*^9}, {3.845525567767469*^9, 3.845525589291168*^9}, {
   3.8455277692478237`*^9, 3.845527797208523*^9}, {3.845527941069654*^9, 
   3.8455279413244753`*^9}, {3.845642898151327*^9, 3.845642999133505*^9}, {
   3.8456484029905853`*^9, 3.8456485170031557`*^9}, {3.845650593136702*^9, 
   3.84565059385633*^9}, {3.845650650354578*^9, 3.845650659022091*^9}, {
   3.846072739398058*^9, 3.846072745427127*^9}, {3.8466128720606403`*^9, 
   3.846612993111693*^9}, {3.8467814726471148`*^9, 3.846781502317933*^9}, {
   3.8467898620132923`*^9, 3.846789863589429*^9}, {3.846837137658448*^9, 
   3.84683716928201*^9}, {3.8468371996689568`*^9, 3.846837200348881*^9}, {
   3.846961231150116*^9, 3.8469612318965054`*^9}, {3.8470803082689133`*^9, 
   3.8470803684448233`*^9}, {3.847272662693125*^9, 3.84727272775454*^9}, {
   3.847287187240872*^9, 3.8472871890238247`*^9}, {3.847287233824512*^9, 
   3.847287259047521*^9}, {3.847288916705769*^9, 3.847288922390792*^9}, {
   3.8477365844430857`*^9, 3.847736585287949*^9}, 3.847736904824368*^9},
 CellID->86693020,ExpressionUUID->"90730535-7fb3-41ca-9c8b-4d6ded77ff8d"],

Cell["\<\
With the semiclassical equation, we can approximate the measured rates [5] by \
adjusting the vibration that mediates the electron transfer or by adjusting \
the electronic coupling. \
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.845398006879942*^9, 3.845398275984207*^9}, {
   3.845399056704618*^9, 3.8453991166189203`*^9}, {3.845399160300664*^9, 
   3.845399184860959*^9}, {3.8454866351330347`*^9, 3.8454866384585123`*^9}, {
   3.8454882984875507`*^9, 3.845488300869893*^9}, {3.8455256348616123`*^9, 
   3.845525704614236*^9}, {3.845526426223998*^9, 3.845526465725134*^9}, {
   3.8455291576993237`*^9, 3.845529164194769*^9}, 3.845530104394269*^9, {
   3.845530332586508*^9, 3.8455303509203587`*^9}, {3.8456430137821007`*^9, 
   3.8456430350219517`*^9}, {3.84565101819884*^9, 3.845651116577362*^9}, {
   3.845651150660925*^9, 3.845651162936602*^9}, 3.846072784955554*^9, {
   3.846072834467929*^9, 3.84607287553512*^9}, {3.846781952911559*^9, 
   3.8467819670066347`*^9}, 3.8472727365517406`*^9, {3.847287275302434*^9, 
   3.847287303926732*^9}, 3.847736625410554*^9, 3.847736906830048*^9},
 CellID->1950403273,ExpressionUUID->"390f70be-7658-44df-affb-0afbc45e7777"],

Cell["Fit-values bell curve MTHF of Closs and Miller:", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.84727035811931*^9},
 CellID->1438951199,ExpressionUUID->"021b0a42-5790-405a-bc6d-6382b91cdaca"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["S",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.75`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"cba7a946-4e52-4043-ba7a-e1f4300e7fa4"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.847270359283107*^9, {
   3.84727056621581*^9, 3.847270566215871*^9}},
 CellID->1959311453,ExpressionUUID->"45d1a2f2-1ae0-40b4-91d6-e47de233a7f6"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["I",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.45`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"99822463-d0e9-46fa-8700-8bafa3c41d89"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.847270360543099*^9, {
   3.847270573460524*^9, 3.847270573460569*^9}},
 CellID->633347473,ExpressionUUID->"f4a8fa54-b566-4759-93c7-cd85d4c16d74"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"vibration", "=", 
    RowBox[{"1500", 
     SuperscriptBox["cm", 
      RowBox[{"-", "1"}]]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "d8a66997-87f2-4a48-be20-ccd37d308199"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.847270361274207*^9},
 CellID->1742024179,ExpressionUUID->"650f4faa-a430-4ea9-bb09-1b7f32e5b894"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", "6.2`"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "753dc36f-3175-479c-ae1a-3eab4a93f6ef"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.847270362781706*^9},
 CellID->1555816902,ExpressionUUID->"913f5391-8066-408c-8e35-25ea9bf96275"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"296", " ", 
     StyleBox["K",
      FontSlant->"Plain"]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "814329e5-1ba1-4c1e-b828-fb33a2904808"],
 ","
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.8472703635916023`*^9},
 CellID->853786042,ExpressionUUID->"163f403f-3e4e-447d-bd6d-26ea14a0b772"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "6.97`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"9eb02765-0344-4623-a743-62b682099810"],
 ", (dielectric constant of the solvent) "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}, 3.847270364559525*^9},
 CellID->96278640,ExpressionUUID->"c4a3c170-50d0-4b75-8630-45df37a67933"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1.406`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"bf06543a-c0d5-4b11-b3dd-7101ca0d86a4"],
 ", (refractive index of solvent)"
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643062058024*^9, 
   3.845643093321829*^9, {3.845651001762803*^9, 3.845651002439273*^9}, {
   3.845651206237673*^9, 3.845651291413849*^9}, {3.8456513808145113`*^9, 
   3.8456513877965107`*^9}, {3.8456517594119453`*^9, 3.845651849540141*^9}, {
   3.846082851444971*^9, 3.846082900657674*^9}, {3.8460878074059706`*^9, 
   3.8460878090266266`*^9}, 3.846087891225417*^9, {3.84678153520865*^9, 
   3.8467815451589403`*^9}, {3.846781602645321*^9, 3.846781633200344*^9}, {
   3.8467819762225018`*^9, 3.846781988014801*^9}},
 CellID->1099916289,ExpressionUUID->"4a5062e4-eb9b-4109-b8e3-991df75a5e00"],

Cell["Fit-values bell curve isooctane of Closs and Miller:", \
"ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.8472703683959703`*^9, 3.847287322864101*^9},
 CellID->1072432135,ExpressionUUID->"e54540e6-ab3c-4b08-b7d8-9de76c22c7de"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["S",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.15`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5e495e9e-fb32-493d-84bc-3a6416981427"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.8472703691049767`*^9, {3.847270597131962*^9, 
   3.847270597132009*^9}},
 CellID->753835847,ExpressionUUID->"d433d5a8-23ed-4329-8b6a-baa69845f566"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Lambda]", 
     StyleBox["I",
      FontSlant->"Plain"]], "=", 
    RowBox[{"0.45`", " ", "eV"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a9618d9a-575e-4c99-9c71-4f0372c19def"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.847270370004826*^9, {3.84727060087849*^9, 
   3.847270600878537*^9}},
 CellID->1713046876,ExpressionUUID->"f0e83e20-b85a-4cdf-8af5-69a73fbc7312"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"vibration", "=", 
    RowBox[{"1500", 
     SuperscriptBox["cm", 
      RowBox[{"-", "1"}]]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "ab878c2c-9ba6-4988-a71e-474b859fedc3"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.847270371456078*^9},
 CellID->2013073250,ExpressionUUID->"afc1dc98-3915-4073-99a9-6664f345dd49"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", "6.2`"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "b9a11173-5b89-44cb-83a8-56b0f718f380"],
 ", "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.8472703724346848`*^9},
 CellID->117254265,ExpressionUUID->"06b08a2d-f413-430a-bc00-8c5e37ed9e01"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"296", " ", 
     StyleBox["K",
      FontSlant->"Plain"]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "12545d06-db05-4e88-974f-58881eff93e5"],
 ","
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.847270373278557*^9},
 CellID->1449927556,ExpressionUUID->"88e52a43-a32b-4bef-918c-42ca6e6b2603"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", "1.962`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"4c2b54cf-465d-4435-b1c4-968e47932f4f"],
 ", (dielectric constant of the solvent) "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9, 3.8472703742234573`*^9},
 CellID->1435491183,ExpressionUUID->"7d98ea50-05d1-43da-a7a3-c51f74839f3a"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1.4029`"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"d28c1571-adda-4e59-96bb-5f5b00ce2552"],
 ", (refractive index of solvent)"
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}, 3.8456343931577096`*^9, 3.845643077221505*^9, {
   3.845643163726302*^9, 3.845643183830635*^9}, 3.845650847212322*^9, {
   3.845651311498663*^9, 3.845651355392065*^9}, {3.8456513932083807`*^9, 
   3.8456514187064657`*^9}, {3.8456518398059673`*^9, 
   3.8456518702754107`*^9}, {3.8460828364635563`*^9, 
   3.8460828428932285`*^9}, {3.8460829078268776`*^9, 
   3.8460829489435015`*^9}, {3.8460878406336594`*^9, 3.846087841756708*^9}, {
   3.846087895807024*^9, 3.846087898094274*^9}, {3.8467815505396338`*^9, 
   3.846781590704651*^9}, {3.846781624198618*^9, 3.8467816414905767`*^9}, 
   3.846781998135685*^9},
 CellID->1469022283,ExpressionUUID->"cedc3377-74cf-4447-96fc-101309895840"],

Cell[TextData[{
 "The parameter ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4332105f-b2ee-409f-84d0-5d49d51f6153"],
 " is in the summation factor, determining how many transfer channels \
contribute to the total rate [3]. Often only six channels are needed. \
Additional information on Marcus theory and electron transfer is given in [6\
\[Dash]9]. If ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "e5421c9f-b718-4538-b487-e213e6a80a16"],
 ", the equation behaves like the classical Marcus equation."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, {3.846516170041276*^9, 
   3.846516170041813*^9}, {3.846781570520352*^9, 3.8467815710250607`*^9}, {
   3.846836863596624*^9, 3.846836926828796*^9}, {3.8468372540074053`*^9, 
   3.846837296175107*^9}, {3.8472706284772387`*^9, 3.847270669924466*^9}, 
   3.8472758330336*^9, {3.847287338138557*^9, 3.847287341431747*^9}, {
   3.84728737536414*^9, 3.847287422893031*^9}},
 CellID->518981415,ExpressionUUID->"d5a6d1d8-eef8-42c6-b890-2e5901687fb0"],

Cell["\<\
This Demonstration displays a three-dimensional representation of the \
semiclassical Marcus model, also called the Marcus\[Dash]Levich\[Dash]Jortner \
theory. The starting values are from the Closs and Miller data, the first \
proof of the inverted region. Other aspects are defined in the interface.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845195381759646*^9, 3.8451953833280582`*^9}, {
   3.845237776133129*^9, 3.845237788620431*^9}, {3.845283324933991*^9, 
   3.845283339427322*^9}, {3.846782019665265*^9, 3.846782063263453*^9}, 
   3.846836848084881*^9, {3.847270685832554*^9, 3.8472707038450203`*^9}, {
   3.8472874343364058`*^9, 3.847287453868804*^9}, {3.84773666395604*^9, 
   3.847736671920457*^9}, {3.847813026578966*^9, 3.847813026985999*^9}},
 CellID->2099753569,ExpressionUUID->"9d52a3da-e3b2-42a9-b11d-926b777005e5"],

Cell[TextData[{
 "The Marcus\[Dash]Levich\[Dash]Jortner (MLJ) theory is especially evident in \
the inverted region. As the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[VeryThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"3e81c2b1-27fc-4501-b93d-4370c543a566"],
 " approaches twice the total ",
 Cell[BoxData[
  FormBox["\[Lambda]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "27f26f78-db8f-48a5-a5d3-fbac4b170fd7"],
 ", inverted region effects start playing a more important role. Also, at \
lower temperatures, MLJ becomes a better approximation. But for very low \
temperatures, there are modified equations (see below). For very low \
temperature, both vibrations should be treated quantum mechanically."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790005848209*^9, 3.8467900058487377`*^9}, 3.84679027580014*^9, {
   3.846839647204831*^9, 3.8468396806757727`*^9}, {3.846839798904573*^9, 
   3.846839810539515*^9}, {3.846839901210908*^9, 3.8468399080501013`*^9}, {
   3.846840048488785*^9, 3.846840067044415*^9}, {3.846853742305655*^9, 
   3.8468538150377493`*^9}, {3.8468538894769497`*^9, 3.846853942444229*^9}, {
   3.8468540715246162`*^9, 3.846854109998088*^9}, {3.8469614668652897`*^9, 
   3.846961509057637*^9}, {3.847270722499433*^9, 3.847270739442436*^9}, {
   3.8472728067060843`*^9, 3.84727284279218*^9}, {3.8472874673973*^9, 
   3.847287495961132*^9}, {3.8472875269860287`*^9, 3.847287585613677*^9}, {
   3.847736681364997*^9, 3.847736712479465*^9}, {3.847813039274561*^9, 
   3.84781305749084*^9}},
 CellID->1984520843,ExpressionUUID->"df2b2b45-37a3-4ef5-bbb9-4c820ef99ba4"],

Cell[TextData[{
 "As for validity of the model, the (single mode) MLJ theory can be applied: \
above ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"~", "77"}], " ", 
    StyleBox["K",
     FontSlant->"Plain"]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "cf5e88be-83b0-4f87-863b-e1fa28c42bc5"],
 ", with the electronic coupling between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"~", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "5337a27b-9e6b-4fad-b16a-69735a84f9fd"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"~", "200"}], " ", 
    SuperscriptBox["cm", 
     RowBox[{"-", "1"}]]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "6e36eda6-dcba-4ed6-8eaf-e9c795cf7071"],
 "; in polar liquids, with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "\[TildeTilde]", 
    RowBox[{"1", "\[Minus]", 
     RowBox[{"10", " ", 
      SuperscriptBox["cm", 
       RowBox[{"-", "1"}]]}]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"9c15ed2f-c41b-45ff-8d19-592fe640d190"],
 "; and in molecular solids, with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "\[TildeTilde]", 
    RowBox[{"10", "\[Minus]", 
     RowBox[{"100", " ", 
      SuperscriptBox["cm", 
       RowBox[{"-", "1"}]]}]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"fac6cff9-935d-477f-aaa7-f883854ee776"],
 " (pertaining to both intermolecular phonons and solid matrix phonons with \
energies of 0.00124 to 0.0124 eV). Intramolecular frequencies ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "i"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"c2c4883f-23e2-4097-a639-96d1e9226445"],
 " can range between 300 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"~", "3000"}], " ", 
    SuperscriptBox["cm", 
     RowBox[{"-", "1"}]]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "99a77eac-0c1d-491b-ac84-72f8ed0619b3"],
 " (0.0372 and 0.372 eV). It is also possible to apply the multi-mode MLJ \
equation [2]."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790005848209*^9, 3.8467900058487377`*^9}, 3.84679027580014*^9, {
   3.846839647204831*^9, 3.8468396806757727`*^9}, {3.846839798904573*^9, 
   3.846839810539515*^9}, {3.846839901210908*^9, 3.8468399080501013`*^9}, {
   3.846840048488785*^9, 3.846840067044415*^9}, {3.846853742305655*^9, 
   3.8468538150377493`*^9}, {3.8468538894769497`*^9, 3.846853942444229*^9}, {
   3.8468540715246162`*^9, 3.846854109998088*^9}, {3.8469614668652897`*^9, 
   3.846961509057637*^9}, {3.847270722499433*^9, 3.8472707228370457`*^9}, {
   3.847272852907186*^9, 3.847272978207086*^9}, 3.8472758348209877`*^9, {
   3.8472876100485697`*^9, 3.847287675692894*^9}, {3.847815476905635*^9, 
   3.847815557976499*^9}, {3.847815592156322*^9, 3.8478155996180773`*^9}, 
   3.847817830166855*^9},
 CellID->706452211,ExpressionUUID->"2eca3962-f99b-4722-ab84-99085fbbb40a"],

Cell["\<\
Thus, in the MLJ theory the internal lambda is treated quantum mechanically. \
The solvent reorganization is treated classically.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790005848209*^9, 3.8467900058487377`*^9}, 3.84679027580014*^9, {
   3.846839647204831*^9, 3.8468396806757727`*^9}, {3.846839798904573*^9, 
   3.846839810539515*^9}, {3.846839901210908*^9, 3.8468399080501013`*^9}, {
   3.846840048488785*^9, 3.846840067044415*^9}, {3.846853742305655*^9, 
   3.8468538150377493`*^9}, {3.8468538894769497`*^9, 3.846853942444229*^9}, {
   3.8468540715246162`*^9, 3.846854109998088*^9}, {3.8469614668652897`*^9, 
   3.846961509057637*^9}, {3.847270722499433*^9, 3.8472707228370457`*^9}, {
   3.847272852907186*^9, 3.847272999389509*^9}, {3.847273402426309*^9, 
   3.8472734822662363`*^9}, 3.847275836159399*^9, {3.847287703787074*^9, 
   3.8472878100856*^9}, {3.847287845077886*^9, 3.84728784976579*^9}, {
   3.8477367411540117`*^9, 3.8477367484416847`*^9}, {3.8478132713490973`*^9, 
   3.847813273269437*^9}},
 CellID->1876928042,ExpressionUUID->"7488cedd-cc52-4261-8348-7586ae28dc42"],

Cell[TextData[{
 "In the intermediate temperature range, the most common one, the solvent \
(environmental) vibrational modes can be treated classically ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[HBar]", " ", 
     SubscriptBox["\[Omega]", "s"]}], "\[LessLess]", 
    RowBox[{
     SubscriptBox["k", 
      StyleBox["B",
       FontSlant->"Plain"]], "T"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"fa5f95e9-542b-4b10-9ec8-44183d5df974"],
 ", where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", 
    StyleBox["S",
     FontSlant->"Plain"]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "cb665e4a-22e8-4b3f-b027-d258fdb9ce9d"],
 " is an average solvent vibrational frequency. The intramolecular vibrations \
are quantum, that is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[HBar]", " ", "\[Omega]"}], ">", 
    RowBox[{
     SubscriptBox["k", 
      StyleBox["B",
       FontSlant->"Plain"]], "T"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"9d25f42d-6085-4918-abbb-2d9106f89e28"],
 ". "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790005848209*^9, 3.8467900058487377`*^9}, 3.84679027580014*^9, {
   3.846839647204831*^9, 3.8468396806757727`*^9}, {3.846839798904573*^9, 
   3.846839810539515*^9}, {3.846839901210908*^9, 3.8468399080501013`*^9}, {
   3.846840048488785*^9, 3.846840067044415*^9}, {3.846853742305655*^9, 
   3.8468538150377493`*^9}, {3.8468538894769497`*^9, 3.846853942444229*^9}, {
   3.8468540715246162`*^9, 3.846854109998088*^9}, {3.8469614668652897`*^9, 
   3.846961509057637*^9}, {3.847270722499433*^9, 3.8472707228370457`*^9}, {
   3.847272852907186*^9, 3.847272999389509*^9}, {3.847273402426309*^9, 
   3.8472734822662363`*^9}, 3.847275836159399*^9, {3.847287703787074*^9, 
   3.8472878100856*^9}, {3.847287845077886*^9, 3.84728784976579*^9}, {
   3.8477367411540117`*^9, 3.847736741346869*^9}},
 CellID->684979579,ExpressionUUID->"3f5dcdea-89e4-4c18-bcb9-66b987e0aa0a"],

Cell[TextData[{
 "In general, a vibration ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "d55ab4f0-a04d-4f08-99bb-9cb98cbd1539"],
 " can be treated as classical if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[HBar]", " ", "\[Omega]"}], "\[LessLess]", 
    RowBox[{
     SubscriptBox["k", 
      StyleBox["B",
       FontSlant->"Plain"]], "T"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"25454d3c-9612-4dbf-a341-52c0f614336c"],
 "; it should be treated as quantum if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[HBar]", " ", "\[Omega]"}], "\[GreaterGreater]", 
    RowBox[{
     SubscriptBox["k", 
      StyleBox["B",
       FontSlant->"Plain"]], "T"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"15ae607a-65e9-4e62-8170-f6ff2b8da174"],
 ". If you look at temperature effects, you have to monitor these values \
(given in the text above in eV) relative to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", 
     StyleBox["B",
      FontSlant->"Plain"]], "T"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a63de807-3f33-4f4f-bc0a-ee7cf1ffaa74"],
 " (presented as output). "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790005848209*^9, 3.8467900058487377`*^9}, 3.84679027580014*^9, {
   3.846839647204831*^9, 3.8468396806757727`*^9}, {3.846839798904573*^9, 
   3.846839810539515*^9}, {3.846839901210908*^9, 3.8468399080501013`*^9}, {
   3.846840048488785*^9, 3.846840067044415*^9}, {3.846853742305655*^9, 
   3.8468538150377493`*^9}, {3.8468538894769497`*^9, 3.846853958049121*^9}, {
   3.847273485036415*^9, 3.8472735616195087`*^9}, {3.847287817854021*^9, 
   3.847287898298438*^9}, {3.847813292710085*^9, 3.847813296605742*^9}},
 CellID->1634122492,ExpressionUUID->"d8947084-f777-48d9-b6b6-ec8075eb92b2"],

Cell["\<\
By adjusting the parameters, a resonance effect between the internal \
reorganization energy and the vibration that mediates the transfer can be \
observed, enhancing the rate at certain values (the sharp spikes at low \
solvent reorganization); it is not clear if this is an artifact of the \
theory. There seems to be no experimental evidence of this effect. \
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790015154175*^9, 3.846790110384144*^9}, {3.846839863496978*^9, 
   3.846839896001359*^9}, {3.846839930000066*^9, 3.846840003261065*^9}, {
   3.8468540008598957`*^9, 3.846854016778407*^9}, {3.8468541817122517`*^9, 
   3.8468542242249517`*^9}, {3.8472735666552773`*^9, 3.847273598706922*^9}, {
   3.847813306237805*^9, 3.847813341094613*^9}},
 CellID->1435578743,ExpressionUUID->"5c4d49bf-a139-453d-a389-493fb7750ff3"],

Cell[TextData[{
 "More information on these oscillations at low reorganization energies and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[VeryThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"923da669-cff8-4908-b1e7-811a8c6d189a"],
 " are available. Papers that report oscillations in the Bell-shaped Marcus \
curve (resonance type effects in the Franck\[Dash]Condon factor) are given \
[12\[Dash]17]."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790015154175*^9, 3.846790153450021*^9}, {3.8467902130411987`*^9, 
   3.846790213225442*^9}, {3.846790486450453*^9, 3.846790526210496*^9}, {
   3.846790566228228*^9, 3.8467905869491568`*^9}, 3.84696162430149*^9, {
   3.846961702986985*^9, 3.846961702987028*^9}, {3.84727360528817*^9, 
   3.847273625231743*^9}, {3.847736782097896*^9, 3.847736787624984*^9}, {
   3.847813356566185*^9, 3.847813357022653*^9}},
 CellID->839004015,ExpressionUUID->"ff16f5b5-55f8-4380-9ec1-542f53f71223"],

Cell["Below 10 K, more complex models are needed [18, 19]. ", \
"ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}, {
   3.8454863804521637`*^9, 3.845486381947442*^9}, {3.845487121395792*^9, 
   3.8454871741573687`*^9}, {3.845488334944723*^9, 3.845488339943221*^9}, {
   3.845490274571213*^9, 3.8454902847204103`*^9}, {3.8455254341930323`*^9, 
   3.8455254377276506`*^9}, {3.845529167545906*^9, 3.845529169538702*^9}, {
   3.84564321036849*^9, 3.8456432107231417`*^9}, {3.845651434471383*^9, 
   3.84565155284729*^9}, {3.8456515916575937`*^9, 3.8456516058125763`*^9}, {
   3.846083129498926*^9, 3.8460831554832935`*^9}, 3.846516171245131*^9, {
   3.846781696967177*^9, 3.846781698390328*^9}, {3.846781821754766*^9, 
   3.8467818937985764`*^9}, {3.846782202479074*^9, 3.846782206550593*^9}, {
   3.846790015154175*^9, 3.846790219257523*^9}, {3.84679068881178*^9, 
   3.8467907115304537`*^9}, 3.846839829800129*^9, {3.846961587273263*^9, 
   3.846961590936306*^9}, {3.847273631164061*^9, 3.847273633582815*^9}, {
   3.847287942570385*^9, 3.847287962060957*^9}, {3.847288984488842*^9, 
   3.847288985323079*^9}, {3.847736800686268*^9, 3.847736803987314*^9}, 
   3.847813365598525*^9},
 CellID->1152165796,ExpressionUUID->"7a312828-7d2a-4443-b12b-e00caa09c182"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Thumbnail",
 Cell[BoxData[
  TemplateBox[{"Thumbnail",Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "To create the thumbnail, copy and paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section and adjust the controls to the most visually appealing \
setting. Do not convert it to a bitmap. The thumbnail is what visitors see \
when browsing the Demonstrations site and while the Flash preview loads.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "5363174b-397a-4e31-b8e5-95e1af887bc9"]
}], "ThumbnailSection",
 CellTags->"Thumbnail",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 
    10, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
    0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
    8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0255072977768, $CellContext`LambdaI$$ = 
    0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 296, $CellContext`V$$ = 
    6, $CellContext`vib$$ = 1500, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 5000, 0.1}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 1000, 0.1}, {{
       Hold[$CellContext`T$$], 296, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`n$$], 5, ""}, 0, 50, 1}, {{
       Hold[$CellContext`a$$], 10, ""}, 6, 18}, {{
       Hold[$CellContext`b$$], -2.5, ""}, -0.1, -5}, {{
       Hold[$CellContext`c$$], 0.1, ""}, 0, 5}, {{
       Hold[$CellContext`e$$], 0.75, ""}, 0.0001, 5}, {{
       Hold[$CellContext`f$$], 20, ""}, 20, 120, 1}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "Huang\[Dash]Rhys, S ="}}, {{
       Hold[$CellContext`KbT$$], 0.0255072977768, 
       Row[{
         Subscript[
          Style["k", Italic], "B"], 
         Style["T", Italic], " (eV)"}]}}, {
      Hold[
       Column[{
        "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
         Manipulate`Place[1], 
         "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[2], 
         Row[{"electronic coupling, ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[3], 
         Row[{"temperature, ", 
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         Row[{"summation factor ", 
           Style["m", Italic]}], 
         Manipulate`Place[5], 
         Row[{
           Style["a", Italic], " (axis, log ", 
           Style["z", Italic], " maximum (log ", 
           Style["k", Italic], "))"}], 
         Manipulate`Place[6], 
         Row[{
           Style["b", Italic], " (axis, ", 
           Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
         Manipulate`Place[7], 
         Row[{
           Style["c", Italic], " (axis, ", 
           Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
         Manipulate`Place[8], 
         Row[{
           Style["e", Italic], " (axis, ", 
           Style["y", Italic], 
           " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
         Manipulate`Place[9], 
         Row[{
           Style["f", Italic], " (number of points to plot (graph))"}], 
         Manipulate`Place[10], "", "", 
         Manipulate`Place[11], 
         Manipulate`Place[12]}, Alignment -> Left, 
        Dividers -> {{True}, {
          True, False, True, False, True, False, True, False, True, False, 
           True, False, True, False, True, False, True, False, True, False, 
           True, False, True, True, True}}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Spacer[140]], Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    420., {208., 212.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`LambdaI$2733$$ = 
    0, $CellContext`vib$2734$$ = 0, $CellContext`V$2735$$ = 
    0, $CellContext`T$2736$$ = 0, $CellContext`n$2737$$ = 
    0, $CellContext`a$2738$$ = 0, $CellContext`b$2739$$ = 
    0, $CellContext`c$2740$$ = 0, $CellContext`e$2741$$ = 
    0, $CellContext`f$2742$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 
        10, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
        0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0255072977768, $CellContext`LambdaI$$ = 
        0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 296, $CellContext`V$$ = 
        6, $CellContext`vib$$ = 1500}, "ControllerVariables" :> {
        Hold[$CellContext`LambdaI$$, $CellContext`LambdaI$2733$$, 0], 
        Hold[$CellContext`vib$$, $CellContext`vib$2734$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$2735$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$2736$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$2737$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$2738$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2739$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2740$$, 0], 
        Hold[$CellContext`e$$, $CellContext`e$2741$$, 0], 
        Hold[$CellContext`f$$, $CellContext`f$2742$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Plot3D[$CellContext`z = (((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`y) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
             0.000123985^2)) $CellContext`V$$^2) 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`x + $CellContext`y + $CellContext`m (
                   0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`y) $CellContext`T$$))), \
{$CellContext`m, 
             0, $CellContext`n$$}], {$CellContext`x, $CellContext`b$$, \
$CellContext`c$$}, {$CellContext`y, 0, $CellContext`e$$}, 
         PlotRange -> {0, 10^$CellContext`a$$}, 
         PlotPoints -> {$CellContext`f$$}, AxesLabel -> {
           Row[{"\[CapitalDelta]G", " (eV)"}], 
           Row[{
             Subscript["\[Lambda]", "S"], " (eV)"}], 
           Row[{"rate (", 
             Superscript["s", "-1"], ")"}]}, ImageSize -> {420, 420}, Mesh -> 
         False, MaxRecursion -> 1, ViewPoint -> {-1, 2, 0.6}]], 
      "Specifications" :> {{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`vib$$, 1500, ""}, 4, 5000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`V$$, 6, ""}, 0.005, 1000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 296, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`n$$, 5, ""}, 0, 50, 1, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`a$$, 10, ""}, 6, 18, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`b$$, -2.5, ""}, -0.1, -5, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`c$$, 0.1, ""}, 0, 5, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`e$$, 0.75, ""}, 0.0001, 5, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`f$$, 20, ""}, 20, 120, 1, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         10}, {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "Huang\[Dash]Rhys, S ="}, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 11}, {{$CellContext`KbT$$, 0.0255072977768, 
          Row[{
            Subscript[
             Style["k", Italic], "B"], 
            Style["T", Italic], " (eV)"}]}, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 12}, 
        Column[{
         "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
          Manipulate`Place[1], 
          "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[2], 
          Row[{"electronic coupling, ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[3], 
          Row[{"temperature, ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          Row[{"summation factor ", 
            Style["m", Italic]}], 
          Manipulate`Place[5], 
          Row[{
            Style["a", Italic], " (axis, log ", 
            Style["z", Italic], " maximum (log ", 
            Style["k", Italic], "))"}], 
          Manipulate`Place[6], 
          Row[{
            Style["b", Italic], " (axis, ", 
            Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
          Manipulate`Place[7], 
          Row[{
            Style["c", Italic], " (axis, ", 
            Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
          Manipulate`Place[8], 
          Row[{
            Style["e", Italic], " (axis, ", 
            Style["y", Italic], 
            " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
          Manipulate`Place[9], 
          Row[{
            Style["f", Italic], " (number of points to plot (graph))"}], 
          Manipulate`Place[10], "", "", 
          Manipulate`Place[11], 
          Manipulate`Place[12]}, Alignment -> Left, 
         Dividers -> {{True}, {
           True, False, True, False, True, False, True, False, True, False, 
            True, False, True, False, True, False, True, False, True, False, 
            True, False, True, True, True}}], 
        Spacer[140]}, 
      "Options" :> {
       ContinuousAction -> False, AutorunSequencing -> {2}, ControlPlacement -> 
        Left}, "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{623., {236., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`z = 1.3100334655397701`*^10, 
       Attributes[Subscript] = {NHoldRest}, 
       Attributes[Superscript] = {NHoldRest, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->1048159982,ExpressionUUID->"b01534b0-10aa-421a-8705-9d837d919474"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Snapshots",
 Cell[BoxData[
  TemplateBox[{"Snapshots", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"To create snapshots, paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section in this section at least three times, and adjust the \
controls of each copy to show a range of interesting settings. Do not convert \
the screenshots to bitmaps. Optional captions for the screenshots may be \
included in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d854de0f-efbb-449a-8b04-a7b3ca5773d5"]
}], "SnapshotsSection",
 CellTags->"Snapshots",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 
    10.2, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
    0.1, $CellContext`f$$ = 40, $CellContext`HR$$ = 
    8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 
    0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
    0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 200, $CellContext`V$$ = 
    6, $CellContext`vib$$ = 1500, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 5000, 0.1}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 1000, 0.1}, {{
       Hold[$CellContext`T$$], 200, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`n$$], 5, ""}, 0, 50, 1}, {{
       Hold[$CellContext`a$$], 10.2, ""}, 6, 18}, {{
       Hold[$CellContext`b$$], -2.5, ""}, -0.1, -5}, {{
       Hold[$CellContext`c$$], 0.1, ""}, 0, 5}, {{
       Hold[$CellContext`e$$], 0.1, ""}, 0.0001, 5}, {{
       Hold[$CellContext`f$$], 40, ""}, 20, 120, 1}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "Huang\[Dash]Rhys, S ="}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       Row[{
         Subscript[
          Style["k", Italic], "B"], 
         Style["T", Italic], " (eV)"}]}}, {
      Hold[
       Column[{
        "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
         Manipulate`Place[1], 
         "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[2], 
         Row[{"electronic coupling, ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[3], 
         Row[{"temperature, ", 
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         Row[{"summation factor ", 
           Style["m", Italic]}], 
         Manipulate`Place[5], 
         Row[{
           Style["a", Italic], " (axis, log ", 
           Style["z", Italic], " maximum (log ", 
           Style["k", Italic], "))"}], 
         Manipulate`Place[6], 
         Row[{
           Style["b", Italic], " (axis, ", 
           Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
         Manipulate`Place[7], 
         Row[{
           Style["c", Italic], " (axis, ", 
           Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
         Manipulate`Place[8], 
         Row[{
           Style["e", Italic], " (axis, ", 
           Style["y", Italic], 
           " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
         Manipulate`Place[9], 
         Row[{
           Style["f", Italic], " (number of points to plot (graph))"}], 
         Manipulate`Place[10], "", "", 
         Manipulate`Place[11], 
         Manipulate`Place[12]}, Alignment -> Left, 
        Dividers -> {{True}, {
          True, False, True, False, True, False, True, False, True, False, 
           True, False, True, False, True, False, True, False, True, False, 
           True, False, True, True, True}}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Spacer[140]], Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    420., {208., 212.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`LambdaI$2782$$ = 
    0, $CellContext`vib$2783$$ = 0, $CellContext`V$2784$$ = 
    0, $CellContext`T$2785$$ = 0, $CellContext`n$2786$$ = 
    0, $CellContext`a$2787$$ = 0, $CellContext`b$2788$$ = 
    0, $CellContext`c$2789$$ = 0, $CellContext`e$2790$$ = 
    0, $CellContext`f$2791$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 
        10.2, $CellContext`b$$ = -2.5, $CellContext`c$$ = 
        0.1, $CellContext`e$$ = 0.1, $CellContext`f$$ = 40, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
        0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 200, $CellContext`V$$ = 
        6, $CellContext`vib$$ = 1500}, "ControllerVariables" :> {
        Hold[$CellContext`LambdaI$$, $CellContext`LambdaI$2782$$, 0], 
        Hold[$CellContext`vib$$, $CellContext`vib$2783$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$2784$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$2785$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$2786$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$2787$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2788$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2789$$, 0], 
        Hold[$CellContext`e$$, $CellContext`e$2790$$, 0], 
        Hold[$CellContext`f$$, $CellContext`f$2791$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Plot3D[$CellContext`z = (((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`y) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
             0.000123985^2)) $CellContext`V$$^2) 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`x + $CellContext`y + $CellContext`m (
                   0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`y) $CellContext`T$$))), \
{$CellContext`m, 
             0, $CellContext`n$$}], {$CellContext`x, $CellContext`b$$, \
$CellContext`c$$}, {$CellContext`y, 0, $CellContext`e$$}, 
         PlotRange -> {0, 10^$CellContext`a$$}, 
         PlotPoints -> {$CellContext`f$$}, AxesLabel -> {
           Row[{"\[CapitalDelta]G", " (eV)"}], 
           Row[{
             Subscript["\[Lambda]", "S"], " (eV)"}], 
           Row[{"rate (", 
             Superscript["s", "-1"], ")"}]}, ImageSize -> {420, 420}, Mesh -> 
         False, MaxRecursion -> 1, ViewPoint -> {-1, 2, 0.6}]], 
      "Specifications" :> {{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`vib$$, 1500, ""}, 4, 5000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`V$$, 6, ""}, 0.005, 1000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 200, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`n$$, 5, ""}, 0, 50, 1, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`a$$, 10.2, ""}, 6, 18, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`b$$, -2.5, ""}, -0.1, -5, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`c$$, 0.1, ""}, 0, 5, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`e$$, 0.1, ""}, 0.0001, 5, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`f$$, 40, ""}, 20, 120, 1, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         10}, {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "Huang\[Dash]Rhys, S ="}, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         11}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          Row[{
            Subscript[
             Style["k", Italic], "B"], 
            Style["T", Italic], " (eV)"}]}, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 12}, 
        Column[{
         "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
          Manipulate`Place[1], 
          "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[2], 
          Row[{"electronic coupling, ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[3], 
          Row[{"temperature, ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          Row[{"summation factor ", 
            Style["m", Italic]}], 
          Manipulate`Place[5], 
          Row[{
            Style["a", Italic], " (axis, log ", 
            Style["z", Italic], " maximum (log ", 
            Style["k", Italic], "))"}], 
          Manipulate`Place[6], 
          Row[{
            Style["b", Italic], " (axis, ", 
            Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
          Manipulate`Place[7], 
          Row[{
            Style["c", Italic], " (axis, ", 
            Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
          Manipulate`Place[8], 
          Row[{
            Style["e", Italic], " (axis, ", 
            Style["y", Italic], 
            " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
          Manipulate`Place[9], 
          Row[{
            Style["f", Italic], " (number of points to plot (graph))"}], 
          Manipulate`Place[10], "", "", 
          Manipulate`Place[11], 
          Manipulate`Place[12]}, Alignment -> Left, 
         Dividers -> {{True}, {
           True, False, True, False, True, False, True, False, True, False, 
            True, False, True, False, True, False, True, False, True, False, 
            True, False, True, True, True}}], 
        Spacer[140]}, 
      "Options" :> {
       ContinuousAction -> False, AutorunSequencing -> {2}, ControlPlacement -> 
        Left}, "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{623., {236., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`z = 1.3100334655397701`*^10, 
       Attributes[Subscript] = {NHoldRest}, 
       Attributes[Superscript] = {NHoldRest, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->616461133,ExpressionUUID->"a0678903-4dc6-4fd2-8f33-7d52b86408f5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 
    10, $CellContext`b$$ = -1.2, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
    0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
    8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 
    0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
    0.3, $CellContext`n$$ = 0, $CellContext`T$$ = 296, $CellContext`V$$ = 
    6, $CellContext`vib$$ = 1500, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 5000, 0.1}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 1000, 0.1}, {{
       Hold[$CellContext`T$$], 296, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`n$$], 0, ""}, 0, 50, 1}, {{
       Hold[$CellContext`a$$], 10, ""}, 6, 18}, {{
       Hold[$CellContext`b$$], -1.2, ""}, -0.1, -5}, {{
       Hold[$CellContext`c$$], 0.1, ""}, 0, 5}, {{
       Hold[$CellContext`e$$], 0.75, ""}, 0.0001, 5}, {{
       Hold[$CellContext`f$$], 20, ""}, 20, 120, 1}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "Huang\[Dash]Rhys, S ="}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       Row[{
         Subscript[
          Style["k", Italic], "B"], 
         Style["T", Italic], " (eV)"}]}}, {
      Hold[
       Column[{
        "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
         Manipulate`Place[1], 
         "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[2], 
         Row[{"electronic coupling, ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[3], 
         Row[{"temperature, ", 
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         Row[{"summation factor ", 
           Style["m", Italic]}], 
         Manipulate`Place[5], 
         Row[{
           Style["a", Italic], " (axis, log ", 
           Style["z", Italic], " maximum (log ", 
           Style["k", Italic], "))"}], 
         Manipulate`Place[6], 
         Row[{
           Style["b", Italic], " (axis, ", 
           Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
         Manipulate`Place[7], 
         Row[{
           Style["c", Italic], " (axis, ", 
           Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
         Manipulate`Place[8], 
         Row[{
           Style["e", Italic], " (axis, ", 
           Style["y", Italic], 
           " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
         Manipulate`Place[9], 
         Row[{
           Style["f", Italic], " (number of points to plot (graph))"}], 
         Manipulate`Place[10], "", "", 
         Manipulate`Place[11], 
         Manipulate`Place[12]}, Alignment -> Left, 
        Dividers -> {{True}, {
          True, False, True, False, True, False, True, False, True, False, 
           True, False, True, False, True, False, True, False, True, False, 
           True, False, True, True, True}}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Spacer[140]], Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    420., {208., 212.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`LambdaI$2831$$ = 
    0, $CellContext`vib$2832$$ = 0, $CellContext`V$2833$$ = 
    0, $CellContext`T$2834$$ = 0, $CellContext`n$2835$$ = 
    0, $CellContext`a$2836$$ = 0, $CellContext`b$2837$$ = 
    0, $CellContext`c$2838$$ = 0, $CellContext`e$2839$$ = 
    0, $CellContext`f$2840$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 
        10, $CellContext`b$$ = -1.2, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
        0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
        0.3, $CellContext`n$$ = 0, $CellContext`T$$ = 296, $CellContext`V$$ = 
        6, $CellContext`vib$$ = 1500}, "ControllerVariables" :> {
        Hold[$CellContext`LambdaI$$, $CellContext`LambdaI$2831$$, 0], 
        Hold[$CellContext`vib$$, $CellContext`vib$2832$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$2833$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$2834$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$2835$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$2836$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2837$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2838$$, 0], 
        Hold[$CellContext`e$$, $CellContext`e$2839$$, 0], 
        Hold[$CellContext`f$$, $CellContext`f$2840$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Plot3D[$CellContext`z = (((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`y) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
             0.000123985^2)) $CellContext`V$$^2) 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`x + $CellContext`y + $CellContext`m (
                   0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`y) $CellContext`T$$))), \
{$CellContext`m, 
             0, $CellContext`n$$}], {$CellContext`x, $CellContext`b$$, \
$CellContext`c$$}, {$CellContext`y, 0, $CellContext`e$$}, 
         PlotRange -> {0, 10^$CellContext`a$$}, 
         PlotPoints -> {$CellContext`f$$}, AxesLabel -> {
           Row[{"\[CapitalDelta]G", " (eV)"}], 
           Row[{
             Subscript["\[Lambda]", "S"], " (eV)"}], 
           Row[{"rate (", 
             Superscript["s", "-1"], ")"}]}, ImageSize -> {420, 420}, Mesh -> 
         False, MaxRecursion -> 1, ViewPoint -> {-1, 2, 0.6}]], 
      "Specifications" :> {{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`vib$$, 1500, ""}, 4, 5000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`V$$, 6, ""}, 0.005, 1000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 296, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`n$$, 0, ""}, 0, 50, 1, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`a$$, 10, ""}, 6, 18, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`b$$, -1.2, ""}, -0.1, -5, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`c$$, 0.1, ""}, 0, 5, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`e$$, 0.75, ""}, 0.0001, 5, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`f$$, 20, ""}, 20, 120, 1, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         10}, {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "Huang\[Dash]Rhys, S ="}, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         11}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          Row[{
            Subscript[
             Style["k", Italic], "B"], 
            Style["T", Italic], " (eV)"}]}, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 12}, 
        Column[{
         "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
          Manipulate`Place[1], 
          "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[2], 
          Row[{"electronic coupling, ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[3], 
          Row[{"temperature, ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          Row[{"summation factor ", 
            Style["m", Italic]}], 
          Manipulate`Place[5], 
          Row[{
            Style["a", Italic], " (axis, log ", 
            Style["z", Italic], " maximum (log ", 
            Style["k", Italic], "))"}], 
          Manipulate`Place[6], 
          Row[{
            Style["b", Italic], " (axis, ", 
            Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
          Manipulate`Place[7], 
          Row[{
            Style["c", Italic], " (axis, ", 
            Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
          Manipulate`Place[8], 
          Row[{
            Style["e", Italic], " (axis, ", 
            Style["y", Italic], 
            " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
          Manipulate`Place[9], 
          Row[{
            Style["f", Italic], " (number of points to plot (graph))"}], 
          Manipulate`Place[10], "", "", 
          Manipulate`Place[11], 
          Manipulate`Place[12]}, Alignment -> Left, 
         Dividers -> {{True}, {
           True, False, True, False, True, False, True, False, True, False, 
            True, False, True, False, True, False, True, False, True, False, 
            True, False, True, True, True}}], 
        Spacer[140]}, 
      "Options" :> {
       ContinuousAction -> False, AutorunSequencing -> {2}, ControlPlacement -> 
        Left}, "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{623., {236., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`z = 1.3100334655397701`*^10, 
       Attributes[Subscript] = {NHoldRest}, 
       Attributes[Superscript] = {NHoldRest, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->1401149203,ExpressionUUID->"4aa7ff42-5f1b-4f0e-9ae0-52741b6aada9"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 
    10, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
    0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
    8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 
    0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
    0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 1000, $CellContext`V$$ = 
    6, $CellContext`vib$$ = 1500, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {{
       Hold[$CellContext`vib$$], 1500, ""}, 4, 5000, 0.1}, {{
       Hold[$CellContext`V$$], 6, ""}, 0.005, 1000, 0.1}, {{
       Hold[$CellContext`T$$], 1000, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`n$$], 5, ""}, 0, 50, 1}, {{
       Hold[$CellContext`a$$], 10, ""}, 6, 18}, {{
       Hold[$CellContext`b$$], -2.5, ""}, -0.1, -5}, {{
       Hold[$CellContext`c$$], 0.1, ""}, 0, 5}, {{
       Hold[$CellContext`e$$], 0.75, ""}, 0.0001, 5}, {{
       Hold[$CellContext`f$$], 20, ""}, 20, 120, 1}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "Huang\[Dash]Rhys, S ="}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       Row[{
         Subscript[
          Style["k", Italic], "B"], 
         Style["T", Italic], " (eV)"}]}}, {
      Hold[
       Column[{
        "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
         Manipulate`Place[1], 
         "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
         Manipulate`Place[2], 
         Row[{"electronic coupling, ", 
           Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
         Manipulate`Place[3], 
         Row[{"temperature, ", 
           Style["T", Italic], " (K)"}], 
         Manipulate`Place[4], 
         Row[{"summation factor ", 
           Style["m", Italic]}], 
         Manipulate`Place[5], 
         Row[{
           Style["a", Italic], " (axis, log ", 
           Style["z", Italic], " maximum (log ", 
           Style["k", Italic], "))"}], 
         Manipulate`Place[6], 
         Row[{
           Style["b", Italic], " (axis, ", 
           Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
         Manipulate`Place[7], 
         Row[{
           Style["c", Italic], " (axis, ", 
           Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
         Manipulate`Place[8], 
         Row[{
           Style["e", Italic], " (axis, ", 
           Style["y", Italic], 
           " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
         Manipulate`Place[9], 
         Row[{
           Style["f", Italic], " (number of points to plot (graph))"}], 
         Manipulate`Place[10], "", "", 
         Manipulate`Place[11], 
         Manipulate`Place[12]}, Alignment -> Left, 
        Dividers -> {{True}, {
          True, False, True, False, True, False, True, False, True, False, 
           True, False, True, False, True, False, True, False, True, False, 
           True, False, True, True, True}}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Spacer[140]], Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    420., {208., 212.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`LambdaI$2884$$ = 
    0, $CellContext`vib$2885$$ = 0, $CellContext`V$2886$$ = 
    0, $CellContext`T$2887$$ = 0, $CellContext`n$2888$$ = 
    0, $CellContext`a$2889$$ = 0, $CellContext`b$2890$$ = 
    0, $CellContext`c$2891$$ = 0, $CellContext`e$2892$$ = 
    0, $CellContext`f$2893$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 
        10, $CellContext`b$$ = -2.5, $CellContext`c$$ = 0.1, $CellContext`e$$ = 
        0.75, $CellContext`f$$ = 20, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`LambdaI$$ = 
        0.3, $CellContext`n$$ = 5, $CellContext`T$$ = 1000, $CellContext`V$$ = 
        6, $CellContext`vib$$ = 1500}, "ControllerVariables" :> {
        Hold[$CellContext`LambdaI$$, $CellContext`LambdaI$2884$$, 0], 
        Hold[$CellContext`vib$$, $CellContext`vib$2885$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$2886$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$2887$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$2888$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$2889$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2890$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2891$$, 0], 
        Hold[$CellContext`e$$, $CellContext`e$2892$$, 0], 
        Hold[$CellContext`f$$, $CellContext`f$2893$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Plot3D[$CellContext`z = (((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`y) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
             0.000123985^2)) $CellContext`V$$^2) 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`x + $CellContext`y + $CellContext`m (
                   0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`y) $CellContext`T$$))), \
{$CellContext`m, 
             0, $CellContext`n$$}], {$CellContext`x, $CellContext`b$$, \
$CellContext`c$$}, {$CellContext`y, 0, $CellContext`e$$}, 
         PlotRange -> {0, 10^$CellContext`a$$}, 
         PlotPoints -> {$CellContext`f$$}, AxesLabel -> {
           Row[{"\[CapitalDelta]G", " (eV)"}], 
           Row[{
             Subscript["\[Lambda]", "S"], " (eV)"}], 
           Row[{"rate (", 
             Superscript["s", "-1"], ")"}]}, ImageSize -> {420, 420}, Mesh -> 
         False, MaxRecursion -> 1, ViewPoint -> {-1, 2, 0.6}]], 
      "Specifications" :> {{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`vib$$, 1500, ""}, 4, 5000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`V$$, 6, ""}, 0.005, 1000, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`T$$, 1000, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`n$$, 5, ""}, 0, 50, 1, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`a$$, 10, ""}, 6, 18, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`b$$, -2.5, ""}, -0.1, -5, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`c$$, 0.1, ""}, 0, 5, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`e$$, 0.75, ""}, 0.0001, 5, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`f$$, 20, ""}, 20, 120, 1, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 
         10}, {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "Huang\[Dash]Rhys, S ="}, Appearance -> "Labeled", ImageSize -> 
         Tiny, ControlPlacement -> 
         11}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          Row[{
            Subscript[
             Style["k", Italic], "B"], 
            Style["T", Italic], " (eV)"}]}, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 12}, 
        Column[{
         "internal reorganization, \!\(\*SubscriptBox[\(\[Lambda]\), \(I\)]\) \
(eV)", 
          Manipulate`Place[1], 
          "vibration, \[Omega] (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))", 
          Manipulate`Place[2], 
          Row[{"electronic coupling, ", 
            Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], 
          Manipulate`Place[3], 
          Row[{"temperature, ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[4], 
          Row[{"summation factor ", 
            Style["m", Italic]}], 
          Manipulate`Place[5], 
          Row[{
            Style["a", Italic], " (axis, log ", 
            Style["z", Italic], " maximum (log ", 
            Style["k", Italic], "))"}], 
          Manipulate`Place[6], 
          Row[{
            Style["b", Italic], " (axis, ", 
            Style["x", Italic], " minimum (\[CapitalDelta]G))"}], 
          Manipulate`Place[7], 
          Row[{
            Style["c", Italic], " (axis, ", 
            Style["x", Italic], " maximum (\[CapitalDelta]G))"}], 
          Manipulate`Place[8], 
          Row[{
            Style["e", Italic], " (axis, ", 
            Style["y", Italic], 
            " maximum (\!\(\*SubscriptBox[\(\[Lambda]\), \(S\)]\)))"}], 
          Manipulate`Place[9], 
          Row[{
            Style["f", Italic], " (number of points to plot (graph))"}], 
          Manipulate`Place[10], "", "", 
          Manipulate`Place[11], 
          Manipulate`Place[12]}, Alignment -> Left, 
         Dividers -> {{True}, {
           True, False, True, False, True, False, True, False, True, False, 
            True, False, True, False, True, False, True, False, True, False, 
            True, False, True, True, True}}], 
        Spacer[140]}, 
      "Options" :> {
       ContinuousAction -> False, AutorunSequencing -> {2}, ControlPlacement -> 
        Left}, "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{623., {236., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`z = 1.3100334655397701`*^10, 
       Attributes[Subscript] = {NHoldRest}, 
       Attributes[Superscript] = {NHoldRest, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->1956465466,ExpressionUUID->"03a9c024-aeff-4e3e-8885-2aa260142b4e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Details",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Details", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "This optional section is for a more detailed description of the \
Demonstration than the caption, but it should still be as concise as \
possible. This section may also include numbered snapshot captions (e.g., \
Snapshot 1: phrase or sentence without an initial capital and without a \
period, unless more than one sentence is used) and explanations of the ", 
          StyleBox["Manipulate", "MRbig"], 
          " control labels. Define any symbols undefined so far. Include only \
text in this section \[LongDash] no code, graphics, etc. Do not change the \
cell style or copy cells from other sections. \n\nA book reference uses this \
format: \n    L. D. Schmidt, ", 
          StyleBox[
          "The Engineering of Chemical Reactions", FontSlant -> "Italic"], 
          ", New York: Oxford University Press, 1998. \n\nAn article \
reference uses this format: \n    D. Pearson, \"A Polynomial-Time Algorithm \
for the Change-Making Problem,\" ", 
          StyleBox["Operations Research Letters", FontSlant -> "Italic"], 
          ", ", 
          StyleBox["33", FontWeight -> "Bold"], 
          "(3), 2005 pp. 231\[Dash]234."}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b42cafa3-93cc-45b2-9bce-00512b05ae14"]
}], "DetailsSection",
 CellTags->"Details",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa"],

Cell[TextData[{
 "Snapshot 1: data based on the work of Closs and Miller (focused here on the \
isooctane data) at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"200", " ", 
     StyleBox["K",
      FontSlant->"Plain"]}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "bc8844a8-64d6-465d-a982-03fd3d89b8c1"],
 ", shifting the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ae1aa918-038a-4d5d-87dc-edd5c6777f5e"],
 " axis to 0.1 eV as the upper limit, highlighting the region with low \
solvent reorganization energies"
}], "DetailNotes",
 CellChangeTimes->{{3.8456115064967422`*^9, 3.845611564835387*^9}, {
   3.845643267621779*^9, 3.845643271142377*^9}, 3.8456475282428007`*^9, {
   3.846083698731824*^9, 3.846083702288703*^9}, {3.847130496498313*^9, 
   3.847130602886478*^9}, {3.8471306330319347`*^9, 3.847130659335702*^9}, {
   3.8472704105842457`*^9, 3.847270449139986*^9}, {3.847274045829446*^9, 
   3.8472740538384438`*^9}, {3.847287999716366*^9, 3.847288015619286*^9}, {
   3.847736820584056*^9, 3.8477368208206263`*^9}},
 CellID->1916642021,ExpressionUUID->"ac9000f0-68a0-41f1-b91b-d8af5158d498"],

Cell[TextData[{
 "Snapshot 2: for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "ab1d4bcf-1c7c-4c9a-8351-0913199997aa"],
 ", the semiclassical Marcus equation behaves similarly to the classical \
Marcus equation"
}], "DetailNotes",
 CellChangeTimes->{{3.8456116065695763`*^9, 3.845611701014373*^9}, {
   3.845612098076188*^9, 3.8456120986279507`*^9}, {3.8456121491502647`*^9, 
   3.845612171276599*^9}, {3.845612233256858*^9, 3.8456122497917347`*^9}, {
   3.845612359938695*^9, 3.845612361211669*^9}, {3.845643300359337*^9, 
   3.845643321802299*^9}, {3.845647569975853*^9, 3.8456475699768353`*^9}, {
   3.845650961244471*^9, 3.845650968727614*^9}, 3.8460836881768064`*^9, {
   3.8460891068940334`*^9, 3.846089107294937*^9}, {3.847130359342997*^9, 
   3.8471304290894003`*^9}, {3.847270451142399*^9, 3.847270467759763*^9}, {
   3.8472880343824997`*^9, 3.847288035956921*^9}, 3.8477369123944197`*^9},
 CellID->834068748,ExpressionUUID->"1c7669b7-26c5-4457-bf08-b1963b653014"],

Cell["\<\
Snapshot 3: in the high temperature limit, the semiclassical Marcus equation \
reduces to the classical Marcus equation\
\>", "DetailNotes",
 CellChangeTimes->{
  3.845611750025838*^9, {3.845611952423215*^9, 3.845611955071247*^9}, {
   3.8456125970744753`*^9, 3.8456126006186666`*^9}, {3.845643340332329*^9, 
   3.845643340837866*^9}, {3.8460837218283386`*^9, 3.846083729984131*^9}, {
   3.8471304598421926`*^9, 3.847130460329955*^9}, {3.847165283916587*^9, 
   3.847165283927608*^9}, {3.8471655355630903`*^9, 3.8471655355632343`*^9}, {
   3.847270470381044*^9, 3.847270477570121*^9}, 3.84728804254316*^9},
 CellID->717664063,ExpressionUUID->"1877e7e1-64c0-4b55-bf65-a9e6ff00dc54"],

Cell["\<\
The results of this Demonstration were checked against the R-package [10] \
that runs in the statistical software package R [11] for computing and \
graphics.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8456126683725033`*^9, 3.845612668372724*^9}, {
   3.845612876110281*^9, 3.845612908862957*^9}, 3.845612946161022*^9, {
   3.845612982526473*^9, 3.845613038754218*^9}, {3.8456132424621964`*^9, 
   3.84561332984474*^9}, {3.845643347577729*^9, 3.845643384287578*^9}, {
   3.845643416273468*^9, 3.845643456000475*^9}, 3.8459232301552773`*^9, {
   3.847288059135151*^9, 3.847288081849759*^9}},
 CellID->266915026,ExpressionUUID->"bd72d70e-f854-4cdf-8801-191f37593fa8"],

Cell["References", "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
  3.845486484235264*^9, 3.845486484236615*^9}},
 CellID->1520831482,ExpressionUUID->"1a86496d-dec7-4fde-804e-4c2644e80cf8"],

Cell[TextData[{
 "[1] R. A. Marcus, \"Electron Transfer Reactions in Chemistry: Theory and \
Experiment (Nobel Lecture),\" ",
 StyleBox["Angewandte Chemie International Edition",
  FontSlant->"Italic"],
 ", ",
 StyleBox["32",
  FontWeight->"Bold"],
 "(8), 1993 pp. 1111\[Dash]1121. ",
 ButtonBox["doi:10.1002/anie.199311113",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1002/anie.199311113"], None},
  ButtonNote->"https://doi.org/10.1002/anie.199311113"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
   3.845486485563533*^9, 3.8454865155028973`*^9}, {3.845487592619128*^9, 
   3.8454876364889593`*^9}, {3.845487667796479*^9, 3.8454876737310143`*^9}, {
   3.845487788050535*^9, 3.8454878088794947`*^9}, {3.845487859066869*^9, 
   3.8454878996227083`*^9}, 3.8454879903912582`*^9, {3.845488646583804*^9, 
   3.845488646849061*^9}, {3.845643465159183*^9, 3.8456434782941628`*^9}, {
   3.845643763608822*^9, 3.845643772552966*^9}, {3.8460839528897514`*^9, 
   3.8460839544787807`*^9}, 3.847274328639555*^9, 3.847274411037867*^9},
 CellID->1044342058,ExpressionUUID->"21e2b6a3-e106-4c32-938f-e4e177edefe5"],

Cell[TextData[{
 "[2] S. Chaudhuri, S. Hedstr\[ODoubleDot]m, D. D. M\[EAcute]ndez-Hern\
\[AAcute]ndez, H. P. Hendrickson, K. A. Jung, J. Ho and V. S. Batista, \
\"Electron Transfer Assisted by Vibronic Coupling from Multiple Modes,\" ",
 StyleBox["Journal of Chemical Theory and Computation",
  FontSlant->"Italic"],
 ", ",
 StyleBox["13",
  FontWeight->"Bold"],
 "(12), 2017 pp. 6000\[Dash]6009. ",
 ButtonBox["doi:10.1021/acs.jctc.7b00513.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/acs.jctc.7b00513"], None},
  ButtonNote->"https://doi.org/10.1021/acs.jctc.7b00513"]
}], "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
   3.845486485563533*^9, 3.845486494542997*^9}, {3.845487520953878*^9, 
   3.845487520958171*^9}, 3.8472744236159887`*^9},
 CellID->2075423495,ExpressionUUID->"69bacdf3-83ed-45d9-8c1a-83faca702e43"],

Cell[TextData[{
 "[3] P. F. Barbara, T. J. Meyer and M. A. Ratner, \"Contemporary Issues in \
Electron Transfer Research\", ",
 StyleBox["Journal of Physical Chemistry",
  FontSlant->"Italic"],
 ", ",
 StyleBox["100",
  FontWeight->"Bold"],
 "(31), 1996 pp. 13148\[Dash]13168. ",
 ButtonBox["doi:10.1021/jp9605663",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/jp9605663"], None},
  ButtonNote->"https://doi.org/10.1021/jp9605663"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845487945501761*^9, 3.845487945501944*^9}, {
   3.845488000437199*^9, 3.845488004909089*^9}, {3.8454884267223167`*^9, 
   3.8454884287459173`*^9}, {3.8454884770455217`*^9, 
   3.8454885081092777`*^9}, {3.8454885599836283`*^9, 
   3.8454885807988997`*^9}, {3.845488614203888*^9, 3.8454886412650547`*^9}, {
   3.845488675008108*^9, 3.845488703037126*^9}, {3.8456439141278267`*^9, 
   3.845643929079504*^9}, 3.84727443532751*^9, {3.8472759283029413`*^9, 
   3.847275929437989*^9}},
 CellID->1362205661,ExpressionUUID->"78c35d1e-b6a4-407f-b097-fdc4f5243817"],

Cell[TextData[{
 "[4] G. L. Closs and J. R. Miller, \"Intramolecular Long-Distance Electron \
Transfer in Organic Molecules,\" ",
 StyleBox["Science",
  FontSlant->"Italic"],
 ", ",
 StyleBox["240",
  FontWeight->"Bold"],
 "(4851), 1988 pp. 440\[Dash]447. ",
 ButtonBox["doi:10.1126/science.240.4851.440",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1126/science.240.4851.440"], None},
  ButtonNote->"https://doi.org/10.1126/science.240.4851.440"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845488847135751*^9, 3.845488847936137*^9}, 
   3.84548892908597*^9, {3.8454889707375813`*^9, 3.845488986639029*^9}, {
   3.845489962649474*^9, 3.8454900049219027`*^9}, {3.845490036544503*^9, 
   3.8454900669925137`*^9}, {3.845490162753018*^9, 3.845490169252675*^9}, {
   3.8454901999758673`*^9, 3.845490199979129*^9}, {3.845529422901569*^9, 
   3.845529423364011*^9}, {3.845643995119815*^9, 3.845644017491386*^9}, 
   3.8472744448788557`*^9},
 CellID->267383760,ExpressionUUID->"1f0eec4f-b40a-4182-b182-b1f4260285a2"],

Cell[TextData[{
 "[5] P. Hudhomme and R. M. Williams, \"Energy and Electron Transfer in \
Photo- and Electro-active Fullerene Dyads,\" ",
 StyleBox["Handbook of Carbon Nano Materials",
  FontSlant->"Italic"],
 " (F. D'Souza and K. M. Kadish, eds.), Hackensack, NJ: World Scientific, \
2011 pp. 545\[Dash]591. ",
 ButtonBox["doi:10.1142/9789814327824_0017",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1142/9789814327824_0017"], None},
  ButtonNote->"https://doi.org/10.1142/9789814327824_0017"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8454685041663237`*^9, 3.8454685192133703`*^9}, {
   3.8454879287150793`*^9, 3.845487937930896*^9}, 3.8454889355990353`*^9, {
   3.845488975277957*^9, 3.8454889821674137`*^9}, {3.845489063987767*^9, 
   3.845489146995013*^9}, {3.845489195356243*^9, 3.8454891953597*^9}, {
   3.845529189934093*^9, 3.845529213918605*^9}, {3.845529391166643*^9, 
   3.8455294155160303`*^9}, {3.845529450779456*^9, 3.8455294536519737`*^9}, {
   3.845529669926862*^9, 3.845529735627886*^9}, {3.8455298100216913`*^9, 
   3.845529810024806*^9}, {3.845644090038953*^9, 3.8456440975309877`*^9}, {
   3.845644135546042*^9, 3.845644164110743*^9}, {3.8456442064346952`*^9, 
   3.8456442778070173`*^9}, {3.8456443227864027`*^9, 3.845644326352326*^9}, {
   3.845645904073799*^9, 3.845645904314596*^9}, 3.847274454070528*^9},
 CellID->240524787,ExpressionUUID->"96232d05-d21a-4d41-ba87-654257b71f8e"],

Cell[TextData[{
 StyleBox["[6] R. M. Williams. \"Introduction to Electron Transfer.\" (Nov \
11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["doi:10.13140/RG.2.2.16547.30244",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.13140/RG.2.2.16547.30244"], None},
  ButtonNote->"http://dx.doi.org/10.13140/RG.2.2.16547.30244"],
  FontSize->12],
 StyleBox[".",
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685041663237`*^9, 3.8454685192133703`*^9}, {
   3.8454879287150793`*^9, 3.845487937930896*^9}, 3.8454889355990353`*^9, {
   3.845488975277957*^9, 3.8454889821674137`*^9}, {3.845489063987767*^9, 
   3.845489146995013*^9}, {3.845489195356243*^9, 3.8454891953597*^9}, {
   3.845529189934093*^9, 3.845529190429112*^9}, {3.845644345129858*^9, 
   3.845644401336515*^9}, {3.846086978538337*^9, 3.846086989377143*^9}, {
   3.846087101643921*^9, 3.8460871065877995`*^9}, {3.84608726893346*^9, 
   3.8460872696295996`*^9}, {3.846087339892658*^9, 3.8460873405009985`*^9}, {
   3.847274463384972*^9, 3.847274465668611*^9}, {3.8478918981568947`*^9, 
   3.847891898699677*^9}},
 CellID->207080162,ExpressionUUID->"2d666b08-3ede-44f0-8b21-d9ffc14a4c44"],

Cell[TextData[{
 StyleBox["[7] R. M. Williams. ",
  FontSize->12],
 StyleBox["Photoinduced Electron Transfer\[LongDash]The Classical Marcus \
Theory",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[" [Video]. (Nov 11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["youtu.be/YFzeMMOvhl0.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/YFzeMMOvhl0"], None},
  ButtonNote->"https://youtu.be/YFzeMMOvhl0"],
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525743612856*^9, 
   3.845525748675395*^9}, {3.845525805979796*^9, 3.845525811505554*^9}, {
   3.8455291931505547`*^9, 3.845529193581238*^9}, {3.845568465269396*^9, 
   3.845568471122637*^9}, 3.845568562033774*^9, {3.8455686095676327`*^9, 
   3.8455686095709*^9}, {3.8455757747280197`*^9, 3.8455758492973747`*^9}, 
   3.845575934939269*^9, {3.845644455407284*^9, 3.845644502295288*^9}, {
   3.845644545217039*^9, 3.845644568012081*^9}, 3.8460871822998037`*^9, 
   3.847274488473094*^9, {3.8478134468248587`*^9, 3.847813449472876*^9}},
 CellID->197499548,ExpressionUUID->"868ee2b0-29ef-4445-a8cd-02e8afe5e3d8"],

Cell[TextData[{
 "[8] R. M. Williams. ",
 StyleBox["Photoinduced Electron Transfer\[LongDash]The Semi-classical Marcus\
\[Dash]Levich\[Dash]Jortner Theory",
  FontSlant->"Italic"],
 " [Video]. (Nov 11, 2021) ",
 ButtonBox["youtu.be/GnPIbH6nM9o",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/GnPIbH6nM9o"], None},
  ButtonNote->"https://youtu.be/GnPIbH6nM9o"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525743612856*^9, 
   3.845525751479699*^9}, {3.845525863247136*^9, 3.8455258691488123`*^9}, {
   3.845529195627624*^9, 3.8455291961570797`*^9}, {3.8455682980810432`*^9, 
   3.845568307911862*^9}, 3.845568351711124*^9, {3.845568383495428*^9, 
   3.845568410984956*^9}, {3.84556844741706*^9, 3.845568447420724*^9}, 
   3.845575765263617*^9, {3.845575801398431*^9, 3.84557582464923*^9}, {
   3.8455758561374407`*^9, 3.845575870098317*^9}, {3.845644596969239*^9, 
   3.84564465818088*^9}, {3.846087195092207*^9, 3.8460872087805185`*^9}, 
   3.847274499071527*^9, {3.847813452336111*^9, 3.847813453753172*^9}},
 CellID->1811878752,ExpressionUUID->"f407f29f-6eb7-444f-b1c7-e89295ac444c"],

Cell[TextData[{
 StyleBox["[9] R. M. Williams. University of Amsterdam. (Nov 11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html"], 
    None},
  ButtonNote->
   "https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html"],
  FontSize->12],
 StyleBox[".",
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525754345191*^9, 
   3.8455257548248997`*^9}, {3.845529199062029*^9, 3.845529199475919*^9}, {
   3.845568650686081*^9, 3.845568674871126*^9}, {3.8455687135594*^9, 
   3.845568713562624*^9}, {3.8455759013240013`*^9, 3.845575902270748*^9}, {
   3.8456447049949293`*^9, 3.8456447390402117`*^9}, {3.845644780968061*^9, 
   3.8456447889895372`*^9}, 3.847274510501581*^9},
 CellID->367075982,ExpressionUUID->"99b6ef86-260a-4a00-a39a-d06594ead657"],

Cell[TextData[{
 "[10] J. Id\[EAcute] and G. Raos. \"ChargeTransport: Charge Transfer Rates \
and Charge Carrier Mobilities.\" (Nov 11, 2021) ",
 ButtonBox["CRAN.R-project.org/package=ChargeTransport",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://CRAN.R-project.org/package=ChargeTransport"], None},
  ButtonNote->"https://CRAN.R-project.org/package=ChargeTransport"],
 ". "
}], "DetailNotes",
 CellChangeTimes->{{3.845643396226883*^9, 3.845643396790044*^9}, {
   3.845644810984469*^9, 3.845644819601562*^9}, {3.845644879116131*^9, 
   3.845644917493957*^9}, 3.847274518309716*^9},
 CellID->532304254,ExpressionUUID->"446132c9-9d69-4ff3-bb34-261dad05ea71"],

Cell[TextData[{
 "[11] \"What Is R?\" The R Foundation. (Nov 11, 2021) ",
 ButtonBox["www.r-project.org/about.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.r-project.org/about.html"], None},
  ButtonNote->"https://www.r-project.org/about.html"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845643431678576*^9, 3.8456434368069973`*^9}, {
   3.845644968028158*^9, 3.845645039456131*^9}, {3.846517341654479*^9, 
   3.8465173416550417`*^9}, 3.84727452806362*^9},
 CellID->688505634,ExpressionUUID->"10becdcd-6a21-40ba-ac86-52a7b526a1ef"],

Cell[TextData[{
 "[12] A. Sarai, \"Energy-Gap and Temperature Dependence of Electron and \
Excitation Transfer in Biological Systems,\" ",
 StyleBox["Chemical Physics Letters",
  FontSlant->"Italic"],
 ", ",
 StyleBox["63",
  FontWeight->"Bold"],
 "(2), 1979 pp. 360\[Dash]366. ",
 ButtonBox["doi:10.1016/0009-2614(79)87036-0",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1016/0009-2614(79)87036-0"], None},
  ButtonNote->"https://doi.org/10.1016/0009-2614(79)87036-0"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.846962513055244*^9, 3.8469625243134317`*^9}, 
   3.846962642685626*^9, {3.847274577710428*^9, 3.847274608344429*^9}},
 CellID->861546623,ExpressionUUID->"5597c3bc-d708-41ec-9b99-41d83852aede"],

Cell[TextData[{
 "[13] J. R. Miller, J. V. Beitz and R. K. Huddleston, \"Effect of Free \
Energy on Rates of Electron Transfer between Molecules,\" ",
 StyleBox["Journal of the American Chemical Society",
  FontSlant->"Italic"],
 ", ",
 StyleBox["106",
  FontWeight->"Bold"],
 "(18), 1984 pp. 5057\[Dash]5068. ",
 ButtonBox["doi:10.1021/ja00330a004",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/ja00330a004"], None},
  ButtonNote->"https://doi.org/10.1021/ja00330a004"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.846962536786943*^9, 3.846962633029429*^9}, {
   3.846962683486155*^9, 3.846962715173335*^9}, 3.846962784697668*^9, {
   3.847274620101563*^9, 3.847274633432053*^9}, {3.847274669153186*^9, 
   3.847274714693687*^9}, {3.847275969704995*^9, 3.8472759700866117`*^9}},
 CellID->1679344687,ExpressionUUID->"2db527a8-8f0b-4c60-85e8-e234a7200b4a"],

Cell[TextData[{
 "[14] M. R. Gunner, D. E. Robertson and P. L. Dutton, \"Kinetic Studies on \
the Reaction Center Protein from ",
 StyleBox["Rhodopseudomonas sphaeroides",
  FontSlant->"Italic"],
 ": The Temperature and Free Energy Dependence of Electron Transfer between \
Various Quinones in the QA Site and the Oxidized Bacteriochlorophyll Dimer,\" \
",
 StyleBox["Journal of Physical Chemistry,",
  FontSlant->"Italic"],
 " ",
 StyleBox["90",
  FontWeight->"Bold"],
 "(16), 1986 pp. 3783\[Dash]3795. ",
 ButtonBox["doi:10.1021/j100407a054",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/j100407a054"], None},
  ButtonNote->"https://doi.org/10.1021/j100407a054"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.846962789442379*^9, 3.8469628153874826`*^9}, {
   3.84696284817925*^9, 3.8469628794922132`*^9}, {3.846962910070717*^9, 
   3.8469629487401876`*^9}, {3.846962984694886*^9, 3.846963103956003*^9}, {
   3.846964035793605*^9, 3.846964057966988*^9}, {3.847274933661448*^9, 
   3.847274986268057*^9}, 3.847275025690114*^9, {3.8472759751843967`*^9, 
   3.847275991137298*^9}},
 CellID->3945199,ExpressionUUID->"de6f1abc-ed23-40a7-a1f6-7eb56a798c90"],

Cell[TextData[{
 "[15] R. Rujkorakarn and F. Tanaka, \"Three-Dimensional Representations of \
Photo-induced Electron Transfer Rates in Pyrene-",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"(", 
     SubscriptBox["CH", "2"], ")"}], "n"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"f455a735-766a-4a6c-8cb6-81c3b1341609"],
 "-N,N'-dimethylaniline Systems Obtained by Three Electron Transfer Theories,\
\" ",
 StyleBox["Journal of Molecular Graphics and Modelling",
  FontSlant->"Italic"],
 ", ",
 StyleBox["27",
  FontWeight->"Bold"],
 "(5), 2009 pp. 571\[Dash]577. ",
 ButtonBox["doi:10.1016/j.jmgm.2008.09.008",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1016/j.jmgm.2008.09.008"], None},
  ButtonNote->"https://doi.org/10.1016/j.jmgm.2008.09.008"],
 "."
}], "DetailNotes",
 CellChangeTimes->{
  3.84696404624016*^9, {3.846964125169018*^9, 3.846964143097245*^9}, {
   3.846964174772668*^9, 3.846964409835622*^9}, {3.84696447725331*^9, 
   3.846964480943151*^9}, {3.846964529215814*^9, 3.8469645365266857`*^9}, {
   3.847275039101791*^9, 3.847275169449366*^9}, 3.8478142060590982`*^9},
 CellID->403430659,ExpressionUUID->"ae319744-761a-409b-b656-397f32ff1b01"],

Cell[TextData[{
 "[16] T. Unger, S. Wedler, F.-J. Kahle, U. Scherf, H. B\[ADoubleDot]ssler \
and A. K\[ODoubleDot]hler, \"The Impact of Driving Force and Temperature on \
the Electron Transfer in Donor\[Dash]Acceptor Blend Systems,\" ",
 StyleBox["The Journal of Physical Chemistry C",
  FontSlant->"Italic"],
 ", ",
 StyleBox["121",
  FontWeight->"Bold"],
 "(41), 2017 pp. 22739\[Dash]22752. ",
 ButtonBox["doi:10.1021/acs.jpcc.7b09213",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/acs.jpcc.7b09213"], None},
  ButtonNote->"https://doi.org/10.1021/acs.jpcc.7b09213"],
 "."
}], "DetailNotes",
 CellChangeTimes->{
  3.8469645790491457`*^9, {3.8470463142303543`*^9, 3.847046321254204*^9}, {
   3.847046351701314*^9, 3.8470464197757273`*^9}, {3.847046456958458*^9, 
   3.847046460915676*^9}, {3.8470465040005283`*^9, 3.84704650731643*^9}, {
   3.847046547770907*^9, 3.847046663336608*^9}, 3.8470470348527927`*^9, {
   3.8472752019236317`*^9, 3.8472752438353567`*^9}, {3.847275279545229*^9, 
   3.847275282202861*^9}},
 CellID->1882450183,ExpressionUUID->"bee1c3f6-1f9d-47ca-801f-e0d864eb8dd2"],

Cell[TextData[{
 "[17] W. W. Parson, \"Generalizing the Marcus Equation,\" ",
 StyleBox["The Journal of Chemical Physics",
  FontSlant->"Italic"],
 ", ",
 StyleBox["152",
  FontWeight->"Bold"],
 "(18), 2020 184106. ",
 ButtonBox["doi:10.1063/5.0007569",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1063/5.0007569"], None},
  ButtonNote->"https://doi.org/10.1063/5.0007569"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8470471547762823`*^9, 3.847047165296341*^9}, {
   3.847275301026005*^9, 3.847275343180945*^9}, 3.847813505972731*^9},
 CellID->630085693,ExpressionUUID->"55a85619-1163-41f3-b106-cd19b7ba5473"],

Cell[TextData[{
 "[18] J. B. Kelber, N. A. Panjwani, D. Wu, R. G\[OAcute]mez-Bombarelli, B. \
W. Lovett, J. J. L. Morton and H. L. Anderson, \"Synthesis and Investigation \
of Donor\[Dash]Porphyrin\[Dash]Acceptor Triads with Long-Lived Photo-Induced \
Charge-Separate States\", ",
 StyleBox["Chemical Science",
  FontSlant->"Italic"],
 ", ",
 StyleBox["6",
  FontWeight->"Bold"],
 ", 2015, pp. 6468-6481. ",
 ButtonBox["doi:10.1039/C5SC01830G",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1039/C5SC01830G"], None},
  ButtonNote->"https://doi.org/10.1039/C5SC01830G"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.847079697692046*^9, 3.847079708335017*^9}, {
   3.847079754152013*^9, 3.8470798542555323`*^9}, {3.847079898002593*^9, 
   3.847079907080399*^9}, {3.847079976362309*^9, 3.8470800610924397`*^9}, 
   3.8472758371950493`*^9, {3.847276016935237*^9, 3.847276018016109*^9}, {
   3.8478135151528263`*^9, 3.847813552592041*^9}, {3.847814522038537*^9, 
   3.8478145370954514`*^9}, {3.847814598983758*^9, 3.84781460112201*^9}},
 CellID->608378894,ExpressionUUID->"f903e7cb-3c9d-4d5e-b2e0-0dd9486144f2"],

Cell[TextData[{
 "[19] G. Lanzani, \"Charge Transfer and Transport,\" ",
 StyleBox["The Photophysics behind Photovoltaics and Photonics",
  FontSlant->"Italic"],
 ", Weinheim: Wiley-VCH, 2012 pp. 145\[Dash]176. ",
 ButtonBox["doi:10.1002/9783527645138.ch8",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1002/9783527645138.ch8"], None},
  ButtonNote->"https://doi.org/10.1002/9783527645138.ch8"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845643431678576*^9, 3.8456434368069973`*^9}, {
   3.845644968028158*^9, 3.845645039456131*^9}, 3.84651734300334*^9, {
   3.846517387156167*^9, 3.846517398954463*^9}, {3.846782132420727*^9, 
   3.846782173431435*^9}, {3.846790463443378*^9, 3.846790469649692*^9}, {
   3.846790601430479*^9, 3.8467906758632383`*^9}, {3.846961791087413*^9, 
   3.8469618064202337`*^9}, {3.846961864982398*^9, 3.846961930662313*^9}, {
   3.8469620058369637`*^9, 3.846962007695765*^9}, 3.8469620649695263`*^9, {
   3.8469620966604853`*^9, 3.8469621174825077`*^9}, {3.8469621484601593`*^9, 
   3.846962161378222*^9}, {3.846962414778636*^9, 3.846962481143942*^9}, {
   3.846962519578617*^9, 3.8469625331784573`*^9}, {3.846962763244134*^9, 
   3.846962809644202*^9}, 3.846964030355497*^9, 3.846964573067029*^9, {
   3.8470466456148977`*^9, 3.847046648926206*^9}, {3.84704714042351*^9, 
   3.8470471617987823`*^9}, {3.847080090157262*^9, 3.847080099844606*^9}, {
   3.847087891165798*^9, 3.847088008416011*^9}, {3.8470880911252403`*^9, 
   3.847088097299285*^9}, {3.847088442720386*^9, 3.84708845514108*^9}, {
   3.847088591537676*^9, 3.8470885950008783`*^9}, {3.847088788688739*^9, 
   3.847088874833516*^9}, {3.84727539668985*^9, 3.847275431644648*^9}, {
   3.847275574793594*^9, 3.847275586958845*^9}, {3.8478135651867123`*^9, 
   3.847813606929929*^9}, {3.847814619927335*^9, 3.8478146397118187`*^9}},
 CellID->100329378,ExpressionUUID->"8a62ff5d-88ea-4849-a76a-0e90a472eb89"],

Cell[TextData[{
 "[20] R. M. Williams. ",
 StyleBox["Marcus Waves 5 Fast",
  FontSlant->"Italic"],
 " [Video]. (Nov 30, 2021) ",
 ButtonBox["youtu.be/xn1_2w6-gqs",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/xn1_2w6-gqs"], None},
  ButtonNote->"https://youtu.be/xn1_2w6-gqs"],
 "."
}], "DetailNotes",
 CellChangeTimes->{
  3.845611750025838*^9, {3.845611952423215*^9, 3.845611955071247*^9}, {
   3.8456125970744753`*^9, 3.8456126006186666`*^9}, {3.845643340332329*^9, 
   3.845643340837866*^9}, {3.8460837218283386`*^9, 3.846083729984131*^9}, {
   3.8471304598421926`*^9, 3.847130460329955*^9}, {3.847165285619527*^9, 
   3.8471652955806093`*^9}, {3.847165335243928*^9, 3.847165386078432*^9}, {
   3.847165476854353*^9, 3.847165476856483*^9}, {3.847270521842367*^9, 
   3.847270522708383*^9}, {3.847275615761516*^9, 3.8472756455744057`*^9}, {
   3.847275693952244*^9, 3.84727573938177*^9}},
 CellID->33954021,ExpressionUUID->"545efda9-597c-4587-bbd0-47f108b558bb"],

Cell[TextData[{
 "[21] R. M. Williams. ",
 StyleBox["Marcus Waves 3 Fast",
  FontSlant->"Italic"],
 " [Video]. (Nov 30, 2021) ",
 ButtonBox["youtu.be/c_Qb89Zvc3s",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/c_Qb89Zvc3s"], None},
  ButtonNote->"https://youtu.be/c_Qb89Zvc3s"],
 "."
}], "DetailNotes",
 CellChangeTimes->{
  3.845611750025838*^9, {3.845611952423215*^9, 3.845611955071247*^9}, {
   3.8456125970744753`*^9, 3.8456126006186666`*^9}, {3.845643340332329*^9, 
   3.845643340837866*^9}, {3.8460837218283386`*^9, 3.846083729984131*^9}, {
   3.8471304598421926`*^9, 3.847130460329955*^9}, {3.847165285619527*^9, 
   3.8471653053158703`*^9}, {3.84716539117448*^9, 3.847165408997692*^9}, {
   3.847165510376032*^9, 3.847165510378087*^9}, {3.847270524700035*^9, 
   3.847270526049801*^9}, {3.84727576011884*^9, 3.8472757831075563`*^9}, {
   3.8472758381282673`*^9, 3.847275848715396*^9}},
 CellID->471294478,ExpressionUUID->"044d6aaf-7dd7-42ee-ac6d-4da886bf7796"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Control Suggestions",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Control Suggestions", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Check the boxes beside items that are appropriate control \
suggestions for this Demonstration. For more information, see the ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          " page.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "f1fe398c-f37e-4aca-9161-633bae63965a"]
}], "ControlSuggestionsSection",
 CellTags->
  "Control Suggestions",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-\
9fec786547ab"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Resize Images",ExpressionUUID->"fcee1195-e255-4dbd-8863-4af840debdbd"]}],
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\""]], "ControlSuggestions",
 CellChangeTimes->{{3.847275793881052*^9, 3.847275794015253*^9}},
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "df0b52c8-7325-4803-bb1e-958545cedfd1"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" on Mac) and drag up and down to zoom.\""}]]], "ControlSuggestions",
 CellChangeTimes->{{3.846442465390655*^9, 3.84644246546778*^9}},
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"61b2b2a8-69c4-4012-b6da-8923112012e2"]}],
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "8e06b60e-3149-4a23-ab31-0a8ab2f5ceaf"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"98a81657-e34e-4dab-ac86-\
717d7eff050a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Slider Zoom",ExpressionUUID->"c8d377e3-56fc-4adc-88e3-cf7642fb3181"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" to make ever finer adjustments.\""}]]], "ControlSuggestions",
 CellChangeTimes->{{3.8454684656711335`*^9, 3.845468465796104*^9}, {
  3.8472757996088257`*^9, 3.847275800889243*^9}},
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Gamepad Controls",ExpressionUUID->
    "1fbb5ded-9a1c-4ba0-a087-0d1c0be219ce"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\""]], "ControlSuggestions",
 CellChangeTimes->{
  3.35696210375764*^9, 3.3895522232313623`*^9, {3.847275801519648*^9, 
   3.847275801620817*^9}},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Automatic Animation",ExpressionUUID->
    "ec8a5240-77b9-42a0-8b9e-365efb47dfeb"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 CellChangeTimes->{{3.847275803422422*^9, 3.8472758035219584`*^9}},
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "5bdb2812-7da3-4bb1-a7fc-436054c40542"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Search Terms",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Search Terms", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide words and phrases that people might search for, with each \
one in a separate cell. Categories are added after the Demonstration is \
submitted, so the best things to enter here are terms (including any \
synonyms) that refer to specific parts of the Demonstration. Do not \
capitalize words unless they are proper names or proper adjectives.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b8b4550c-a7c1-4c5e-acf4-64f68ac8ea51"]
}], "SearchTermsSection",
 CellTags->
  "Search Terms",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b"],

Cell["charge separation", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634545063831*^9}},
 CellID->2129058965,ExpressionUUID->"5b0f8ff9-f928-461f-8dd2-e42a25032219"],

Cell["charge recombination", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.8456345498627834`*^9}},
 CellID->309789228,ExpressionUUID->"317f6e93-9300-4a19-8d37-0f303a35778f"],

Cell["photo-induced electron transfer", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.8456345553917937`*^9}},
 CellID->292502039,ExpressionUUID->"dfeff995-689a-410a-88ed-8c0bf1d5c8fb"],

Cell["Rudolph Marcus", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634560437248*^9}},
 CellID->116661474,ExpressionUUID->"d5b61c72-5561-4480-84a0-f45692f7d060"],

Cell["electron transfer theory", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634565522756*^9}},
 CellID->80983373,ExpressionUUID->"09fa06ef-6408-4b41-9c14-51a7f415b66d"],

Cell["Marcus-Levich-Jortner", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634570790687*^9}},
 CellID->412622865,ExpressionUUID->"985bd04a-df82-42b9-925b-0a185b1572c1"],

Cell["Huang-Rhys factor", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634577528832*^9}},
 CellID->262018152,ExpressionUUID->"3b6b0a34-5874-40ec-9fbe-bade7e6b6af9"],

Cell["electron phonon coupling ", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634577002655*^9}},
 CellID->588225219,ExpressionUUID->"7b6878f4-e6f0-4015-ac31-7bfa12512633"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Related Links",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Related Links", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide hyperlinks (not just bare URLs) to any relevant wolfram.com \
pages, with the page title as the linked text. Links to ", 
          ButtonBox[
          "NKS | Online", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://www.wolframscience.com/nks"], None}], 
          " should use the section title, not a page number. Links to \
non-Wolfram sites go in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d5b26c0d-c135-41cd-9d97-dc9003b05c57"]
}], "RelatedLinksSection",
 CellTags->
  "Related Links",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe"],

Cell[TextData[ButtonBox["Marcus Theory of Electron Transfer 1: Classical \
versus Semi-classical Models",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransfer1ClassicalVersusSemiClassicalM/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransfer1ClassicalVersusSemiClassicalM/"]], \
"RelatedLinks",
 CellChangeTimes->{{3.846441508275496*^9, 3.846441508279381*^9}},
 CellID->1413542048,ExpressionUUID->"4be8e68d-b569-43ee-be01-ebe6b05e81cc"],

Cell[TextData[ButtonBox["Marcus Theory of Electron-Transfer Reactions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransferReactions/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/MarcusTheoryOfElectronTransferReactions/\
"]], "RelatedLinks",
 CellChangeTimes->{{3.8454684380554533`*^9, 3.8454684380554533`*^9}},
 CellID->2070922,ExpressionUUID->"c5cfbfe8-e939-4aac-a0a4-7527af53c5dd"],

Cell[TextData[ButtonBox["Marcus Theory for Electron Transfer in Photosystem \
II",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryForElectronTransferInPhotosystemII/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
MarcusTheoryForElectronTransferInPhotosystemII/"]], "RelatedLinks",
 CellChangeTimes->{{3.845468460694504*^9, 3.845468460694504*^9}},
 CellID->261318040,ExpressionUUID->"e89389a3-503b-43e6-bc3d-5d03804f72cb"],

Cell[TextData[ButtonBox["Quantum Harmonic Oscillator Tunneling into \
Classically Forbidden Regions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
QuantumHarmonicOscillatorTunnelingIntoClassicallyForbiddenRe/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
QuantumHarmonicOscillatorTunnelingIntoClassicallyForbiddenRe/"]], \
"RelatedLinks",
 CellChangeTimes->{{3.8455692825477*^9, 3.845569282548484*^9}, 
   3.845569402798053*^9, {3.8455694420813303`*^9, 3.845569442085705*^9}},
 CellID->1621482253,ExpressionUUID->"28e5ce1c-1776-4163-bc51-7fc8297805e3"],

Cell[TextData[ButtonBox["Franck-Condon Principle in Vibronic Transitions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
FranckCondonPrincipleInVibronicTransitions/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
FranckCondonPrincipleInVibronicTransitions/"]], "RelatedLinks",
 CellChangeTimes->{
  3.8455694768741217`*^9, {3.8455695138231163`*^9, 3.8455695138271093`*^9}},
 CellID->684745741,ExpressionUUID->"4c48e8fc-b2cc-4ca6-b21d-597ac16c531b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Authoring Information",
 Cell[BoxData[
  TemplateBox[{"Authoring Information", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "'Contributed by: John Smith' for single authors; 'Contributed by: \
John Smith, Robert Ford, and Jane Doe' for multiple authors. To credit people \
other than Demonstrations authors, please see the detailed ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "990970f3-a922-4bea-919a-d6fa2da1f6d5"]
}], "AuthorSection",
 CellTags->
  "Authoring \
Information",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a"],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Ren\[EAcute] M. Williams",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://demonstrations.wolfram.com/author.html?author=Ren%C3%A9+M.+\
Williams"], None},
  ButtonNote->
   "https://demonstrations.wolfram.com/author.html?author=Ren%C3%A9+M.+\
Williams"]
}], "Author",
 CellChangeTimes->{{3.847889654013073*^9, 
  3.847889654013073*^9}},ExpressionUUID->"e6a077c9-f528-4852-97e7-\
764f2f3a1895"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"DemonstrationSource",
WindowSize->{778, 732},
WindowMargins->{{-1842, Automatic}, {Automatic, 34}},
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.10.2121", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3, "$ApplicationName" -> "Pubs", "$LinkBase" -> "Pubs", 
    "$ApplicationDirectory" -> "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\Documentation\\English\\", 
    "$UseNewPageDialog" -> "False", "$CondensedBlogMenus" -> "True"}, 
  "PresenterSettings" -> {
   "OutlineThumbnails" -> {"1" -> "Thumbnail"}, 
    "OutlinePalette" -> {"Thumbnails" -> {}, "ThumbnailMagnification" -> 0.8},
     "SideNotesPalette" -> {"PaletteNumber" -> 0}}, "BlogsDirectory" -> 
  "\\\\wrisync02.wri.wolfram.com\\backup$\\jayw\\My \
Documents\\jaywstasks\\BlogTools\\Blogs\\", "ChatNotebookID" -> 
  "fef9786d-4748-42a0-a328-5496e837f205", "Originator" -> 
  "chatframework@wolfram.com", "ScreenName" -> "", "ChatCreationDate" -> 
  "DateObject[{2018, 6, 18, 13, 5, 54.5673134}, Instant, Gregorian, -5.]", 
  "CustomWindowTitle" -> "None", "ChatNotebookDate" -> "18 Jun 2018 13:05:54",
   "ChatNotebookWindowTitle" -> "chatframework's Chat - (18 Jun 2018 13:05)", 
  "Participants" -> {"chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "AllParticipants" -> {
   "chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "Contacts" -> {
   "andre@wolfram.com", "bradym@wolfram.com", "brianv@wolfram.com", 
    "jayw@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "EmailListData" -> {0, 0, 0, 0, 1}, "ScrollLock" -> False, "Terminated" -> 
  True, "QuestionState" -> "Timeup", 
  "AttachedCells" -> {
   "Initialization Code" -> None, "Manipulate" -> None, "Caption" -> None, 
    "Snapshots" -> CellObject[17281], "Details" -> None, "Related Links" -> 
    None, "Search Terms" -> None, "Control Suggestions" -> None, "Thumbnail" -> 
    None, "Authoring Information" -> None}, "TryRealOnly" -> False},
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (June 19, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"dc487b88-0bf3-4b5e-9c93-e8b7cf809cd1"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initialization Code"->{
  Cell[752, 27, 1827, 38, 67, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
   CellTags->"Initialization Code"]},
 "Manipulate"->{
  Cell[2604, 69, 1518, 29, 67, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
   CellTags->"Manipulate"]},
 "Caption"->{
  Cell[36508, 763, 1132, 23, 67, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
   CellTags->"Caption"]},
 "Thumbnail"->{
  Cell[103506, 1996, 999, 21, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
   CellTags->"Thumbnail"]},
 "Snapshots"->{
  Cell[115459, 2244, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
   CellTags->"Snapshots"]},
 "Details"->{
  Cell[149521, 2943, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
   CellTags->"Details"]},
 "Control Suggestions"->{
  Cell[177703, 3570, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
   CellTags->"Control Suggestions"]},
 "ResizeImages"->{
  Cell[178837, 3600, 472, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[179312, 3612, 847, 20, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[180162, 3634, 435, 12, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[180600, 3648, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[181342, 3668, 1062, 25, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[182407, 3695, 521, 13, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[182931, 3710, 1631, 34, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[184565, 3746, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
   CellTags->"BookmarkAnimation"]},
 "Search Terms"->{
  Cell[185610, 3774, 1073, 24, 68, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
   CellTags->"Search Terms"]},
 "Related Links"->{
  Cell[189397, 3851, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
   CellTags->"Related Links"]},
 "Authoring Information"->{
  Cell[193248, 3946, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
   CellTags->"Authoring Information"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initialization Code", 197277, 4038},
 {"Manipulate", 197442, 4041},
 {"Caption", 197592, 4044},
 {"Thumbnail", 197750, 4047},
 {"Snapshots", 197903, 4050},
 {"Details", 198055, 4053},
 {"Control Suggestions", 198215, 4056},
 {"ResizeImages", 198391, 4059},
 {"RotateAndZoomIn3D", 198557, 4062},
 {"DragLocators", 198723, 4065},
 {"CreateAndDeleteLocators", 198895, 4068},
 {"SliderZoom", 199065, 4071},
 {"GamepadControls", 199228, 4074},
 {"AutomaticAnimation", 199398, 4077},
 {"BookmarkAnimation", 199571, 4080},
 {"Search Terms", 199738, 4083},
 {"Related Links", 199901, 4086},
 {"Authoring Information", 200074, 4089}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 169, 3, 216, "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],
Cell[752, 27, 1827, 38, 67, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
 CellTags->"Initialization Code"],
Cell[CellGroupData[{
Cell[2604, 69, 1518, 29, 67, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
 CellTags->"Manipulate"],
Cell[CellGroupData[{
Cell[4147, 102, 22040, 440, 745, "Input",ExpressionUUID->"ebecb9f0-1d25-4711-89cd-7223315dbb49",
 CellID->2071835132],
Cell[26190, 544, 10272, 213, 538, "Output",ExpressionUUID->"4cf375b7-eb20-449e-a77d-276321055a33",
 CellID->2135287576]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36508, 763, 1132, 23, 67, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
 CellTags->"Caption"],
Cell[37643, 788, 3863, 71, 69, "ManipulateCaption",ExpressionUUID->"10d06e69-f1e7-4610-b520-424965ba4617",
 CellID->2005410859],
Cell[41509, 861, 3370, 60, 84, "ManipulateCaption",ExpressionUUID->"deba3ab5-0412-40f6-98c5-57cfc3ab7688",
 CellID->837612789],
Cell[44882, 923, 3797, 79, 43, "ManipulateCaption",ExpressionUUID->"7ad90eec-1676-414b-9cad-e77098c78b8d",
 CellID->128144587],
Cell[48682, 1004, 615, 17, 23, "ManipulateCaption",ExpressionUUID->"c73766c7-fc54-421e-9e2a-1f1cb1318d36",
 CellID->731237523],
Cell[49300, 1023, 2672, 37, 67, "ManipulateCaption",ExpressionUUID->"ba0285fe-84a0-4730-860f-5c18077533c9",
 CellID->2026902308],
Cell[51975, 1062, 1757, 25, 37, "ManipulateCaption",ExpressionUUID->"628a19fb-840d-489e-95e3-ccc53df21a5b",
 CellID->794880798],
Cell[53735, 1089, 3428, 65, 116, "ManipulateCaption",ExpressionUUID->"90730535-7fb3-41ca-9c8b-4d6ded77ff8d",
 CellID->86693020],
Cell[57166, 1156, 1549, 22, 37, "ManipulateCaption",ExpressionUUID->"390f70be-7658-44df-affb-0afbc45e7777",
 CellID->1950403273],
Cell[58718, 1180, 1109, 14, 22, "ManipulateCaption",ExpressionUUID->"021b0a42-5790-405a-bc6d-6382b91cdaca",
 CellID->1438951199],
Cell[59830, 1196, 1379, 25, 23, "ManipulateCaption",ExpressionUUID->"45d1a2f2-1ae0-40b4-91d6-e47de233a7f6",
 CellID->1959311453],
Cell[61212, 1223, 1379, 25, 23, "ManipulateCaption",ExpressionUUID->"f4a8fa54-b566-4759-93c7-cd85d4c16d74",
 CellID->633347473],
Cell[62594, 1250, 1307, 23, 23, "ManipulateCaption",ExpressionUUID->"650f4faa-a430-4ea9-bb09-1b7f32e5b894",
 CellID->1742024179],
Cell[63904, 1275, 1229, 20, 23, "ManipulateCaption",ExpressionUUID->"913f5391-8066-408c-8e35-25ea9bf96275",
 CellID->1555816902],
Cell[65136, 1297, 1295, 23, 23, "ManipulateCaption",ExpressionUUID->"163f403f-3e4e-447d-bd6d-26ea14a0b772",
 CellID->853786042],
Cell[66434, 1322, 1274, 20, 23, "ManipulateCaption",ExpressionUUID->"c4a3c170-50d0-4b75-8630-45df37a67933",
 CellID->96278640],
Cell[67711, 1344, 1238, 20, 23, "ManipulateCaption",ExpressionUUID->"4a5062e4-eb9b-4109-b8e3-991df75a5e00",
 CellID->1099916289],
Cell[68952, 1366, 1204, 17, 22, "ManipulateCaption",ExpressionUUID->"e54540e6-ab3c-4b08-b7d8-9de76c22c7de",
 CellID->1072432135],
Cell[70159, 1385, 1444, 27, 23, "ManipulateCaption",ExpressionUUID->"d433d5a8-23ed-4329-8b6a-baa69845f566",
 CellID->753835847],
Cell[71606, 1414, 1442, 27, 23, "ManipulateCaption",ExpressionUUID->"f0e83e20-b85a-4cdf-8af5-69a73fbc7312",
 CellID->1713046876],
Cell[73051, 1443, 1370, 25, 23, "ManipulateCaption",ExpressionUUID->"afc1dc98-3915-4073-99a9-6664f345dd49",
 CellID->2013073250],
Cell[74424, 1470, 1293, 22, 23, "ManipulateCaption",ExpressionUUID->"06b08a2d-f413-430a-bc00-8c5e37ed9e01",
 CellID->117254265],
Cell[75720, 1494, 1357, 25, 23, "ManipulateCaption",ExpressionUUID->"88e52a43-a32b-4bef-918c-42ca6e6b2603",
 CellID->1449927556],
Cell[77080, 1521, 1342, 22, 23, "ManipulateCaption",ExpressionUUID->"7d98ea50-05d1-43da-a7a3-c51f74839f3a",
 CellID->1435491183],
Cell[78425, 1545, 1302, 22, 23, "ManipulateCaption",ExpressionUUID->"cedc3377-74cf-4447-96fc-101309895840",
 CellID->1469022283],
Cell[79730, 1569, 2012, 33, 54, "ManipulateCaption",ExpressionUUID->"d5a6d1d8-eef8-42c6-b890-2e5901687fb0",
 CellID->518981415],
Cell[81745, 1604, 1147, 16, 55, "ManipulateCaption",ExpressionUUID->"9d52a3da-e3b2-42a9-b11d-926b777005e5",
 CellID->2099753569],
Cell[82895, 1622, 2747, 42, 71, "ManipulateCaption",ExpressionUUID->"df2b2b45-37a3-4ef5-bbb9-4c820ef99ba4",
 CellID->1984520843],
Cell[85645, 1666, 3964, 84, 89, "ManipulateCaption",ExpressionUUID->"2eca3962-f99b-4722-ab84-99085fbbb40a",
 CellID->706452211],
Cell[89612, 1752, 2202, 31, 39, "ManipulateCaption",ExpressionUUID->"7488cedd-cc52-4261-8348-7586ae28dc42",
 CellID->1876928042],
Cell[91817, 1785, 3058, 59, 55, "ManipulateCaption",ExpressionUUID->"3f5dcdea-89e4-4c18-bcb9-66b987e0aa0a",
 CellID->684979579],
Cell[94878, 1846, 2915, 58, 55, "ManipulateCaption",ExpressionUUID->"d8947084-f777-48d9-b6b6-ec8075eb92b2",
 CellID->1634122492],
Cell[97796, 1906, 1936, 27, 71, "ManipulateCaption",ExpressionUUID->"5c4d49bf-a139-453d-a389-493fb7750ff3",
 CellID->1435578743],
Cell[99735, 1935, 2068, 31, 55, "ManipulateCaption",ExpressionUUID->"ff16f5b5-55f8-4380-9ec1-542f53f71223",
 CellID->839004015],
Cell[101806, 1968, 1663, 23, 23, "ManipulateCaption",ExpressionUUID->"7a312828-7d2a-4443-b12b-e00caa09c182",
 CellID->1152165796]
}, Open  ]],
Cell[CellGroupData[{
Cell[103506, 1996, 999, 21, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
 CellTags->"Thumbnail"],
Cell[104508, 2019, 10914, 220, 489, "Output",ExpressionUUID->"b01534b0-10aa-421a-8705-9d837d919474",
 CellID->1048159982]
}, Open  ]],
Cell[CellGroupData[{
Cell[115459, 2244, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
 CellTags->"Snapshots"],
Cell[116480, 2268, 11000, 222, 489, "Output",ExpressionUUID->"a0678903-4dc6-4fd2-8f33-7d52b86408f5",
 CellID->616461133],
Cell[127483, 2492, 10997, 222, 489, "Output",ExpressionUUID->"4aa7ff42-5f1b-4f0e-9ae0-52741b6aada9",
 CellID->1401149203],
Cell[138483, 2716, 11001, 222, 489, "Output",ExpressionUUID->"03a9c024-aeff-4e3e-8885-2aa260142b4e",
 CellID->1956465466]
}, Open  ]],
Cell[CellGroupData[{
Cell[149521, 2943, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
 CellTags->"Details"],
Cell[151320, 2981, 1167, 24, 39, "DetailNotes",ExpressionUUID->"ac9000f0-68a0-41f1-b91b-d8af5158d498",
 CellID->1916642021],
Cell[152490, 3007, 1036, 18, 23, "DetailNotes",ExpressionUUID->"1c7669b7-26c5-4457-bf08-b1963b653014",
 CellID->834068748],
Cell[153529, 3027, 691, 11, 39, "DetailNotes",ExpressionUUID->"1877e7e1-64c0-4b55-bf65-a9e6ff00dc54",
 CellID->717664063],
Cell[154223, 3040, 675, 11, 39, "DetailNotes",ExpressionUUID->"bd72d70e-f854-4cdf-8801-191f37593fa8",
 CellID->266915026],
Cell[154901, 3053, 224, 3, 23, "DetailNotes",ExpressionUUID->"1a86496d-dec7-4fde-804e-4c2644e80cf8",
 CellID->1520831482],
Cell[155128, 3058, 1174, 24, 39, "DetailNotes",ExpressionUUID->"21e2b6a3-e106-4c32-938f-e4e177edefe5",
 CellID->1044342058],
Cell[156305, 3084, 888, 19, 55, "DetailNotes",ExpressionUUID->"69bacdf3-83ed-45d9-8c1a-83faca702e43",
 CellID->2075423495],
Cell[157196, 3105, 1063, 24, 39, "DetailNotes",ExpressionUUID->"78c35d1e-b6a4-407f-b097-fdc4f5243817",
 CellID->1362205661],
Cell[158262, 3131, 1038, 23, 39, "DetailNotes",ExpressionUUID->"1f0eec4f-b40a-4182-b182-b1f4260285a2",
 CellID->267383760],
Cell[159303, 3156, 1436, 25, 55, "DetailNotes",ExpressionUUID->"96232d05-d21a-4d41-ba87-654257b71f8e",
 CellID->240524787],
Cell[160742, 3183, 1181, 23, 24, "DetailNotes",ExpressionUUID->"2d666b08-3ede-44f0-8b21-d9ffc14a4c44",
 CellID->207080162],
Cell[161926, 3208, 1271, 26, 41, "DetailNotes",ExpressionUUID->"868ee2b0-29ef-4445-a8cd-02e8afe5e3d8",
 CellID->197499548],
Cell[163200, 3236, 1286, 24, 39, "DetailNotes",ExpressionUUID->"f407f29f-6eb7-444f-b1c7-e89295ac444c",
 CellID->1811878752],
Cell[164489, 3262, 1111, 22, 41, "DetailNotes",ExpressionUUID->"99b6ef86-260a-4a00-a39a-d06594ead657",
 CellID->367075982],
Cell[165603, 3286, 670, 13, 39, "DetailNotes",ExpressionUUID->"446132c9-9d69-4ff3-bb34-261dad05ea71",
 CellID->532304254],
Cell[166276, 3301, 559, 12, 23, "DetailNotes",ExpressionUUID->"10becdcd-6a21-40ba-ac86-52a7b526a1ef",
 CellID->688505634],
Cell[166838, 3315, 735, 18, 39, "DetailNotes",ExpressionUUID->"5597c3bc-d708-41ec-9b99-41d83852aede",
 CellID->861546623],
Cell[167576, 3335, 887, 20, 39, "DetailNotes",ExpressionUUID->"2db527a8-8f0b-4c60-85e8-e234a7200b4a",
 CellID->1679344687],
Cell[168466, 3357, 1183, 27, 71, "DetailNotes",ExpressionUUID->"de6f1abc-ed23-40a7-a1f6-7eb56a798c90",
 CellID->3945199],
Cell[169652, 3386, 1206, 29, 55, "DetailNotes",ExpressionUUID->"ae319744-761a-409b-b656-397f32ff1b01",
 CellID->403430659],
Cell[170861, 3417, 1121, 24, 55, "DetailNotes",ExpressionUUID->"bee1c3f6-1f9d-47ca-801f-e0d864eb8dd2",
 CellID->1882450183],
Cell[171985, 3443, 639, 17, 39, "DetailNotes",ExpressionUUID->"55a85619-1163-41f3-b106-cd19b7ba5473",
 CellID->630085693],
Cell[172627, 3462, 1131, 24, 55, "DetailNotes",ExpressionUUID->"f903e7cb-3c9d-4d5e-b2e0-0dd9486144f2",
 CellID->608378894],
Cell[173761, 3488, 1921, 31, 39, "DetailNotes",ExpressionUUID->"8a62ff5d-88ea-4849-a76a-0e90a472eb89",
 CellID->100329378],
Cell[175685, 3521, 988, 21, 23, "DetailNotes",ExpressionUUID->"545efda9-597c-4587-bbd0-47f108b558bb",
 CellID->33954021],
Cell[176676, 3544, 990, 21, 23, "DetailNotes",ExpressionUUID->"044d6aaf-7dd7-42ee-ac6d-4da886bf7796",
 CellID->471294478]
}, Open  ]],
Cell[CellGroupData[{
Cell[177703, 3570, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
 CellTags->"Control Suggestions"],
Cell[178837, 3600, 472, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
 CellTags->"ResizeImages"],
Cell[179312, 3612, 847, 20, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
 CellTags->"RotateAndZoomIn3D"],
Cell[180162, 3634, 435, 12, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
 CellTags->"DragLocators"],
Cell[180600, 3648, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
 CellTags->"CreateAndDeleteLocators"],
Cell[181342, 3668, 1062, 25, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
 CellTags->"SliderZoom"],
Cell[182407, 3695, 521, 13, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
 CellTags->"GamepadControls"],
Cell[182931, 3710, 1631, 34, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
 CellTags->"AutomaticAnimation"],
Cell[184565, 3746, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185610, 3774, 1073, 24, 68, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
 CellTags->"Search Terms"],
Cell[186686, 3800, 328, 4, 23, "SearchTerms",ExpressionUUID->"5b0f8ff9-f928-461f-8dd2-e42a25032219",
 CellID->2129058965],
Cell[187017, 3806, 332, 4, 23, "SearchTerms",ExpressionUUID->"317f6e93-9300-4a19-8d37-0f303a35778f",
 CellID->309789228],
Cell[187352, 3812, 343, 4, 23, "SearchTerms",ExpressionUUID->"dfeff995-689a-410a-88ed-8c0bf1d5c8fb",
 CellID->292502039],
Cell[187698, 3818, 324, 4, 23, "SearchTerms",ExpressionUUID->"d5b61c72-5561-4480-84a0-f45692f7d060",
 CellID->116661474],
Cell[188025, 3824, 333, 4, 23, "SearchTerms",ExpressionUUID->"09fa06ef-6408-4b41-9c14-51a7f415b66d",
 CellID->80983373],
Cell[188361, 3830, 331, 4, 23, "SearchTerms",ExpressionUUID->"985bd04a-df82-42b9-925b-0a185b1572c1",
 CellID->412622865],
Cell[188695, 3836, 327, 4, 23, "SearchTerms",ExpressionUUID->"3b6b0a34-5874-40ec-9fbe-bade7e6b6af9",
 CellID->262018152],
Cell[189025, 3842, 335, 4, 23, "SearchTerms",ExpressionUUID->"7b6878f4-e6f0-4015-ac31-7bfa12512633",
 CellID->588225219]
}, Open  ]],
Cell[CellGroupData[{
Cell[189397, 3851, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
 CellTags->"Related Links"],
Cell[190591, 3881, 542, 11, 23, "RelatedLinks",ExpressionUUID->"4be8e68d-b569-43ee-be01-ebe6b05e81cc",
 CellID->1413542048],
Cell[191136, 3894, 465, 9, 23, "RelatedLinks",ExpressionUUID->"c5cfbfe8-e939-4aac-a0a4-7527af53c5dd",
 CellID->2070922],
Cell[191604, 3905, 488, 10, 23, "RelatedLinks",ExpressionUUID->"e89389a3-503b-43e6-bc3d-5d03804f72cb",
 CellID->261318040],
Cell[192095, 3917, 610, 12, 23, "RelatedLinks",ExpressionUUID->"28e5ce1c-1776-4163-bc51-7fc8297805e3",
 CellID->1621482253],
Cell[192708, 3931, 503, 10, 23, "RelatedLinks",ExpressionUUID->"4c48e8fc-b2cc-4ca6-b21d-597ac16c531b",
 CellID->684745741]
}, Open  ]],
Cell[CellGroupData[{
Cell[193248, 3946, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
 CellTags->"Authoring Information"],
Cell[194409, 3976, 453, 13, 23, "Author",ExpressionUUID->"e6a077c9-f528-4852-97e7-764f2f3a1895"]
}, Open  ]]
}, Open  ]]
}
]
*)

