(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    182917,       3841]
NotebookOptionsPosition[    168716,       3575]
NotebookOutlinePosition[    174706,       3699]
CellTagsIndexPosition[    174034,       3677]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Marcus Theory of Electron Transfer 3: 
Interactive Potential Energy Surfaces for Charge Separation\
\>", "Title",
 CellChangeTimes->{{3.848332318443584*^9, 3.84833233057486*^9}, {
  3.848346083541547*^9, 3.848346103043672*^9}, {3.8485133992763443`*^9, 
  3.848513401202848*^9}, {3.848649273405107*^9, 
  3.8486492828194017`*^9}},ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-\
13c361826e91"],

Cell[TextData[{
 "Initialization Code",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Initialization Code", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"Provide any code that must be evaluated before the ", 
          StyleBox["Manipulate", "MRbig"], 
          ". This will automatically be built into the ", 
          StyleBox["Manipulate", "MRbig"], 
          " in the final notebook version. Never use a package that is not \
included in the default distribution of ", 
          StyleBox["Mathematica", FontSlant -> "Italic"], 
          ". To use a package, use the ", 
          StyleBox["Initialization", "MRbig"], " option (with ", 
          StyleBox["Get", "MRbig"], ", not ", 
          StyleBox["Needs", "MRbig"], ") in the ", 
          StyleBox["Manipulate", "MRbig"], 
          " itself, and use the full name of the function from the package. \
For example:\n", 
          StyleBox[
          "  Manipulate[\n  ...\n  ComputationalGeometry`ConvexHull[...]...\n \
 ...\n  Initialization :> Get[\"ComputationalGeometry`\"],\n  ...\n  ]", 
           "MR"], "\nIf you provide initialization code, include a ", 
          StyleBox["SaveDefinitions->True", "MRbig"], " option in the ", 
          StyleBox["Manipulate", "MRbig"], ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "81fde376-e763-44cf-83ed-5c52ec315067"]
}], "InitializationSection",
 CellTags->
  "Initialization \
Code",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Manipulate",
 Cell[BoxData[
  TemplateBox[{"Manipulate", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"This section contains the ", 
          StyleBox["Manipulate", "MRbig"], 
          " input cell and its evaluated output cell. Make all control labels \
or labels in the output as descriptive as possible, with only proper nouns \
and proper adjectives capitalized. More description of the controls can be \
provided in the Details section below, if necessary. If you change this ", 
          StyleBox["Manipulate", "MRbig"], 
          " after creating screenshots and/or thumbnails, use ", 
          StyleBox["Update Thumbnail & Snapshots", FontWeight -> "Bold"], 
          " in the toolbar to update any copies in later sections. You can \
control the Flash preview for the Demonstration with the ", 
          StyleBox["AutorunSequencing", "MRbig"], " option. Use ", 
          StyleBox["SaveDefinitions->True", "MRbig"], 
          " if you provided initialization code in the previous section."}], 
        "MoreInfoText"], Background -> GrayLevel[0.95], FrameMargins -> 20, 
       FrameStyle -> GrayLevel[0.9], RoundingRadius -> 5]], "MoreInfoText", 
     Deletable -> True, CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d12d57a6-93e6-4518-8a9c-9df2eb688354"]
}], "ManipulateSection",
 CellTags->
  "Manipulate",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Quiet", "[", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "Pa1", ",", "Pa2", ",", "xMin", ",", "yMin", ",", "DeltaG", ",", 
        "LambdaT", ",", "Ea", ",", "P1", ",", " ", "Y", ",", " ", "LambdaS", 
        ",", "KetC", ",", "Kopt", ",", " ", "X"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Y", "=", " ", 
        RowBox[{
         RowBox[{"-", "Eoo"}], "+", "Eox", "-", "Ered", "-", 
         RowBox[{"F", "*", 
          FractionBox["14.399645", 
           RowBox[{"eps", " ", "Rc"}]]}], "-", 
         RowBox[{"F", "*", 
          RowBox[{"(", 
           RowBox[{"14.399645", "/", "2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "eps"]}], "+", 
            FractionBox["1", "epsEC"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "Ran"], "+", 
            FractionBox["1", "Rcat"]}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"LambdaS", "=", " ", 
        RowBox[{"14.399645", "*", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"(", 
             RowBox[{"2", "*", "Ran"}], ")"}]], "+", 
           FractionBox["1", 
            RowBox[{"(", 
             RowBox[{"2", "*", "Rcat"}], ")"}]], "-", 
           FractionBox["1", "Rc"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            SuperscriptBox["n", "2"]], "-", 
           FractionBox["1", "eps"]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"KetC", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"0.0000861733033", " ", 
                 RowBox[{"(", 
                  RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}], 
                ")"}], "0.5"]}], ")"}]}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Pi]", 
             RowBox[{"3", "/", "2"}]], "*", 
            SuperscriptBox[
             RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
          SuperscriptBox["V", "2"], "*", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"Y", "+", "LambdaS", "+", "LambdaI"}], ")"}], "2"], 
             RowBox[{"4", "*", "0.0000861733033", "*", 
              RowBox[{"(", 
               RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}]]}]]}], 
         ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Kopt", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"0.0000861733033", " ", 
                RowBox[{"(", 
                 RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}], 
               ")"}], "0.5"]}], ")"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Pi]", 
            RowBox[{"3", "/", "2"}]], "*", 
           SuperscriptBox[
            RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
         SuperscriptBox["V", "2"]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"X", "=", 
        RowBox[{"LambdaS", "+", "LambdaI"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Ea", " ", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Y", "+", "LambdaI", "+", "LambdaS"}], ")"}], "^", "2"}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", "*", 
           RowBox[{"(", 
            RowBox[{"LambdaI", "+", "LambdaS"}], ")"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xMin", " ", "=", 
        RowBox[{"Sqrt", "[", "X", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"yMin", "=", 
        RowBox[{
         RowBox[{"xMin", "^", "2"}], "-", 
         RowBox[{"2", 
          RowBox[{"Sqrt", "[", "X", "]"}], "*", "xMin"}], "+", "X", "+", 
         "Y"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DeltaG", " ", "=", " ", "yMin"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", "LambdaT", ")"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"(", "xMin", ")"}], "^", "2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Ea", " ", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"DeltaG", "+", "LambdaT"}], ")"}], "^", "2"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", "*", "LambdaT"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Grid", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
              "Y", ",", "\"\< = \[CapitalDelta]\[ThinSpace]G(eV)    \>\"", 
               ",", "X", ",", 
               "\"\< = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    \
\>\"", ",", "LambdaS", ",", "\"\< = \[Lambda]s(eV)\>\""}], "}"}], "]"}], 
            "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"NumberForm", "[", 
                RowBox[{
                 RowBox[{"N", "[", "Ea", "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"6", ",", "3"}], "}"}]}], "]"}], ",", 
               "\"\< = Ea(eV)       \>\"", ",", " ", "Kopt", ",", 
               "\"\<= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))\>\""}], "}"}], "]"}], "}"}],
            ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Framed", "[", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
               "KetC", ",", 
                "\"\<= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\(\\\ \
\)\)]\)Rate of electron transfer,(\!\(\*SuperscriptBox[\(s\), \
\(-1\)]\))\>\""}], "}"}], "]"}], "]"}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Plot", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "^", "2"}], ",", 
                RowBox[{
                 RowBox[{"x", "^", "2"}], "-", 
                 RowBox[{"2", "*", 
                  RowBox[{"Sqrt", "[", "X", "]"}], "*", "x"}], "+", "X", "+", 
                 "Y"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", 
                RowBox[{"-", "a"}], ",", "b"}], "}"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "c"}], ",", "d"}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Epilog", "\[Rule]", 
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{"Black", ",", "Thick"}], "]"}], ",", 
                   RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "yMin"}], "}"}]}], "}"}], "]"}]}], 
                  "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{"Blue", ",", "Thick"}], "]"}], ",", 
                   RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"xMin", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"xMin", ",", 
                    RowBox[{
                    RowBox[{"(", "xMin", ")"}], "^", "2"}]}], "}"}]}], "}"}], 
                    "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{"Red", ",", "Thick"}], "]"}], ",", 
                   RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", "Ea", ")"}], "^", "0.5"}], ",", "Ea"}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", "Ea", ")"}], "^", "0.5"}], ",", "0"}], 
                    "}"}]}], "}"}], "]"}]}], "}"}]}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"AxesLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<reaction coordinate\>\"", ",", 
                 "\"\<free energy, (eV)\>\""}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}], "}"}]}], 
          "}"}], ",", " ", 
         RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
         RowBox[{"Frame", " ", "\[Rule]", "All"}]}], "]"}]}]}], "]"}], "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", " ", 
     RowBox[{"\"\<oxidation, D, \>\"", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(E\), \(ox\)]\)\>\"", ",", "Italic"}],
        "]"}], ",", "\"\< (eV)\>\""}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Eox", ",", "0.605", ",", " ", "\"\<\>\""}], "}"}], ",", "0", 
      ",", "4", ",", "0.01", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", " ", 
     RowBox[{"\"\<reduction, A, \>\"", ",", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(E\), \(red\)]\)\>\"", ",", "Italic"}], "]"}],
       ",", "\"\< (eV)\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Ered", ",", 
        RowBox[{"-", "0.57"}], ",", " ", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"-", "4"}], ",", "0", ",", "0.01", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", " ", 
     RowBox[{"\"\<zero-zero, \>\"", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(E\), \(00\)]\)\>\"", ",", "Italic"}],
        "]"}], ",", "\"\< (eV)\>\""}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Eoo", ",", "1.76", ",", " ", "\"\<\>\""}], "}"}], ",", "0", 
      ",", "5", ",", "0.01", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<c to c distance, \>\"", " ", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Rc\>\"", ",", "Italic"}], "]"}], ",", 
      "\"\< (A\[Degree])\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Rc", ",", "18", ",", " ", "\"\<\>\""}], "}"}], ",", "3.6", 
      ",", "80", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<anion radius, \>\"", " ", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<r-\>\"", ",", "Italic"}], "]"}], ",", 
      "\"\< (A\[Degree])\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Ran", ",", "5.6", ",", " ", "\"\<\>\""}], "}"}], ",", "1.8", 
      ",", "30", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<cation radius, \>\"", " ", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<r+\>\"", ",", "Italic"}], "]"}], ",", 
      "\"\< (A\[Degree])\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Rcat", ",", "3.7", ",", " ", "\"\<\>\""}], "}"}], ",", "1.8", 
      ",", "30", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{
    "{", " ", 
     "\"\<internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)\>\"", 
     "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"LambdaI", ",", "0.3", ",", " ", "\"\<\>\""}], "}"}], ",", 
      "0.0001", ",", "2", ",", "0.01", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<coupling, \>\"", " ", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<V\>\"", ",", "Italic"}], "]"}], ",", 
      "\"\< (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"V", ",", "28", ",", " ", "\"\<\>\""}], "}"}], ",", "0.005", 
      ",", "1000", ",", "0.1", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<eps (solvent) \>\"", ",", " ", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<\[Epsilon]\>\"", ",", "Italic"}], "]"}], ",", 
      "\"\<\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Control", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eps", ",", "25.2", ",", " ", "\"\<\>\""}], "}"}], ",", "1.8", 
      ",", "68", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Item", "[", 
    RowBox[{
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<n (solvent) \>\"", ",", " ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<n\>\"", ",", "Italic"}], "]"}], ",", "\"\<\>\""}], 
          "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Control", "@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"n", ",", "1.528", ",", " ", "\"\<\>\""}], "}"}], ",", 
           "1.0", ",", "3", ",", " ", 
           RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
           RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<temp., \>\"", ",", " ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<T\>\"", ",", "Italic"}], "]"}], ",", 
           "\"\< (K)\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Control", "@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"T", ",", "300", ",", " ", "\"\<\>\""}], "}"}], ",", "4", 
           ",", "1000", ",", "1", ",", " ", 
           RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
           RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<epsEC (for EC) \>\"", ",", " ", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<\[Epsilon]\>\"", ",", "Italic"}], "]"}], ",", 
           "\"\<\>\""}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Control", "@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"epsEC", ",", "37.5", ",", " ", "\"\<\>\""}], "}"}], ",", 
           "1.8", ",", "68", ",", " ", 
           RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
           RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Item", "[", 
    RowBox[{
     RowBox[{"Row", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\< axis,   \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", 
         "\"\< minimum (x) \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", "\"\<\>\"", ",", 
         "\n", "\t", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"a", ",", "2", ",", "\"\<a (eV)\>\""}], "}"}], ",", 
            "0.01", ",", "40", ",", " ", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", "\"\< axis,   \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", 
         "\"\< maximum (x) \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", "\"\<\>\"", ",", 
         "\n", "\t", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"b", ",", "3", ",", "\"\<b (eV)\>\""}], "}"}], ",", 
            "0.01", ",", "40", ",", " ", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}]}], "}"}],
        ",", 
       RowBox[{"BaseStyle", "\[Rule]", "10"}]}], "]"}], ",", "\n", "\t\t", 
     RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Item", "[", 
    RowBox[{
     RowBox[{"Row", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\< axis,   \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", 
         "\"\< minimum (y) \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", "\"\<\>\"", ",", 
         "\n", "\t", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"c", ",", "0.8", ",", "\"\<c (eV)\>\""}], "}"}], ",", 
            "0.01", ",", "40", ",", " ", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", "\"\< axis,   \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", 
         "\"\< maximum (y) \>\"", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", "\"\<\>\"", ",", 
         "\n", "\t", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"d", ",", "2", ",", "\"\<d (eV)\>\""}], "}"}], ",", 
            "0.01", ",", "40", ",", " ", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", " ", "Tiny"}]}], "}"}]}]}], "}"}],
        ",", 
       RowBox[{"BaseStyle", "\[Rule]", "10"}]}], "]"}], ",", "\n", "\t\t", 
     RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Item", "[", 
    RowBox[{
     RowBox[{"Row", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)\>\"", ",", " ", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\>\"", ",", "Italic"}], "]"}], ",", "\"\<\>\"", ",", 
         "\n", "\t\t\t", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"F", ",", "1", ",", " ", "\"\<\>\""}], "}"}], ",", 
            RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}]}],
         "}"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", "10"}]}], "]"}], ",", "\n", "\t\t", 
     RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Alignment", "\[Rule]", "Left"}], ",", "  ", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "False"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", " ", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.8478226281784897`*^9, {3.847824587985618*^9, 3.8478245974807997`*^9}, {
   3.847824641029331*^9, 3.847824649987049*^9}, 3.847824818110614*^9, {
   3.8478249010615587`*^9, 3.8478249530130863`*^9}, {3.847825061539379*^9, 
   3.847825062472171*^9}, {3.847825101296335*^9, 3.847825122792523*^9}, 
   3.847825220976329*^9, 3.847825252310506*^9, {3.847825293054255*^9, 
   3.8478252953275223`*^9}, {3.8478257169787073`*^9, 3.847825727350924*^9}, {
   3.847910964129068*^9, 3.847910971456005*^9}, 3.8479110166847*^9, {
   3.847911075301579*^9, 3.847911132947177*^9}, 3.847911196017006*^9, {
   3.847911237650618*^9, 3.8479112478811207`*^9}, {3.8479113689666367`*^9, 
   3.84791140000576*^9}, {3.84794309013566*^9, 3.847943090656623*^9}, 
   3.84794313508869*^9, {3.847943484950404*^9, 3.8479434859680367`*^9}, {
   3.84794356278137*^9, 3.847943583460475*^9}, 3.847943659747796*^9, {
   3.84832412063105*^9, 3.848324142334817*^9}, {3.848324175847273*^9, 
   3.848324217690957*^9}, 3.8483242830954247`*^9, {3.848324317728806*^9, 
   3.848324318722426*^9}, {3.84832437085608*^9, 3.848324375644723*^9}, {
   3.8483244472426167`*^9, 3.848324450720496*^9}, {3.848324522828086*^9, 
   3.848324534913858*^9}, {3.848324661063628*^9, 3.848324687071504*^9}, {
   3.848324984999708*^9, 3.8483250069894457`*^9}, {3.848325056577334*^9, 
   3.848325145806005*^9}, {3.84832518618332*^9, 3.848325189923236*^9}, {
   3.848325223461582*^9, 3.84832524458134*^9}, {3.848329147077982*^9, 
   3.848329168888186*^9}, {3.848329208455481*^9, 3.848329244112371*^9}, 
   3.8483292871389627`*^9, {3.848329526306449*^9, 3.848329541337446*^9}, {
   3.848329573502112*^9, 3.8483295852220373`*^9}, {3.848329617501111*^9, 
   3.848329621725403*^9}, {3.848332787078703*^9, 3.848332798094577*^9}, {
   3.848332831784041*^9, 3.848332837518469*^9}, {3.848332927196178*^9, 
   3.848332963782254*^9}, {3.8483330336515512`*^9, 3.848333037210788*^9}, {
   3.8483331484416733`*^9, 3.84833320274826*^9}, {3.848333427487319*^9, 
   3.8483335225863047`*^9}, 3.8483336276375017`*^9, {3.848333670085617*^9, 
   3.848333670884439*^9}, {3.848333793991034*^9, 3.848333799584792*^9}, {
   3.848333832486868*^9, 3.84833383483892*^9}, {3.8483338819481707`*^9, 
   3.8483338937317753`*^9}, {3.848333935394096*^9, 3.848333972038226*^9}, {
   3.848334048617518*^9, 3.848334077633565*^9}, {3.8483343138269176`*^9, 
   3.8483343326738577`*^9}, {3.848334493640517*^9, 3.848334548640493*^9}, {
   3.848334598676394*^9, 3.848334621606194*^9}, {3.848334750239336*^9, 
   3.848334767037952*^9}, {3.848334839605473*^9, 3.848334840066957*^9}, {
   3.848340447698575*^9, 3.8483404549976797`*^9}, {3.848340488324709*^9, 
   3.848340525642517*^9}, {3.848340714375248*^9, 3.8483407305661087`*^9}, {
   3.848340765537484*^9, 3.848340771834404*^9}, {3.84834082507421*^9, 
   3.84834082943987*^9}, {3.848340859553997*^9, 3.8483408681105556`*^9}, 
   3.848341149361661*^9, {3.848341195919735*^9, 3.848341207218254*^9}, {
   3.8483412720104513`*^9, 3.848341310028872*^9}, {3.848341365811845*^9, 
   3.848341401991872*^9}, {3.848341442433169*^9, 3.848341523862097*^9}, {
   3.848341856388629*^9, 3.848341879622127*^9}, {3.84834200930866*^9, 
   3.848342014143734*^9}, 3.848342078391758*^9, {3.848342136835145*^9, 
   3.848342137594452*^9}, {3.848342366073592*^9, 3.8483423811984377`*^9}, {
   3.848342426195922*^9, 3.8483424395657253`*^9}, {3.848342518492241*^9, 
   3.8483425188720512`*^9}, 3.848342607588871*^9, {3.8483426428161077`*^9, 
   3.84834267811138*^9}, 3.848342776666448*^9, {3.848342893033937*^9, 
   3.848342902230029*^9}, {3.848342952010365*^9, 3.848342998692752*^9}, {
   3.8483430345965357`*^9, 3.848343058484253*^9}, {3.848343167648439*^9, 
   3.848343214447199*^9}, {3.8483432803305473`*^9, 3.848343326615508*^9}, {
   3.848343372045611*^9, 3.848343414977694*^9}, {3.8483434596289797`*^9, 
   3.848343484433262*^9}, {3.848343611381242*^9, 3.8483436160694304`*^9}, {
   3.848343658176428*^9, 3.848343661671681*^9}, {3.848343728879768*^9, 
   3.848343729405448*^9}, 3.848343792179475*^9, {3.848343837725976*^9, 
   3.848343852924672*^9}, {3.84834388310962*^9, 3.848343883193549*^9}, {
   3.8483439315662527`*^9, 3.848343934559147*^9}, {3.8483452669736357`*^9, 
   3.8483452685083323`*^9}, {3.848345311809711*^9, 3.848345318641333*^9}, 
   3.848345445056237*^9, {3.848345746922789*^9, 3.8483457531860228`*^9}, {
   3.84834582715689*^9, 3.848345855002248*^9}, {3.8483459072020397`*^9, 
   3.848345931017619*^9}, {3.848345986111311*^9, 3.848346001539987*^9}, {
   3.84850715058528*^9, 3.848507151630699*^9}, 3.848507687236239*^9, 
   3.848507744163121*^9, {3.848508380506817*^9, 3.848508382168412*^9}, {
   3.848508421429408*^9, 3.848508430281485*^9}, {3.8485103410863857`*^9, 
   3.848510342653244*^9}, {3.848510389100574*^9, 3.848510393284131*^9}, {
   3.848510509454796*^9, 3.84851051279455*^9}, 3.8485105726305428`*^9, {
   3.848510697322526*^9, 3.848510733553389*^9}, {3.848510796817212*^9, 
   3.848510913141654*^9}, 3.848510963876481*^9, {3.848511024833523*^9, 
   3.8485110722149878`*^9}, {3.848511172910164*^9, 3.848511175476412*^9}, {
   3.848511222530971*^9, 3.848511246476632*^9}, {3.848511296269589*^9, 
   3.84851130191809*^9}, 3.84851150276162*^9, {3.848511574376683*^9, 
   3.8485115748843327`*^9}, {3.848511627546685*^9, 3.848511635827285*^9}, {
   3.8485116824716454`*^9, 3.848511682846363*^9}, {3.848511735379636*^9, 
   3.84851173616477*^9}, {3.848511793118081*^9, 3.8485117942302933`*^9}, {
   3.8485118446731462`*^9, 3.848511846432066*^9}, 3.8485118777077503`*^9, {
   3.848511965166004*^9, 3.8485119881582003`*^9}, 3.848512059346122*^9, {
   3.848512251503179*^9, 3.8485123098067102`*^9}, 3.848512370835829*^9, {
   3.848512441927299*^9, 3.848512473554907*^9}, 3.848512563412359*^9, 
   3.8485126193625917`*^9, 3.8485126615150633`*^9, {3.848513054717388*^9, 
   3.848513098844738*^9}, {3.8485132112282267`*^9, 3.848513211414033*^9}, {
   3.8485134197072697`*^9, 3.848513420697464*^9}, 3.848513570520754*^9, {
   3.848513614656454*^9, 3.848513638752184*^9}, {3.848513673127202*^9, 
   3.848513710597527*^9}, {3.8485137757369328`*^9, 3.8485137768105507`*^9}, {
   3.848513932896245*^9, 3.848513933061584*^9}, {3.848514774795805*^9, 
   3.8485147861615458`*^9}, {3.848515187627018*^9, 3.848515235079743*^9}, {
   3.848515348038046*^9, 3.848515365472336*^9}, {3.848515939943829*^9, 
   3.848515941909968*^9}, {3.848551785679944*^9, 3.848551803843709*^9}, 
   3.8485870874931173`*^9, {3.848587371774048*^9, 3.8485874723905563`*^9}, 
   3.848587579456812*^9, {3.848587698309705*^9, 3.8485877024121923`*^9}, {
   3.848587750169529*^9, 3.8485878148114967`*^9}, {3.848587848731675*^9, 
   3.848587863211225*^9}, {3.8485879069510193`*^9, 3.84858790765336*^9}, {
   3.848587938257012*^9, 3.84858799982441*^9}, {3.8485880519167843`*^9, 
   3.848588136760235*^9}, {3.848588173407611*^9, 3.848588173933775*^9}, {
   3.848588245875545*^9, 3.8485883115187397`*^9}, {3.848588748110855*^9, 
   3.848588851642858*^9}, {3.848588882485359*^9, 3.848588882705127*^9}, {
   3.848589025048439*^9, 3.848589063448339*^9}, {3.8485891131397753`*^9, 
   3.848589137965427*^9}, {3.84858917451018*^9, 3.848589175100401*^9}, {
   3.848589220021965*^9, 3.8485892614825687`*^9}, 3.84858930004307*^9, {
   3.848589409551375*^9, 3.8485895643776913`*^9}, {3.8485895969149513`*^9, 
   3.848589636170209*^9}, {3.848589738284883*^9, 3.84858981676066*^9}, {
   3.848589880526112*^9, 3.8485899742114162`*^9}, 3.848590021978456*^9, {
   3.8485900699943733`*^9, 3.848590073241503*^9}, {3.84859143305546*^9, 
   3.848591438811583*^9}, 3.848591470063629*^9, {3.84859150471066*^9, 
   3.8485915772571993`*^9}, {3.848603559388685*^9, 3.848603579936977*^9}, {
   3.848603678332747*^9, 3.848603700377675*^9}, {3.848603833293211*^9, 
   3.848603843755972*^9}, {3.8486038941381187`*^9, 3.848603903343054*^9}, {
   3.848604075288671*^9, 3.848604134199791*^9}, {3.848604213148378*^9, 
   3.848604219740397*^9}, {3.848604684752318*^9, 3.84860473695989*^9}, 
   3.848604834481999*^9, {3.84864881474538*^9, 3.84864881518482*^9}, {
   3.848664239136016*^9, 3.848664275271604*^9}, {3.848664337010275*^9, 
   3.848664360045137*^9}, 3.849079443589807*^9, {3.8490800187447443`*^9, 
   3.849080042995558*^9}, {3.8490800850659323`*^9, 3.849080090975925*^9}, {
   3.849080172526245*^9, 3.849080176843154*^9}, {3.849284686590601*^9, 
   3.849284693749892*^9}, {3.849287440612916*^9, 3.849287443811935*^9}, {
   3.850663075725994*^9, 3.850663078393785*^9}, {3.850663109792037*^9, 
   3.8506631237943773`*^9}, 3.850731349551284*^9, {3.8507314396485558`*^9, 
   3.8507314436333923`*^9}, 3.850731593749271*^9, 3.85073165749212*^9, 
   3.850731700668015*^9, 3.850731739886565*^9, 3.850731794479561*^9, 
   3.850731870835803*^9, 3.850731929369882*^9, {3.850731982203908*^9, 
   3.8507319856259937`*^9}, 3.850732126065881*^9, 3.85073231882176*^9, {
   3.8507323949742126`*^9, 3.850732404539559*^9}, 3.850732581617426*^9, {
   3.850732684940145*^9, 3.850732687654591*^9}, 3.850818274262387*^9, {
   3.8508385043226748`*^9, 3.850838506625971*^9}, 3.850839040171782*^9, {
   3.8508391299620867`*^9, 3.850839258929307*^9}, {3.85083930558601*^9, 
   3.8508393101043043`*^9}, {3.850839407868465*^9, 3.8508394317993793`*^9}, {
   3.850839499181778*^9, 3.850839500619706*^9}, {3.850839569431451*^9, 
   3.850839570106176*^9}, {3.8508407912806168`*^9, 3.8508408062359467`*^9}, 
   3.850840882857617*^9, 3.850840917668212*^9, {3.850841423503487*^9, 
   3.8508415509968023`*^9}, {3.8508418211026707`*^9, 3.850841916638174*^9}, {
   3.8508420018533897`*^9, 3.850842009047852*^9}, {3.850842144031228*^9, 
   3.8508421689858437`*^9}, {3.850842264729254*^9, 3.8508423350297537`*^9}, {
   3.850842541418743*^9, 3.85084254281358*^9}, {3.850842676749588*^9, 
   3.850842736063715*^9}, {3.8508427791598873`*^9, 3.850842795976921*^9}, {
   3.850842850058255*^9, 3.850842896944067*^9}, 3.8508429650739937`*^9, {
   3.850843002746546*^9, 3.850843007820991*^9}, 3.8508432095861692`*^9, {
   3.8508432583082438`*^9, 3.850843263344789*^9}, 3.850843319188044*^9, {
   3.8508434151520643`*^9, 3.850843424854981*^9}, {3.8508434595071087`*^9, 
   3.8508435087576303`*^9}, {3.85084354480098*^9, 3.850843551718481*^9}, {
   3.850843591882043*^9, 3.85084362800175*^9}, {3.8508440630402393`*^9, 
   3.8508440691741962`*^9}, 3.8508440996807947`*^9, {3.85084413228752*^9, 
   3.850844151386554*^9}, {3.850844198648964*^9, 3.85084420124984*^9}, {
   3.850844258397984*^9, 3.8508443028508472`*^9}, {3.850844390369676*^9, 
   3.850844424722518*^9}, {3.8508445895293493`*^9, 3.850844602253673*^9}, {
   3.85084491110737*^9, 3.8508449520705833`*^9}, {3.850845002871233*^9, 
   3.850845019701494*^9}, {3.850845128231456*^9, 3.8508452075644073`*^9}, {
   3.850845265069853*^9, 3.85084528748676*^9}, {3.850845333533813*^9, 
   3.850845351916027*^9}, {3.850845474755618*^9, 3.8508454923333807`*^9}, {
   3.850845565882367*^9, 3.8508455714135923`*^9}, {3.850845621127068*^9, 
   3.85084570011241*^9}, {3.850845809389262*^9, 3.850845854399037*^9}, {
   3.850845994752474*^9, 3.85084600619312*^9}, {3.85084606491604*^9, 
   3.850846071717469*^9}, {3.85084612496017*^9, 3.850846132785928*^9}, {
   3.850846210720174*^9, 3.850846221067934*^9}, {3.850846258891679*^9, 
   3.850846271039238*^9}, {3.85084637012304*^9, 3.850846370948578*^9}, {
   3.8508464493065987`*^9, 3.850846453818849*^9}, {3.850846560747775*^9, 
   3.85084656748947*^9}, {3.850846642775688*^9, 3.850846661387212*^9}, {
   3.85084670803232*^9, 3.850846712927135*^9}, 3.850846755453293*^9, {
   3.850846788395043*^9, 3.8508467888661537`*^9}, {3.850846940390139*^9, 
   3.850846941167224*^9}, {3.850847025617663*^9, 3.850847057467959*^9}, 
   3.850847090911516*^9, 3.8508472016026278`*^9, {3.850847257114792*^9, 
   3.850847284066197*^9}, 3.85084735659837*^9, {3.850847399971182*^9, 
   3.850847433232511*^9}, {3.850847486361661*^9, 3.850847551848073*^9}, {
   3.8508477133076973`*^9, 3.850847751313118*^9}, {3.850848929298449*^9, 
   3.8508489447145*^9}, {3.85084902469001*^9, 3.8508490287342052`*^9}, {
   3.8508490736797247`*^9, 3.85084907568775*^9}, {3.850849173542747*^9, 
   3.850849175467709*^9}, {3.850849364298305*^9, 3.85084937469118*^9}, {
   3.850849419556528*^9, 3.850849439423908*^9}, {3.850880305546026*^9, 
   3.8508803143915*^9}, {3.850930668123341*^9, 3.850930669794622*^9}, {
   3.850930935456485*^9, 3.8509309773675137`*^9}, 3.850931094753645*^9, {
   3.850931186104979*^9, 3.850931192830029*^9}, {3.850931258865803*^9, 
   3.850931269243393*^9}, {3.85093131129615*^9, 3.8509313124544153`*^9}, {
   3.850931435117271*^9, 3.850931436754678*^9}, {3.850931573803681*^9, 
   3.850931574575164*^9}, 3.85093165013046*^9, {3.850931690582552*^9, 
   3.850931691481407*^9}, {3.850931731990388*^9, 3.850931732679246*^9}, 
   3.850931763324297*^9, 3.850931817803175*^9, {3.8509318592909822`*^9, 
   3.850931893272822*^9}, {3.8509319252977133`*^9, 3.8509319733702097`*^9}, 
   3.850932003787962*^9, 3.850932058374607*^9, {3.850932145644124*^9, 
   3.850932146103835*^9}, {3.850932184952303*^9, 3.850932186504609*^9}, 
   3.8509323025418787`*^9, 3.850932365883658*^9, 3.850932496213018*^9, {
   3.850932677925294*^9, 3.850932680391094*^9}, {3.850932817600075*^9, 
   3.8509328186370993`*^9}, {3.850932869530343*^9, 3.85093287433212*^9}, 
   3.850932946569862*^9, 3.850933020010494*^9, {3.850933056975206*^9, 
   3.850933079062581*^9}, 3.850933115547111*^9, 3.850933175935454*^9, {
   3.850933220806899*^9, 3.850933318774393*^9}, {3.85093336435785*^9, 
   3.850933365429284*^9}, {3.850933445172233*^9, 3.850933473925436*^9}, {
   3.8509335402909184`*^9, 3.850933643707296*^9}, {3.850933676629034*^9, 
   3.850933748031453*^9}, {3.850933798702961*^9, 3.850933806131669*^9}, {
   3.850933874677866*^9, 3.850933877262754*^9}, {3.8509339412863293`*^9, 
   3.850933947421997*^9}, {3.8509339954371157`*^9, 3.850934016539297*^9}, {
   3.850934060876107*^9, 3.850934081062974*^9}, 3.8509341795813503`*^9, {
   3.850934213555254*^9, 3.850934220374529*^9}, {3.8509343110898657`*^9, 
   3.850934313025916*^9}, {3.850934387477466*^9, 3.850934391899962*^9}, {
   3.8509344383262663`*^9, 3.850934469562705*^9}, {3.850934521287223*^9, 
   3.850934524424163*^9}, {3.850934606065447*^9, 3.8509346801870728`*^9}, 
   3.850934759476831*^9, {3.850934853039967*^9, 3.850934854894658*^9}, {
   3.850934918659494*^9, 3.850934919464725*^9}, {3.850935014515499*^9, 
   3.8509350162267838`*^9}, {3.8509351141728907`*^9, 
   3.8509351185148582`*^9}, {3.850935247465824*^9, 3.850935248906683*^9}, {
   3.850935354736215*^9, 3.850935370411767*^9}, {3.850935441989122*^9, 
   3.850935477572506*^9}, {3.85093561102446*^9, 3.8509356131513433`*^9}, {
   3.8509357060405693`*^9, 3.850935709837893*^9}, {3.850936253514409*^9, 
   3.850936254725946*^9}, {3.851016097626369*^9, 3.851016123661759*^9}, {
   3.851020507251132*^9, 3.851020639844939*^9}, {3.8515998374474387`*^9, 
   3.851599837902873*^9}, {3.8515998830306664`*^9, 3.8515999386626263`*^9}, {
   3.8515999707143717`*^9, 3.85160000425393*^9}, {3.851600049258679*^9, 
   3.851600060227377*^9}, {3.851682742163096*^9, 3.851682931968375*^9}, {
   3.8516829982605696`*^9, 3.8516830445347157`*^9}, {3.8516830972438297`*^9, 
   3.851683154695222*^9}, 3.851683203027399*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2, $CellContext`b$$ = 
    3, $CellContext`c$$ = 0.8, $CellContext`d$$ = 2, $CellContext`Eoo$$ = 
    1.76, $CellContext`Eox$$ = 0.605, $CellContext`eps$$ = 
    25.2, $CellContext`epsEC$$ = 
    37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
    1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
    1.528, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
    18, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 300, $CellContext`V$$ = 
    28, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Row[{"oxidation, D, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eox$$], 0.605, ""}, 0, 4, 0.01}, {
      Hold[
       Row[{"reduction, A, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ered$$], -0.57, ""}, -4, 0, 0.01}, {
      Hold[
       Row[{"zero-zero, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eoo$$], 1.76, ""}, 0, 5, 0.01}, {
      Hold[
       Row[{"c to c distance, ", 
         Style["Rc", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rc$$], 18, ""}, 3.6, 80}, {
      Hold[
       Row[{"anion radius, ", 
         Style["r-", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ran$$], 5.6, ""}, 1.8, 30}, {
      Hold[
       Row[{"cation radius, ", 
         Style["r+", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rcat$$], 3.7, ""}, 1.8, 30}, {
      Hold[
       Row[{"internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {
      Hold[
       Row[{"coupling, ", 
         Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 28, ""}, 0.005, 1000, 0.1}, {
      Hold[
       Row[{"eps (solvent) ", 
         Style["\[Epsilon]", Italic], ""}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`eps$$], 25.2, ""}, 1.8, 68}, {{
       Hold[$CellContext`n$$], 1.528, ""}, 1., 3}, {{
       Hold[$CellContext`T$$], 300, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`epsEC$$], 37.5, ""}, 1.8, 68}, {
      Hold[
       Item[
        Row[{
          Row[{"n (solvent) ", 
            Style["n", Italic], ""}], 
          Manipulate`Place[1], 
          Row[{"temp., ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[2], 
          Row[{"epsEC (for EC) ", 
            Style["\[Epsilon]", Italic], ""}], 
          Manipulate`Place[3]}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a$$], 2, "a (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`b$$], 3, "b (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[4], " axis,   ", 
          Style["", Italic], " maximum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[5]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$$], 0.8, "c (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`d$$], 2, "d (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[6], " axis,   ", 
          Style["", Italic], " maximum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[7]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`F$$], 1, ""}, -1, 1, 1}, {
      Hold[
       Item[
        Row[{
         "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
          Style["", Italic], "", 
          Manipulate`Place[8]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 2, $CellContext`b$$ = 
        3, $CellContext`c$$ = 0.8, $CellContext`d$$ = 2, $CellContext`Eoo$$ = 
        1.76, $CellContext`Eox$$ = 0.605, $CellContext`eps$$ = 
        25.2, $CellContext`epsEC$$ = 
        37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
        1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
        1.528, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
        18, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 
        300, $CellContext`V$$ = 28}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Module[{$CellContext`Pa1$, $CellContext`Pa2$, $CellContext`xMin$, \
$CellContext`yMin$, $CellContext`DeltaG$, $CellContext`LambdaT$, \
$CellContext`Ea$, $CellContext`P1$, $CellContext`Y$, $CellContext`LambdaS$, \
$CellContext`KetC$, $CellContext`Kopt$, $CellContext`X$}, $CellContext`Y$ = \
-$CellContext`Eoo$$ + $CellContext`Eox$$ - $CellContext`Ered$$ - \
$CellContext`F$$ (
            14.399645/($CellContext`eps$$ $CellContext`Rc$$)) - \
$CellContext`F$$ (14.399645/2) (-(1/$CellContext`eps$$) + 
            1/$CellContext`epsEC$$) (1/$CellContext`Ran$$ + 
            1/$CellContext`Rcat$$); $CellContext`LambdaS$ = 
          14.399645 (1/(2 $CellContext`Ran$$) + 1/(2 $CellContext`Rcat$$) - 
            1/$CellContext`Rc$$) (1/$CellContext`n$$^2 - 
            1/$CellContext`eps$$); $CellContext`KetC$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 0.000123985^2) $CellContext`V$$^2 
           E^(-(($CellContext`Y$ + $CellContext`LambdaS$ + \
$CellContext`LambdaI$$)^2/(4 
              0.0000861733033 ($CellContext`LambdaS$ + \
$CellContext`LambdaI$$) $CellContext`T$$))); $CellContext`Kopt$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 
            0.000123985^2) $CellContext`V$$^2; $CellContext`X$ = \
$CellContext`LambdaS$ + $CellContext`LambdaI$$; $CellContext`Ea$ = \
($CellContext`Y$ + $CellContext`LambdaI$$ + $CellContext`LambdaS$)^2/(
           4 ($CellContext`LambdaI$$ + $CellContext`LambdaS$)); \
$CellContext`xMin$ = 
          Sqrt[$CellContext`X$]; $CellContext`yMin$ = $CellContext`xMin$^2 - 
           2 Sqrt[$CellContext`X$] $CellContext`xMin$ + $CellContext`X$ + \
$CellContext`Y$; $CellContext`DeltaG$ = $CellContext`yMin$; \
$CellContext`LambdaT$ = $CellContext`xMin$^2; $CellContext`Ea$ = \
($CellContext`DeltaG$ + $CellContext`LambdaT$)^2/(4 $CellContext`LambdaT$); 
         Grid[{{
             
             Row[{$CellContext`Y$, 
               " = \[CapitalDelta]\[ThinSpace]G(eV)    ", $CellContext`X$, 
               " = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    ", \
$CellContext`LambdaS$, " = \[Lambda]s(eV)"}]}, {
             Row[{
               NumberForm[
                N[$CellContext`Ea$], {6, 3}], 
               " = Ea(eV)       ", $CellContext`Kopt$, 
               
               "= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {
             Framed[
              
              Row[{$CellContext`KetC$, 
                "= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\( \)\)]\)Rate of \
electron transfer,(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]]}, {
             
             Plot[{$CellContext`x^2, $CellContext`x^2 - 2 
               Sqrt[$CellContext`X$] $CellContext`x + $CellContext`X$ + \
$CellContext`Y$}, {$CellContext`x, -$CellContext`a$$, $CellContext`b$$}, 
              PlotRange -> {-$CellContext`c$$, $CellContext`d$$}, Epilog -> {{
                 Directive[Black, Thick], 
                 Line[{{0, 0}, {0, $CellContext`yMin$}}]}, {
                 Directive[Blue, Thick], 
                 
                 Line[{{$CellContext`xMin$, 
                    0}, {$CellContext`xMin$, $CellContext`xMin$^2}}]}, {
                 Directive[Red, Thick], 
                 
                 Line[{{$CellContext`Ea$^0.5, $CellContext`Ea$}, \
{$CellContext`Ea$^0.5, 0}}]}}, 
              AxesLabel -> {"reaction coordinate", "free energy, (eV)"}, 
              ImageSize -> 450]}}, Alignment -> Left, Frame -> All]]], 
      "Specifications" :> {
        Row[{"oxidation, D, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eox$$, 0.605, ""}, 0, 4, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"reduction, A, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Ered$$, -0.57, ""}, -4, 0, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"zero-zero, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eoo$$, 1.76, ""}, 0, 5, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"c to c distance, ", 
          Style["Rc", Italic], " (A\[Degree])"}], {{$CellContext`Rc$$, 18, 
          ""}, 3.6, 80, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"anion radius, ", 
          Style["r-", Italic], " (A\[Degree])"}], {{$CellContext`Ran$$, 5.6, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"cation radius, ", 
          Style["r+", Italic], " (A\[Degree])"}], {{$CellContext`Rcat$$, 3.7, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{
         "internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}], \
{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny}, 
        Row[{"coupling, ", 
          Style["V", Italic], 
          " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], {{$CellContext`V$$, 
          28, ""}, 0.005, 1000, 0.1, Appearance -> "Labeled", ImageSize -> 
         Tiny}, 
        Row[{"eps (solvent) ", 
          Style["\[Epsilon]", Italic], ""}], {{$CellContext`eps$$, 25.2, ""}, 
         1.8, 68, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 1.528, ""}, 1., 3, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`T$$, 300, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`epsEC$$, 37.5, ""}, 1.8, 68, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 3}, 
        Item[
         Row[{
           Row[{"n (solvent) ", 
             Style["n", Italic], ""}], 
           Manipulate`Place[1], 
           Row[{"temp., ", 
             Style["T", Italic], " (K)"}], 
           Manipulate`Place[2], 
           Row[{"epsEC (for EC) ", 
             Style["\[Epsilon]", Italic], ""}], 
           Manipulate`Place[3]}], ControlPlacement -> 
         Bottom], {{$CellContext`a$$, 2, "a (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`b$$, 3, "b (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 5}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[4], " axis,   ", 
           Style["", Italic], " maximum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[5]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`c$$, 0.8, "c (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`d$$, 2, "d (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[6], " axis,   ", 
           Style["", Italic], " maximum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[7]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`F$$, 1, ""}, -1, 1, 1, Appearance -> 
         "Labeled", ControlPlacement -> 8}, 
        Item[
         Row[{
          "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
           Style["", Italic], "", 
           Manipulate`Place[8]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom]}, 
      "Options" :> {
       Alignment -> Left, ControlPlacement -> Left, SynchronousUpdating -> 
        False, Frame -> All}, "DefaultOptions" :> {ControllerLinking -> True}],
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->527730449,ExpressionUUID->"ae693cb6-ba72-450e-b1ca-422daa82eaaa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Caption",
 Cell[BoxData[
  TemplateBox[{"Caption", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "The caption provides all the information needed to understand the \
Demonstration. It should be between three and five sentences long, but \
clarity is more important than length. Include only text in this section \
\[LongDash] no code, graphics, etc. Do not change the cell style or copy \
cells from other sections. Do not copy text from books or the web. Write your \
ideas in your own words. If you want to refer to something on the web, link \
to it in the Details.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "a97b5d36-1c59-4018-b3f0-6bfc71662d3d"]
}], "ManipulateCaptionSection",
 CellTags->"Caption",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4"],

Cell[TextData[{
 "With this Demonstration  you can use the Classical Marcus Equation to \
calculate and manipulate the rate of electron transfer (charge separation) by \
using \"molecular parameters\". By using 8 molecular input parameters and 4 \
general input parameters, we can calculate the Gibbs Free energy of electron \
transfer (DeltaG), the barrier (Ea), the total reorganization energy \
(LambdaT) as well as the rate of the charge separation (k",
 Cell[BoxData[
  FormBox["et", TraditionalForm]], "InlineMath",ExpressionUUID->
  "36227a3b-8373-4620-9586-7ac053fce791"],
 "). The pre-exponential factor is the rate that can be obtained if no \
barrier is present (k",
 Cell[BoxData[
  FormBox["opt", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4211c25e-a4ec-4421-9aa9-0f6efe44323d"],
 "). By using the sliders of the manipulators (or changing the values \
manually in the box), we can see the effects of all individual parameters on \
the rates and thermodynamic quantities. The blue curve is the initial \
reactant (locally excited state), the yellow curve is the final product \
(after charge separation). Also presented are the driving force (black), the \
barrier (in red) and the total reorganization energy (in blue) as vertical \
lines. Eox and Ered are the redox data of the donor and acceptor (in same \
solvent with dielectric constant (= epsEC) vs the same reference electrode ), \
Rc = center to center distance, Ran and Rcat are the ionic radii, V =  \
electronic coupling, Li = internal reorganization energy, dielectric \
constants (eps) , refractive index (n). E",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "00"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "aa3dd85a-3423-481e-ba55-f0002536c71b"],
 " = singlet state energy (or triplet state energy) of the system."
}], "ManipulateCaption",
 CellChangeTimes->{
  3.84928489267634*^9, {3.8492849245050173`*^9, 3.849284924505584*^9}, {
   3.849285364114943*^9, 3.849285397458675*^9}, {3.84928544347633*^9, 
   3.849285472228623*^9}, {3.84928562954766*^9, 3.849285662025875*^9}, {
   3.849285812062294*^9, 3.849285919747197*^9}, {3.84928645073186*^9, 
   3.849286457522538*^9}, {3.849287568181405*^9, 3.849287574866727*^9}, {
   3.849287651553747*^9, 
   3.849287670837543*^9}},ExpressionUUID->"71921e4e-c8c2-4f05-96e3-\
4e3047349e9a"],

Cell["\<\
Driving force, total reorganization energy, solvent reorganization energy, \
barrier to electron transfer and the pre-exponential factor are used and \
calculated separately, as shown at the top. The starting data comes from \
C60[11]DMA in benzonitrile solvent, published in 1996 (see below). For \
neutral starting donor and acceptor the Coulomb Correction (F) is 1, for a \
charge shift reaction it is 0, for charged initial reactants (and neutral \
products) it is -1. (see manipulator, F). With  four manipulators you can \
scale the graph. \
\>", "ManipulateCaption",
 CellChangeTimes->{
  3.84928489267634*^9, {3.8492849245050173`*^9, 3.849284924505584*^9}, {
   3.849285364114943*^9, 3.849285396778349*^9}, {3.849285558791024*^9, 
   3.849285581255416*^9}, 3.8492856138416986`*^9, {3.849285693978755*^9, 
   3.849285766442868*^9}, {3.8492859374983883`*^9, 3.8492859651249123`*^9}, {
   3.849286488236271*^9, 3.849286489403781*^9}, {3.849286626905816*^9, 
   3.849286643832704*^9}, {3.84928739466437*^9, 3.8492873956146517`*^9}, {
   3.8492874279120007`*^9, 3.849287428461883*^9}, 3.849288031725088*^9, {
   3.850451849271963*^9, 3.850451873807328*^9}},
 CellID->1123106709,ExpressionUUID->"81ac6df1-7eef-434b-9bf0-af390dcf1f23"],

Cell["\<\
This projects is build upon two Wolfram projects shown below that, to my \
knowledge, have been developed by students. Those projects actually contain a \
minor small mistake (for the barrier), but they gave me a push to develop \
this project. Their adapted code is used in this project. I thank these \
people very much!  \
\>", "ManipulateCaption",
 CellChangeTimes->{
  3.84928489267634*^9, {3.8492849247049932`*^9, 3.84928492470531*^9}, {
   3.84928620271231*^9, 3.849286360864365*^9}, 3.849286512604248*^9, {
   3.849286830901182*^9, 3.849286830901424*^9}, {3.850230239314218*^9, 
   3.8502302421587677`*^9}, {3.850451892122254*^9, 3.850451899610097*^9}, {
   3.8504519319783983`*^9, 3.850451934282221*^9}},
 CellID->701360872,ExpressionUUID->"3e6b90b7-a201-4bda-9d78-01770128f898"],

Cell[TextData[{
 "Nobel Prize winner Rudolph Marcus developed the theory of electron transfer \
[1]. The classical Marcus equation (CME) is based on two simultaneous \
quadratic relations, involving the driving force (",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]", "\[ThinSpace]", "G"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"b25399f8-823d-48a8-8b01-4981300eb8d4"],
 "), the internal and external (solvent) reorganization energy (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "I"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5f81e95a-a78b-44e4-bafe-c0ad4c1bebaf"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "S"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"e9d21e30-8c5c-4fbf-9b87-42a059c7b58f"],
 ") and the electronic coupling (",
 Cell[BoxData[
  FormBox["V", TraditionalForm]], "InlineMath",ExpressionUUID->
  "cc684e44-22b4-4f28-a95f-d20ef5f2285a"],
 "). The CME underestimates the electron transfer rate in the inverted region \
[2, 3]. "
}], "ManipulateCaption",
 CellChangeTimes->{
  3.84928489267634*^9, {3.8492849247049932`*^9, 3.84928492470531*^9}, {
   3.84928620271231*^9, 3.849286360864365*^9}, 3.849286512604248*^9, 
   3.849286832059332*^9, {3.8492868677141314`*^9, 3.849286867714716*^9}},
 CellID->1512240980,ExpressionUUID->"e01ac0e0-26df-411d-b86a-d3a66a83e8b7"],

Cell["\<\
We can also use the so-called Closs and Miller data [4], which provided the \
first experimental proof of the inverted region. This is a charge shift \
reaction, so the Coulomb Correction should be set to zero.  We can approach \
the measured rates [5] by using the appropriate input parameters, like we \
show for C60[11]DMA in benzonitrile for charge separation. Additional \
information on Marcus theory and electron transfer is available in references \
[6\[Dash]9].\
\>", "ManipulateCaption",
 CellChangeTimes->{
  3.84928489267634*^9, 3.849284926200842*^9, 3.8492857849893503`*^9, 
   3.849286755680704*^9, {3.84928722821784*^9, 3.8492872804755507`*^9}, {
   3.8492877134411917`*^9, 3.849287722784644*^9}, {3.849288035735182*^9, 
   3.849288035735588*^9}},
 CellID->1422814127,ExpressionUUID->"9628a6cc-021b-4224-a426-d4ed28d0f1d4"],

Cell["\<\
Some examples using literature data/test data are given below in a link [10]. \
\>", "ManipulateCaption",
 CellChangeTimes->{
  3.84928489267634*^9, 3.849284926200842*^9, 3.8492857849893503`*^9, 
   3.849286755680704*^9, {3.84928722821784*^9, 3.8492872804755507`*^9}, {
   3.8492877134411917`*^9, 3.849287722784644*^9}, {3.849288036723317*^9, 
   3.849288042818481*^9}, {3.851622250656871*^9, 3.851622250657156*^9}},
 CellID->467106557,ExpressionUUID->"3f3c28f5-4bb6-4462-80f5-687f5dcfee71"],

Cell["\<\
Note that under certain 'unrealistic' conditions the reorganization can \
become negative (which makes no physical sense), which results in complex \
number solutions and imaginary electron transfer rates (for example with low \
Rc and high r- and r+ you can get k = 7.875*10^7 - 1.286*10^24 \[ImaginaryI])\
\>", "ManipulateCaption",
 CellChangeTimes->{
  3.851622590143793*^9, {3.851622644603704*^9, 3.851622665691167*^9}},
 CellID->1350886619,ExpressionUUID->"497148e1-3681-40c5-b1c8-58b7405ebc7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Thumbnail",
 Cell[BoxData[
  TemplateBox[{"Thumbnail", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "To create the thumbnail, copy and paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section and adjust the controls to the most visually appealing \
setting. Do not convert it to a bitmap. The thumbnail is what visitors see \
when browsing the Demonstrations site and while the Flash preview loads.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "5363174b-397a-4e31-b8e5-95e1af887bc9"]
}], "ThumbnailSection",
 CellTags->"Thumbnail",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2, $CellContext`b$$ = 
    3, $CellContext`c$$ = 0.8, $CellContext`d$$ = 2, $CellContext`Eoo$$ = 
    1.76, $CellContext`Eox$$ = 0.605, $CellContext`eps$$ = 
    25.2, $CellContext`epsEC$$ = 
    37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
    1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
    1.528, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
    18, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 300, $CellContext`V$$ = 
    28, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Row[{"oxidation, D, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eox$$], 0.605, ""}, 0, 4, 0.01}, {
      Hold[
       Row[{"reduction, A, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ered$$], -0.57, ""}, -4, 0, 0.01}, {
      Hold[
       Row[{"zero-zero, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eoo$$], 1.76, ""}, 0, 5, 0.01}, {
      Hold[
       Row[{"c to c distance, ", 
         Style["Rc", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rc$$], 18, ""}, 3.6, 80}, {
      Hold[
       Row[{"anion radius, ", 
         Style["r-", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ran$$], 5.6, ""}, 1.8, 30}, {
      Hold[
       Row[{"cation radius, ", 
         Style["r+", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rcat$$], 3.7, ""}, 1.8, 30}, {
      Hold[
       Row[{"internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {
      Hold[
       Row[{"coupling, ", 
         Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 28, ""}, 0.005, 1000, 0.1}, {
      Hold[
       Row[{"eps (solvent) ", 
         Style["\[Epsilon]", Italic], ""}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`eps$$], 25.2, ""}, 1.8, 68}, {{
       Hold[$CellContext`n$$], 1.528, ""}, 1., 3}, {{
       Hold[$CellContext`T$$], 300, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`epsEC$$], 37.5, ""}, 1.8, 68}, {
      Hold[
       Item[
        Row[{
          Row[{"n (solvent) ", 
            Style["n", Italic], ""}], 
          Manipulate`Place[1], 
          Row[{"temp., ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[2], 
          Row[{"epsEC (for EC) ", 
            Style["\[Epsilon]", Italic], ""}], 
          Manipulate`Place[3]}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a$$], 2, "a (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`b$$], 3, "b (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[4], " axis,   ", 
          Style["", Italic], " maximum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[5]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$$], 0.8, "c (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`d$$], 2, "d (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[6], " axis,   ", 
          Style["", Italic], " maximum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[7]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`F$$], 1, ""}, -1, 1, 1}, {
      Hold[
       Item[
        Row[{
         "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
          Style["", Italic], "", 
          Manipulate`Place[8]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 2, $CellContext`b$$ = 
        3, $CellContext`c$$ = 0.8, $CellContext`d$$ = 2, $CellContext`Eoo$$ = 
        1.76, $CellContext`Eox$$ = 0.605, $CellContext`eps$$ = 
        25.2, $CellContext`epsEC$$ = 
        37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
        1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
        1.528, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
        18, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 
        300, $CellContext`V$$ = 28}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Module[{$CellContext`Pa1$, $CellContext`Pa2$, $CellContext`xMin$, \
$CellContext`yMin$, $CellContext`DeltaG$, $CellContext`LambdaT$, \
$CellContext`Ea$, $CellContext`P1$, $CellContext`Y$, $CellContext`LambdaS$, \
$CellContext`KetC$, $CellContext`Kopt$, $CellContext`X$}, $CellContext`Y$ = \
-$CellContext`Eoo$$ + $CellContext`Eox$$ - $CellContext`Ered$$ - \
$CellContext`F$$ (
            14.399645/($CellContext`eps$$ $CellContext`Rc$$)) - \
$CellContext`F$$ (14.399645/2) (-(1/$CellContext`eps$$) + 
            1/$CellContext`epsEC$$) (1/$CellContext`Ran$$ + 
            1/$CellContext`Rcat$$); $CellContext`LambdaS$ = 
          14.399645 (1/(2 $CellContext`Ran$$) + 1/(2 $CellContext`Rcat$$) - 
            1/$CellContext`Rc$$) (1/$CellContext`n$$^2 - 
            1/$CellContext`eps$$); $CellContext`KetC$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 0.000123985^2) $CellContext`V$$^2 
           E^(-(($CellContext`Y$ + $CellContext`LambdaS$ + \
$CellContext`LambdaI$$)^2/(4 
              0.0000861733033 ($CellContext`LambdaS$ + \
$CellContext`LambdaI$$) $CellContext`T$$))); $CellContext`Kopt$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 
            0.000123985^2) $CellContext`V$$^2; $CellContext`X$ = \
$CellContext`LambdaS$ + $CellContext`LambdaI$$; $CellContext`Ea$ = \
($CellContext`Y$ + $CellContext`LambdaI$$ + $CellContext`LambdaS$)^2/(
           4 ($CellContext`LambdaI$$ + $CellContext`LambdaS$)); \
$CellContext`xMin$ = 
          Sqrt[$CellContext`X$]; $CellContext`yMin$ = $CellContext`xMin$^2 - 
           2 Sqrt[$CellContext`X$] $CellContext`xMin$ + $CellContext`X$ + \
$CellContext`Y$; $CellContext`DeltaG$ = $CellContext`yMin$; \
$CellContext`LambdaT$ = $CellContext`xMin$^2; $CellContext`Ea$ = \
($CellContext`DeltaG$ + $CellContext`LambdaT$)^2/(4 $CellContext`LambdaT$); 
         Grid[{{
             
             Row[{$CellContext`Y$, 
               " = \[CapitalDelta]\[ThinSpace]G(eV)    ", $CellContext`X$, 
               " = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    ", \
$CellContext`LambdaS$, " = \[Lambda]s(eV)"}]}, {
             Row[{
               NumberForm[
                N[$CellContext`Ea$], {6, 3}], 
               " = Ea(eV)       ", $CellContext`Kopt$, 
               
               "= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {
             Framed[
              
              Row[{$CellContext`KetC$, 
                "= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\( \)\)]\)Rate of \
electron transfer,(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]]}, {
             
             Plot[{$CellContext`x^2, $CellContext`x^2 - 2 
               Sqrt[$CellContext`X$] $CellContext`x + $CellContext`X$ + \
$CellContext`Y$}, {$CellContext`x, -$CellContext`a$$, $CellContext`b$$}, 
              PlotRange -> {-$CellContext`c$$, $CellContext`d$$}, Epilog -> {{
                 Directive[Black, Thick], 
                 Line[{{0, 0}, {0, $CellContext`yMin$}}]}, {
                 Directive[Blue, Thick], 
                 
                 Line[{{$CellContext`xMin$, 
                    0}, {$CellContext`xMin$, $CellContext`xMin$^2}}]}, {
                 Directive[Red, Thick], 
                 
                 Line[{{$CellContext`Ea$^0.5, $CellContext`Ea$}, \
{$CellContext`Ea$^0.5, 0}}]}}, 
              AxesLabel -> {"reaction coordinate", "free energy, (eV)"}, 
              ImageSize -> 450]}}, Alignment -> Left, Frame -> All]]], 
      "Specifications" :> {
        Row[{"oxidation, D, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eox$$, 0.605, ""}, 0, 4, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"reduction, A, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Ered$$, -0.57, ""}, -4, 0, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"zero-zero, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eoo$$, 1.76, ""}, 0, 5, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"c to c distance, ", 
          Style["Rc", Italic], " (A\[Degree])"}], {{$CellContext`Rc$$, 18, 
          ""}, 3.6, 80, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"anion radius, ", 
          Style["r-", Italic], " (A\[Degree])"}], {{$CellContext`Ran$$, 5.6, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"cation radius, ", 
          Style["r+", Italic], " (A\[Degree])"}], {{$CellContext`Rcat$$, 3.7, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{
         "internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}], \
{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny}, 
        Row[{"coupling, ", 
          Style["V", Italic], 
          " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], {{$CellContext`V$$, 
          28, ""}, 0.005, 1000, 0.1, Appearance -> "Labeled", ImageSize -> 
         Tiny}, 
        Row[{"eps (solvent) ", 
          Style["\[Epsilon]", Italic], ""}], {{$CellContext`eps$$, 25.2, ""}, 
         1.8, 68, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 1.528, ""}, 1., 3, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`T$$, 300, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`epsEC$$, 37.5, ""}, 1.8, 68, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 3}, 
        Item[
         Row[{
           Row[{"n (solvent) ", 
             Style["n", Italic], ""}], 
           Manipulate`Place[1], 
           Row[{"temp., ", 
             Style["T", Italic], " (K)"}], 
           Manipulate`Place[2], 
           Row[{"epsEC (for EC) ", 
             Style["\[Epsilon]", Italic], ""}], 
           Manipulate`Place[3]}], ControlPlacement -> 
         Bottom], {{$CellContext`a$$, 2, "a (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`b$$, 3, "b (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 5}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[4], " axis,   ", 
           Style["", Italic], " maximum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[5]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`c$$, 0.8, "c (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`d$$, 2, "d (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[6], " axis,   ", 
           Style["", Italic], " maximum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[7]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`F$$, 1, ""}, -1, 1, 1, Appearance -> 
         "Labeled", ControlPlacement -> 8}, 
        Item[
         Row[{
          "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
           Style["", Italic], "", 
           Manipulate`Place[8]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom]}, 
      "Options" :> {
       Alignment -> Left, ControlPlacement -> Left, SynchronousUpdating -> 
        False, Frame -> All}, "DefaultOptions" :> {ControllerLinking -> True}],
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->349667646,ExpressionUUID->"ea6c80b7-7be3-4c89-8ca7-7de6dd32d2bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Snapshots",
 Cell[BoxData[
  TemplateBox[{"Snapshots", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"To create snapshots, paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section in this section at least three times, and adjust the \
controls of each copy to show a range of interesting settings. Do not convert \
the screenshots to bitmaps. Optional captions for the screenshots may be \
included in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d854de0f-efbb-449a-8b04-a7b3ca5773d5"]
}], "SnapshotsSection",
 CellTags->"Snapshots",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    2, $CellContext`c$$ = 0.6, $CellContext`d$$ = 1.4, $CellContext`Eoo$$ = 
    1.76, $CellContext`Eox$$ = 0.605, $CellContext`eps$$ = 
    25.2, $CellContext`epsEC$$ = 
    37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
    1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
    1.528, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
    18, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 300, $CellContext`V$$ = 
    28, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Row[{"oxidation, D, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eox$$], 0.605, ""}, 0, 4, 0.01}, {
      Hold[
       Row[{"reduction, A, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ered$$], -0.57, ""}, -4, 0, 0.01}, {
      Hold[
       Row[{"zero-zero, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eoo$$], 1.76, ""}, 0, 5, 0.01}, {
      Hold[
       Row[{"c to c distance, ", 
         Style["Rc", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rc$$], 18, ""}, 3.6, 80}, {
      Hold[
       Row[{"anion radius, ", 
         Style["r-", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ran$$], 5.6, ""}, 1.8, 30}, {
      Hold[
       Row[{"cation radius, ", 
         Style["r+", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rcat$$], 3.7, ""}, 1.8, 30}, {
      Hold[
       Row[{"internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {
      Hold[
       Row[{"coupling, ", 
         Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 28, ""}, 0.005, 1000, 0.1}, {
      Hold[
       Row[{"eps (solvent) ", 
         Style["\[Epsilon]", Italic], ""}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`eps$$], 25.2, ""}, 1.8, 68}, {{
       Hold[$CellContext`n$$], 1.528, ""}, 1., 3}, {{
       Hold[$CellContext`T$$], 300, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`epsEC$$], 37.5, ""}, 1.8, 68}, {
      Hold[
       Item[
        Row[{
          Row[{"n (solvent) ", 
            Style["n", Italic], ""}], 
          Manipulate`Place[1], 
          Row[{"temp., ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[2], 
          Row[{"epsEC (for EC) ", 
            Style["\[Epsilon]", Italic], ""}], 
          Manipulate`Place[3]}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a$$], 1, "a (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`b$$], 2, "b (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[4], " axis,   ", 
          Style["", Italic], " maximum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[5]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$$], 0.6, "c (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`d$$], 1.4, "d (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[6], " axis,   ", 
          Style["", Italic], " maximum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[7]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`F$$], 1, ""}, -1, 1, 1}, {
      Hold[
       Item[
        Row[{
         "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
          Style["", Italic], "", 
          Manipulate`Place[8]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        2, $CellContext`c$$ = 0.6, $CellContext`d$$ = 1.4, $CellContext`Eoo$$ = 
        1.76, $CellContext`Eox$$ = 0.605, $CellContext`eps$$ = 
        25.2, $CellContext`epsEC$$ = 
        37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
        1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
        1.528, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
        18, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 
        300, $CellContext`V$$ = 28}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Module[{$CellContext`Pa1$, $CellContext`Pa2$, $CellContext`xMin$, \
$CellContext`yMin$, $CellContext`DeltaG$, $CellContext`LambdaT$, \
$CellContext`Ea$, $CellContext`P1$, $CellContext`Y$, $CellContext`LambdaS$, \
$CellContext`KetC$, $CellContext`Kopt$, $CellContext`X$}, $CellContext`Y$ = \
-$CellContext`Eoo$$ + $CellContext`Eox$$ - $CellContext`Ered$$ - \
$CellContext`F$$ (
            14.399645/($CellContext`eps$$ $CellContext`Rc$$)) - \
$CellContext`F$$ (14.399645/2) (-(1/$CellContext`eps$$) + 
            1/$CellContext`epsEC$$) (1/$CellContext`Ran$$ + 
            1/$CellContext`Rcat$$); $CellContext`LambdaS$ = 
          14.399645 (1/(2 $CellContext`Ran$$) + 1/(2 $CellContext`Rcat$$) - 
            1/$CellContext`Rc$$) (1/$CellContext`n$$^2 - 
            1/$CellContext`eps$$); $CellContext`KetC$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 0.000123985^2) $CellContext`V$$^2 
           E^(-(($CellContext`Y$ + $CellContext`LambdaS$ + \
$CellContext`LambdaI$$)^2/(4 
              0.0000861733033 ($CellContext`LambdaS$ + \
$CellContext`LambdaI$$) $CellContext`T$$))); $CellContext`Kopt$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 
            0.000123985^2) $CellContext`V$$^2; $CellContext`X$ = \
$CellContext`LambdaS$ + $CellContext`LambdaI$$; $CellContext`Ea$ = \
($CellContext`Y$ + $CellContext`LambdaI$$ + $CellContext`LambdaS$)^2/(
           4 ($CellContext`LambdaI$$ + $CellContext`LambdaS$)); \
$CellContext`xMin$ = 
          Sqrt[$CellContext`X$]; $CellContext`yMin$ = $CellContext`xMin$^2 - 
           2 Sqrt[$CellContext`X$] $CellContext`xMin$ + $CellContext`X$ + \
$CellContext`Y$; $CellContext`DeltaG$ = $CellContext`yMin$; \
$CellContext`LambdaT$ = $CellContext`xMin$^2; $CellContext`Ea$ = \
($CellContext`DeltaG$ + $CellContext`LambdaT$)^2/(4 $CellContext`LambdaT$); 
         Grid[{{
             
             Row[{$CellContext`Y$, 
               " = \[CapitalDelta]\[ThinSpace]G(eV)    ", $CellContext`X$, 
               " = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    ", \
$CellContext`LambdaS$, " = \[Lambda]s(eV)"}]}, {
             Row[{
               NumberForm[
                N[$CellContext`Ea$], {6, 3}], 
               " = Ea(eV)       ", $CellContext`Kopt$, 
               "= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {
             Framed[
              
              Row[{$CellContext`KetC$, 
                "= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\( \)\)]\)Rate of \
electron transfer,(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]]}, {
             
             Plot[{$CellContext`x^2, $CellContext`x^2 - 2 
               Sqrt[$CellContext`X$] $CellContext`x + $CellContext`X$ + \
$CellContext`Y$}, {$CellContext`x, -$CellContext`a$$, $CellContext`b$$}, 
              PlotRange -> {-$CellContext`c$$, $CellContext`d$$}, Epilog -> {{
                 Directive[Black, Thick], 
                 Line[{{0, 0}, {0, $CellContext`yMin$}}]}, {
                 Directive[Blue, Thick], 
                 
                 Line[{{$CellContext`xMin$, 
                    0}, {$CellContext`xMin$, $CellContext`xMin$^2}}]}, {
                 Directive[Red, Thick], 
                 
                 Line[{{$CellContext`Ea$^0.5, $CellContext`Ea$}, \
{$CellContext`Ea$^0.5, 0}}]}}, 
              AxesLabel -> {"reaction coordinate", "free energy, (eV)"}, 
              ImageSize -> 450]}}, Alignment -> Left, Frame -> All]]], 
      "Specifications" :> {
        Row[{"oxidation, D, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eox$$, 0.605, ""}, 0, 4, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"reduction, A, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Ered$$, -0.57, ""}, -4, 0, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"zero-zero, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eoo$$, 1.76, ""}, 0, 5, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"c to c distance, ", 
          Style["Rc", Italic], " (A\[Degree])"}], {{$CellContext`Rc$$, 18, 
          ""}, 3.6, 80, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"anion radius, ", 
          Style["r-", Italic], " (A\[Degree])"}], {{$CellContext`Ran$$, 5.6, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"cation radius, ", 
          Style["r+", Italic], " (A\[Degree])"}], {{$CellContext`Rcat$$, 3.7, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{
         "internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}], \
{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny}, 
        Row[{"coupling, ", 
          Style["V", Italic], 
          " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], {{$CellContext`V$$, 
          28, ""}, 0.005, 1000, 0.1, Appearance -> "Labeled", ImageSize -> 
         Tiny}, 
        Row[{"eps (solvent) ", 
          Style["\[Epsilon]", Italic], ""}], {{$CellContext`eps$$, 25.2, ""}, 
         1.8, 68, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 1.528, ""}, 1., 3, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`T$$, 300, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`epsEC$$, 37.5, ""}, 1.8, 68, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 3}, 
        Item[
         Row[{
           Row[{"n (solvent) ", 
             Style["n", Italic], ""}], 
           Manipulate`Place[1], 
           Row[{"temp., ", 
             Style["T", Italic], " (K)"}], 
           Manipulate`Place[2], 
           Row[{"epsEC (for EC) ", 
             Style["\[Epsilon]", Italic], ""}], 
           Manipulate`Place[3]}], ControlPlacement -> 
         Bottom], {{$CellContext`a$$, 1, "a (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`b$$, 2, "b (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 5}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[4], " axis,   ", 
           Style["", Italic], " maximum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[5]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`c$$, 0.6, "c (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`d$$, 1.4, "d (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[6], " axis,   ", 
           Style["", Italic], " maximum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[7]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`F$$, 1, ""}, -1, 1, 1, Appearance -> 
         "Labeled", ControlPlacement -> 8}, 
        Item[
         Row[{
          "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
           Style["", Italic], "", 
           Manipulate`Place[8]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom]}, 
      "Options" :> {
       Alignment -> Left, ControlPlacement -> Left, SynchronousUpdating -> 
        False, Frame -> All}, "DefaultOptions" :> {ControllerLinking -> True}],
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->189306603,ExpressionUUID->"d007968d-da8b-4dfe-abbf-2efbd7e29b99"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    1.5, $CellContext`c$$ = 0.5, $CellContext`d$$ = 0.4, $CellContext`Eoo$$ = 
    1.76, $CellContext`Eox$$ = 0.16, $CellContext`eps$$ = 
    2.38, $CellContext`epsEC$$ = 
    37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
    1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
    1.497, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
    9, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 300, $CellContext`V$$ = 
    97.1, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Row[{"oxidation, D, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eox$$], 0.16, ""}, 0, 4, 0.01}, {
      Hold[
       Row[{"reduction, A, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ered$$], -0.57, ""}, -4, 0, 0.01}, {
      Hold[
       Row[{"zero-zero, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eoo$$], 1.76, ""}, 0, 5, 0.01}, {
      Hold[
       Row[{"c to c distance, ", 
         Style["Rc", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rc$$], 9, ""}, 3.6, 80}, {
      Hold[
       Row[{"anion radius, ", 
         Style["r-", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ran$$], 5.6, ""}, 1.8, 30}, {
      Hold[
       Row[{"cation radius, ", 
         Style["r+", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rcat$$], 3.7, ""}, 1.8, 30}, {
      Hold[
       Row[{"internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {
      Hold[
       Row[{"coupling, ", 
         Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 97.1, ""}, 0.005, 1000, 0.1}, {
      Hold[
       Row[{"eps (solvent) ", 
         Style["\[Epsilon]", Italic], ""}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`eps$$], 2.38, ""}, 1.8, 68}, {{
       Hold[$CellContext`n$$], 1.497, ""}, 1., 3}, {{
       Hold[$CellContext`T$$], 300, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`epsEC$$], 37.5, ""}, 1.8, 68}, {
      Hold[
       Item[
        Row[{
          Row[{"n (solvent) ", 
            Style["n", Italic], ""}], 
          Manipulate`Place[1], 
          Row[{"temp., ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[2], 
          Row[{"epsEC (for EC) ", 
            Style["\[Epsilon]", Italic], ""}], 
          Manipulate`Place[3]}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a$$], 1, "a (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`b$$], 1.5, "b (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[4], " axis,   ", 
          Style["", Italic], " maximum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[5]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$$], 0.5, "c (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`d$$], 0.4, "d (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[6], " axis,   ", 
          Style["", Italic], " maximum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[7]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`F$$], 1, ""}, -1, 1, 1}, {
      Hold[
       Item[
        Row[{
         "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
          Style["", Italic], "", 
          Manipulate`Place[8]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        1.5, $CellContext`c$$ = 0.5, $CellContext`d$$ = 
        0.4, $CellContext`Eoo$$ = 1.76, $CellContext`Eox$$ = 
        0.16, $CellContext`eps$$ = 2.38, $CellContext`epsEC$$ = 
        37.5, $CellContext`Ered$$ = -0.57, $CellContext`F$$ = 
        1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
        1.497, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
        9, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 
        300, $CellContext`V$$ = 97.1}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Module[{$CellContext`Pa1$, $CellContext`Pa2$, $CellContext`xMin$, \
$CellContext`yMin$, $CellContext`DeltaG$, $CellContext`LambdaT$, \
$CellContext`Ea$, $CellContext`P1$, $CellContext`Y$, $CellContext`LambdaS$, \
$CellContext`KetC$, $CellContext`Kopt$, $CellContext`X$}, $CellContext`Y$ = \
-$CellContext`Eoo$$ + $CellContext`Eox$$ - $CellContext`Ered$$ - \
$CellContext`F$$ (
            14.399645/($CellContext`eps$$ $CellContext`Rc$$)) - \
$CellContext`F$$ (14.399645/2) (-(1/$CellContext`eps$$) + 
            1/$CellContext`epsEC$$) (1/$CellContext`Ran$$ + 
            1/$CellContext`Rcat$$); $CellContext`LambdaS$ = 
          14.399645 (1/(2 $CellContext`Ran$$) + 1/(2 $CellContext`Rcat$$) - 
            1/$CellContext`Rc$$) (1/$CellContext`n$$^2 - 
            1/$CellContext`eps$$); $CellContext`KetC$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 0.000123985^2) $CellContext`V$$^2 
           E^(-(($CellContext`Y$ + $CellContext`LambdaS$ + \
$CellContext`LambdaI$$)^2/(4 
              0.0000861733033 ($CellContext`LambdaS$ + \
$CellContext`LambdaI$$) $CellContext`T$$))); $CellContext`Kopt$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 
            0.000123985^2) $CellContext`V$$^2; $CellContext`X$ = \
$CellContext`LambdaS$ + $CellContext`LambdaI$$; $CellContext`Ea$ = \
($CellContext`Y$ + $CellContext`LambdaI$$ + $CellContext`LambdaS$)^2/(
           4 ($CellContext`LambdaI$$ + $CellContext`LambdaS$)); \
$CellContext`xMin$ = 
          Sqrt[$CellContext`X$]; $CellContext`yMin$ = $CellContext`xMin$^2 - 
           2 Sqrt[$CellContext`X$] $CellContext`xMin$ + $CellContext`X$ + \
$CellContext`Y$; $CellContext`DeltaG$ = $CellContext`yMin$; \
$CellContext`LambdaT$ = $CellContext`xMin$^2; $CellContext`Ea$ = \
($CellContext`DeltaG$ + $CellContext`LambdaT$)^2/(4 $CellContext`LambdaT$); 
         Grid[{{
             
             Row[{$CellContext`Y$, 
               " = \[CapitalDelta]\[ThinSpace]G(eV)    ", $CellContext`X$, 
               " = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    ", \
$CellContext`LambdaS$, " = \[Lambda]s(eV)"}]}, {
             Row[{
               NumberForm[
                N[$CellContext`Ea$], {6, 3}], 
               " = Ea(eV)       ", $CellContext`Kopt$, 
               "= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {
             Framed[
              
              Row[{$CellContext`KetC$, 
                "= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\( \)\)]\)Rate of \
electron transfer,(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]]}, {
             
             Plot[{$CellContext`x^2, $CellContext`x^2 - 2 
               Sqrt[$CellContext`X$] $CellContext`x + $CellContext`X$ + \
$CellContext`Y$}, {$CellContext`x, -$CellContext`a$$, $CellContext`b$$}, 
              PlotRange -> {-$CellContext`c$$, $CellContext`d$$}, Epilog -> {{
                 Directive[Black, Thick], 
                 Line[{{0, 0}, {0, $CellContext`yMin$}}]}, {
                 Directive[Blue, Thick], 
                 
                 Line[{{$CellContext`xMin$, 
                    0}, {$CellContext`xMin$, $CellContext`xMin$^2}}]}, {
                 Directive[Red, Thick], 
                 
                 Line[{{$CellContext`Ea$^0.5, $CellContext`Ea$}, \
{$CellContext`Ea$^0.5, 0}}]}}, 
              AxesLabel -> {"reaction coordinate", "free energy, (eV)"}, 
              ImageSize -> 450]}}, Alignment -> Left, Frame -> All]]], 
      "Specifications" :> {
        Row[{"oxidation, D, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eox$$, 0.16, ""}, 0, 4, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"reduction, A, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Ered$$, -0.57, ""}, -4, 0, 0.01, 
         Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"zero-zero, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eoo$$, 1.76, ""}, 0, 5, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"c to c distance, ", 
          Style["Rc", Italic], " (A\[Degree])"}], {{$CellContext`Rc$$, 9, ""},
          3.6, 80, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"anion radius, ", 
          Style["r-", Italic], " (A\[Degree])"}], {{$CellContext`Ran$$, 5.6, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"cation radius, ", 
          Style["r+", Italic], " (A\[Degree])"}], {{$CellContext`Rcat$$, 3.7, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{
         "internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}], \
{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny}, 
        Row[{"coupling, ", 
          Style["V", Italic], 
          " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], {{$CellContext`V$$, 
          97.1, ""}, 0.005, 1000, 0.1, Appearance -> "Labeled", ImageSize -> 
         Tiny}, 
        Row[{"eps (solvent) ", 
          Style["\[Epsilon]", Italic], ""}], {{$CellContext`eps$$, 2.38, ""}, 
         1.8, 68, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 1.497, ""}, 1., 3, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`T$$, 300, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`epsEC$$, 37.5, ""}, 1.8, 68, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 3}, 
        Item[
         Row[{
           Row[{"n (solvent) ", 
             Style["n", Italic], ""}], 
           Manipulate`Place[1], 
           Row[{"temp., ", 
             Style["T", Italic], " (K)"}], 
           Manipulate`Place[2], 
           Row[{"epsEC (for EC) ", 
             Style["\[Epsilon]", Italic], ""}], 
           Manipulate`Place[3]}], ControlPlacement -> 
         Bottom], {{$CellContext`a$$, 1, "a (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`b$$, 1.5, "b (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 5}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[4], " axis,   ", 
           Style["", Italic], " maximum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[5]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`c$$, 0.5, "c (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`d$$, 0.4, "d (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[6], " axis,   ", 
           Style["", Italic], " maximum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[7]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`F$$, 1, ""}, -1, 1, 1, Appearance -> 
         "Labeled", ControlPlacement -> 8}, 
        Item[
         Row[{
          "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
           Style["", Italic], "", 
           Manipulate`Place[8]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom]}, 
      "Options" :> {
       Alignment -> Left, ControlPlacement -> Left, SynchronousUpdating -> 
        False, Frame -> All}, "DefaultOptions" :> {ControllerLinking -> True}],
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->572002538,ExpressionUUID->"5f141c5f-8e9b-46b8-bffc-af3b877c7c74"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1.5, $CellContext`b$$ = 
    3.000000000000347, $CellContext`c$$ = 
    2.600000000000203, $CellContext`d$$ = 1.3, $CellContext`Eoo$$ = 
    2.4, $CellContext`Eox$$ = 0., $CellContext`eps$$ = 
    6.2, $CellContext`epsEC$$ = 6.2, $CellContext`Ered$$ = 
    0., $CellContext`F$$ = 0, $CellContext`LambdaI$$ = 
    0.45, $CellContext`n$$ = 1.406, $CellContext`Ran$$ = 
    4.8, $CellContext`Rc$$ = 17.4, $CellContext`Rcat$$ = 
    4.78, $CellContext`T$$ = 296, $CellContext`V$$ = 6.2, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Row[{"oxidation, D, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eox$$], 0., ""}, 0, 4, 0.01}, {
      Hold[
       Row[{"reduction, A, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ered$$], 0., ""}, -4, 0, 0.01}, {
      Hold[
       Row[{"zero-zero, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eoo$$], 2.4, ""}, 0, 5, 0.01}, {
      Hold[
       Row[{"c to c distance, ", 
         Style["Rc", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rc$$], 17.4, ""}, 3.6, 80}, {
      Hold[
       Row[{"anion radius, ", 
         Style["r-", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ran$$], 4.8, ""}, 1.8, 30}, {
      Hold[
       Row[{"cation radius, ", 
         Style["r+", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rcat$$], 4.78, ""}, 1.8, 30}, {
      Hold[
       Row[{"internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`LambdaI$$], 0.45, ""}, 0.0001, 2, 0.01}, {
      Hold[
       Row[{"coupling, ", 
         Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 6.2, ""}, 0.005, 1000, 0.1}, {
      Hold[
       Row[{"eps (solvent) ", 
         Style["\[Epsilon]", Italic], ""}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`eps$$], 6.2, ""}, 1.8, 68}, {{
       Hold[$CellContext`n$$], 1.406, ""}, 1., 3}, {{
       Hold[$CellContext`T$$], 296, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`epsEC$$], 6.2, ""}, 1.8, 68}, {
      Hold[
       Item[
        Row[{
          Row[{"n (solvent) ", 
            Style["n", Italic], ""}], 
          Manipulate`Place[1], 
          Row[{"temp., ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[2], 
          Row[{"epsEC (for EC) ", 
            Style["\[Epsilon]", Italic], ""}], 
          Manipulate`Place[3]}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a$$], 1.5, "a (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`b$$], 3.000000000000347, "b (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[4], " axis,   ", 
          Style["", Italic], " maximum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[5]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$$], 2.600000000000203, "c (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`d$$], 1.3, "d (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[6], " axis,   ", 
          Style["", Italic], " maximum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[7]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`F$$], 0, ""}, -1, 1, 1}, {
      Hold[
       Item[
        Row[{
         "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
          Style["", Italic], "", 
          Manipulate`Place[8]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1.5, $CellContext`b$$ = 
        3.000000000000347, $CellContext`c$$ = 
        2.600000000000203, $CellContext`d$$ = 1.3, $CellContext`Eoo$$ = 
        2.4, $CellContext`Eox$$ = 0., $CellContext`eps$$ = 
        6.2, $CellContext`epsEC$$ = 6.2, $CellContext`Ered$$ = 
        0., $CellContext`F$$ = 0, $CellContext`LambdaI$$ = 
        0.45, $CellContext`n$$ = 1.406, $CellContext`Ran$$ = 
        4.8, $CellContext`Rc$$ = 17.4, $CellContext`Rcat$$ = 
        4.78, $CellContext`T$$ = 296, $CellContext`V$$ = 6.2}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Module[{$CellContext`Pa1$, $CellContext`Pa2$, $CellContext`xMin$, \
$CellContext`yMin$, $CellContext`DeltaG$, $CellContext`LambdaT$, \
$CellContext`Ea$, $CellContext`P1$, $CellContext`Y$, $CellContext`LambdaS$, \
$CellContext`KetC$, $CellContext`Kopt$, $CellContext`X$}, $CellContext`Y$ = \
-$CellContext`Eoo$$ + $CellContext`Eox$$ - $CellContext`Ered$$ - \
$CellContext`F$$ (
            14.399645/($CellContext`eps$$ $CellContext`Rc$$)) - \
$CellContext`F$$ (14.399645/2) (-(1/$CellContext`eps$$) + 
            1/$CellContext`epsEC$$) (1/$CellContext`Ran$$ + 
            1/$CellContext`Rcat$$); $CellContext`LambdaS$ = 
          14.399645 (1/(2 $CellContext`Ran$$) + 1/(2 $CellContext`Rcat$$) - 
            1/$CellContext`Rc$$) (1/$CellContext`n$$^2 - 
            1/$CellContext`eps$$); $CellContext`KetC$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 0.000123985^2) $CellContext`V$$^2 
           E^(-(($CellContext`Y$ + $CellContext`LambdaS$ + \
$CellContext`LambdaI$$)^2/(4 
              0.0000861733033 ($CellContext`LambdaS$ + \
$CellContext`LambdaI$$) $CellContext`T$$))); $CellContext`Kopt$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 
            0.000123985^2) $CellContext`V$$^2; $CellContext`X$ = \
$CellContext`LambdaS$ + $CellContext`LambdaI$$; $CellContext`Ea$ = \
($CellContext`Y$ + $CellContext`LambdaI$$ + $CellContext`LambdaS$)^2/(
           4 ($CellContext`LambdaI$$ + $CellContext`LambdaS$)); \
$CellContext`xMin$ = 
          Sqrt[$CellContext`X$]; $CellContext`yMin$ = $CellContext`xMin$^2 - 
           2 Sqrt[$CellContext`X$] $CellContext`xMin$ + $CellContext`X$ + \
$CellContext`Y$; $CellContext`DeltaG$ = $CellContext`yMin$; \
$CellContext`LambdaT$ = $CellContext`xMin$^2; $CellContext`Ea$ = \
($CellContext`DeltaG$ + $CellContext`LambdaT$)^2/(4 $CellContext`LambdaT$); 
         Grid[{{
             
             Row[{$CellContext`Y$, 
               " = \[CapitalDelta]\[ThinSpace]G(eV)    ", $CellContext`X$, 
               " = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    ", \
$CellContext`LambdaS$, " = \[Lambda]s(eV)"}]}, {
             Row[{
               NumberForm[
                N[$CellContext`Ea$], {6, 3}], 
               " = Ea(eV)       ", $CellContext`Kopt$, 
               "= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {
             Framed[
              
              Row[{$CellContext`KetC$, 
                "= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\( \)\)]\)Rate of \
electron transfer,(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]]}, {
             
             Plot[{$CellContext`x^2, $CellContext`x^2 - 2 
               Sqrt[$CellContext`X$] $CellContext`x + $CellContext`X$ + \
$CellContext`Y$}, {$CellContext`x, -$CellContext`a$$, $CellContext`b$$}, 
              PlotRange -> {-$CellContext`c$$, $CellContext`d$$}, Epilog -> {{
                 Directive[Black, Thick], 
                 Line[{{0, 0}, {0, $CellContext`yMin$}}]}, {
                 Directive[Blue, Thick], 
                 
                 Line[{{$CellContext`xMin$, 
                    0}, {$CellContext`xMin$, $CellContext`xMin$^2}}]}, {
                 Directive[Red, Thick], 
                 
                 Line[{{$CellContext`Ea$^0.5, $CellContext`Ea$}, \
{$CellContext`Ea$^0.5, 0}}]}}, 
              AxesLabel -> {"reaction coordinate", "free energy, (eV)"}, 
              ImageSize -> 450]}}, Alignment -> Left, Frame -> All]]], 
      "Specifications" :> {
        Row[{"oxidation, D, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eox$$, 0., ""}, 0, 4, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"reduction, A, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Ered$$, 0., ""}, -4, 0, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"zero-zero, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eoo$$, 2.4, ""}, 0, 5, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"c to c distance, ", 
          Style["Rc", Italic], " (A\[Degree])"}], {{$CellContext`Rc$$, 17.4, 
          ""}, 3.6, 80, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"anion radius, ", 
          Style["r-", Italic], " (A\[Degree])"}], {{$CellContext`Ran$$, 4.8, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"cation radius, ", 
          Style["r+", Italic], " (A\[Degree])"}], {{$CellContext`Rcat$$, 4.78,
           ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{
         "internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}], \
{{$CellContext`LambdaI$$, 0.45, ""}, 0.0001, 2, 0.01, Appearance -> "Labeled",
          ImageSize -> Tiny}, 
        Row[{"coupling, ", 
          Style["V", Italic], 
          " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], {{$CellContext`V$$, 
          6.2, ""}, 0.005, 1000, 0.1, Appearance -> "Labeled", ImageSize -> 
         Tiny}, 
        Row[{"eps (solvent) ", 
          Style["\[Epsilon]", Italic], ""}], {{$CellContext`eps$$, 6.2, ""}, 
         1.8, 68, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 1.406, ""}, 1., 3, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`T$$, 296, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`epsEC$$, 6.2, ""}, 1.8, 68, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 3}, 
        Item[
         Row[{
           Row[{"n (solvent) ", 
             Style["n", Italic], ""}], 
           Manipulate`Place[1], 
           Row[{"temp., ", 
             Style["T", Italic], " (K)"}], 
           Manipulate`Place[2], 
           Row[{"epsEC (for EC) ", 
             Style["\[Epsilon]", Italic], ""}], 
           Manipulate`Place[3]}], ControlPlacement -> 
         Bottom], {{$CellContext`a$$, 1.5, "a (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`b$$, 3.000000000000347, "b (eV)"}, 0.01, 40, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 5}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[4], " axis,   ", 
           Style["", Italic], " maximum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[5]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`c$$, 2.600000000000203, "c (eV)"}, 0.01, 40, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`d$$, 1.3, "d (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[6], " axis,   ", 
           Style["", Italic], " maximum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[7]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`F$$, 0, ""}, -1, 1, 1, Appearance -> 
         "Labeled", ControlPlacement -> 8}, 
        Item[
         Row[{
          "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
           Style["", Italic], "", 
           Manipulate`Place[8]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom]}, 
      "Options" :> {
       Alignment -> Left, ControlPlacement -> Left, SynchronousUpdating -> 
        False, Frame -> All}, "DefaultOptions" :> {ControllerLinking -> True}],
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->724378501,ExpressionUUID->"39f83618-199e-4e7b-8f76-a775b8c12772"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    2, $CellContext`c$$ = 1.5, $CellContext`d$$ = 1, $CellContext`Eoo$$ = 
    2.66, $CellContext`Eox$$ = 0.16, $CellContext`eps$$ = 
    2.38, $CellContext`epsEC$$ = 
    37.5, $CellContext`Ered$$ = -0.5699999999999998, $CellContext`F$$ = 
    1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
    1.497, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
    9, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 300, $CellContext`V$$ = 
    97.1, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Row[{"oxidation, D, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eox$$], 0.16, ""}, 0, 4, 0.01}, {
      Hold[
       Row[{"reduction, A, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ered$$], -0.5699999999999998, ""}, -4, 0, 0.01}, {
      Hold[
       Row[{"zero-zero, ", 
         Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], " (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Eoo$$], 2.66, ""}, 0, 5, 0.01}, {
      Hold[
       Row[{"c to c distance, ", 
         Style["Rc", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rc$$], 9, ""}, 3.6, 80}, {
      Hold[
       Row[{"anion radius, ", 
         Style["r-", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Ran$$], 5.6, ""}, 1.8, 30}, {
      Hold[
       Row[{"cation radius, ", 
         Style["r+", Italic], " (A\[Degree])"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`Rcat$$], 3.7, ""}, 1.8, 30}, {
      Hold[
       Row[{"internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`LambdaI$$], 0.3, ""}, 0.0001, 2, 0.01}, {
      Hold[
       Row[{"coupling, ", 
         Style["V", Italic], " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 97.1, ""}, 0.005, 1000, 0.1}, {
      Hold[
       Row[{"eps (solvent) ", 
         Style["\[Epsilon]", Italic], ""}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`eps$$], 2.38, ""}, 1.8, 68}, {{
       Hold[$CellContext`n$$], 1.497, ""}, 1., 3}, {{
       Hold[$CellContext`T$$], 300, ""}, 4, 1000, 1}, {{
       Hold[$CellContext`epsEC$$], 37.5, ""}, 1.8, 68}, {
      Hold[
       Item[
        Row[{
          Row[{"n (solvent) ", 
            Style["n", Italic], ""}], 
          Manipulate`Place[1], 
          Row[{"temp., ", 
            Style["T", Italic], " (K)"}], 
          Manipulate`Place[2], 
          Row[{"epsEC (for EC) ", 
            Style["\[Epsilon]", Italic], ""}], 
          Manipulate`Place[3]}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a$$], 1, "a (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`b$$], 2, "b (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[4], " axis,   ", 
          Style["", Italic], " maximum (x) ", 
          Style["", Italic], "", 
          Manipulate`Place[5]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c$$], 1.5, "c (eV)"}, 0.01, 40}, {{
       Hold[$CellContext`d$$], 1, "d (eV)"}, 0.01, 40}, {
      Hold[
       Item[
        Row[{" axis,   ", 
          Style["", Italic], " minimum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[6], " axis,   ", 
          Style["", Italic], " maximum (y) ", 
          Style["", Italic], "", 
          Manipulate`Place[7]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`F$$], 1, ""}, -1, 1, 1}, {
      Hold[
       Item[
        Row[{
         "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
          Style["", Italic], "", 
          Manipulate`Place[8]}, BaseStyle -> 10]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        2, $CellContext`c$$ = 1.5, $CellContext`d$$ = 1, $CellContext`Eoo$$ = 
        2.66, $CellContext`Eox$$ = 0.16, $CellContext`eps$$ = 
        2.38, $CellContext`epsEC$$ = 
        37.5, $CellContext`Ered$$ = -0.5699999999999998, $CellContext`F$$ = 
        1, $CellContext`LambdaI$$ = 0.3, $CellContext`n$$ = 
        1.497, $CellContext`Ran$$ = 5.6, $CellContext`Rc$$ = 
        9, $CellContext`Rcat$$ = 3.7, $CellContext`T$$ = 
        300, $CellContext`V$$ = 97.1}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Module[{$CellContext`Pa1$, $CellContext`Pa2$, $CellContext`xMin$, \
$CellContext`yMin$, $CellContext`DeltaG$, $CellContext`LambdaT$, \
$CellContext`Ea$, $CellContext`P1$, $CellContext`Y$, $CellContext`LambdaS$, \
$CellContext`KetC$, $CellContext`Kopt$, $CellContext`X$}, $CellContext`Y$ = \
-$CellContext`Eoo$$ + $CellContext`Eox$$ - $CellContext`Ered$$ - \
$CellContext`F$$ (
            14.399645/($CellContext`eps$$ $CellContext`Rc$$)) - \
$CellContext`F$$ (14.399645/2) (-(1/$CellContext`eps$$) + 
            1/$CellContext`epsEC$$) (1/$CellContext`Ran$$ + 
            1/$CellContext`Rcat$$); $CellContext`LambdaS$ = 
          14.399645 (1/(2 $CellContext`Ran$$) + 1/(2 $CellContext`Rcat$$) - 
            1/$CellContext`Rc$$) (1/$CellContext`n$$^2 - 
            1/$CellContext`eps$$); $CellContext`KetC$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 0.000123985^2) $CellContext`V$$^2 
           E^(-(($CellContext`Y$ + $CellContext`LambdaS$ + \
$CellContext`LambdaI$$)^2/(4 
              0.0000861733033 ($CellContext`LambdaS$ + \
$CellContext`LambdaI$$) $CellContext`T$$))); $CellContext`Kopt$ = (1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 (0.0000861733033 ($CellContext`LambdaS$ + $CellContext`LambdaI$$) \
$CellContext`T$$)^0.5)) (2 Pi^(3/2) 
            0.000123985^2) $CellContext`V$$^2; $CellContext`X$ = \
$CellContext`LambdaS$ + $CellContext`LambdaI$$; $CellContext`Ea$ = \
($CellContext`Y$ + $CellContext`LambdaI$$ + $CellContext`LambdaS$)^2/(
           4 ($CellContext`LambdaI$$ + $CellContext`LambdaS$)); \
$CellContext`xMin$ = 
          Sqrt[$CellContext`X$]; $CellContext`yMin$ = $CellContext`xMin$^2 - 
           2 Sqrt[$CellContext`X$] $CellContext`xMin$ + $CellContext`X$ + \
$CellContext`Y$; $CellContext`DeltaG$ = $CellContext`yMin$; \
$CellContext`LambdaT$ = $CellContext`xMin$^2; $CellContext`Ea$ = \
($CellContext`DeltaG$ + $CellContext`LambdaT$)^2/(4 $CellContext`LambdaT$); 
         Grid[{{
             
             Row[{$CellContext`Y$, 
               " = \[CapitalDelta]\[ThinSpace]G(eV)    ", $CellContext`X$, 
               " = \!\(\*SubscriptBox[\(\[Lambda]\), \(T\)]\)(eV)    ", \
$CellContext`LambdaS$, " = \[Lambda]s(eV)"}]}, {
             Row[{
               NumberForm[
                N[$CellContext`Ea$], {6, 3}], 
               " = Ea(eV)       ", $CellContext`Kopt$, 
               "= \!\(\*SubscriptBox[\(k\), \
\(opt\)]\)(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]}, {
             Framed[
              
              Row[{$CellContext`KetC$, 
                "= \!\(\*SubscriptBox[\(k\), \(\(ET\)\(,\)\( \)\)]\)Rate of \
electron transfer,(\!\(\*SuperscriptBox[\(s\), \(-1\)]\))"}]]}, {
             
             Plot[{$CellContext`x^2, $CellContext`x^2 - 2 
               Sqrt[$CellContext`X$] $CellContext`x + $CellContext`X$ + \
$CellContext`Y$}, {$CellContext`x, -$CellContext`a$$, $CellContext`b$$}, 
              PlotRange -> {-$CellContext`c$$, $CellContext`d$$}, Epilog -> {{
                 Directive[Black, Thick], 
                 Line[{{0, 0}, {0, $CellContext`yMin$}}]}, {
                 Directive[Blue, Thick], 
                 
                 Line[{{$CellContext`xMin$, 
                    0}, {$CellContext`xMin$, $CellContext`xMin$^2}}]}, {
                 Directive[Red, Thick], 
                 
                 Line[{{$CellContext`Ea$^0.5, $CellContext`Ea$}, \
{$CellContext`Ea$^0.5, 0}}]}}, 
              AxesLabel -> {"reaction coordinate", "free energy, (eV)"}, 
              ImageSize -> 450]}}, Alignment -> Left, Frame -> All]]], 
      "Specifications" :> {
        Row[{"oxidation, D, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(ox\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eox$$, 0.16, ""}, 0, 4, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"reduction, A, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(red\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Ered$$, -0.5699999999999998, ""}, -4, 0, 
         0.01, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"zero-zero, ", 
          Style["\!\(\*SubscriptBox[\(E\), \(00\)]\)", Italic], 
          " (eV)"}], {{$CellContext`Eoo$$, 2.66, ""}, 0, 5, 0.01, Appearance -> 
         "Labeled", ImageSize -> Tiny}, 
        Row[{"c to c distance, ", 
          Style["Rc", Italic], " (A\[Degree])"}], {{$CellContext`Rc$$, 9, ""},
          3.6, 80, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"anion radius, ", 
          Style["r-", Italic], " (A\[Degree])"}], {{$CellContext`Ran$$, 5.6, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{"cation radius, ", 
          Style["r+", Italic], " (A\[Degree])"}], {{$CellContext`Rcat$$, 3.7, 
          ""}, 1.8, 30, Appearance -> "Labeled", ImageSize -> Tiny}, 
        Row[{
         "internal , \!\(\*SubscriptBox[\(\[Lambda]\), \(i\)]\) (eV)"}], \
{{$CellContext`LambdaI$$, 0.3, ""}, 0.0001, 2, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny}, 
        Row[{"coupling, ", 
          Style["V", Italic], 
          " (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}], {{$CellContext`V$$, 
          97.1, ""}, 0.005, 1000, 0.1, Appearance -> "Labeled", ImageSize -> 
         Tiny}, 
        Row[{"eps (solvent) ", 
          Style["\[Epsilon]", Italic], ""}], {{$CellContext`eps$$, 2.38, ""}, 
         1.8, 68, Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 1.497, ""}, 1., 3, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`T$$, 300, ""}, 4, 1000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`epsEC$$, 37.5, ""}, 1.8, 68, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 3}, 
        Item[
         Row[{
           Row[{"n (solvent) ", 
             Style["n", Italic], ""}], 
           Manipulate`Place[1], 
           Row[{"temp., ", 
             Style["T", Italic], " (K)"}], 
           Manipulate`Place[2], 
           Row[{"epsEC (for EC) ", 
             Style["\[Epsilon]", Italic], ""}], 
           Manipulate`Place[3]}], ControlPlacement -> 
         Bottom], {{$CellContext`a$$, 1, "a (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`b$$, 2, "b (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 5}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[4], " axis,   ", 
           Style["", Italic], " maximum (x) ", 
           Style["", Italic], "", 
           Manipulate`Place[5]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`c$$, 1.5, "c (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`d$$, 1, "d (eV)"}, 0.01, 40, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 7}, 
        Item[
         Row[{" axis,   ", 
           Style["", Italic], " minimum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[6], " axis,   ", 
           Style["", Italic], " maximum (y) ", 
           Style["", Italic], "", 
           Manipulate`Place[7]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom], {{$CellContext`F$$, 1, ""}, -1, 1, 1, Appearance -> 
         "Labeled", ControlPlacement -> 8}, 
        Item[
         Row[{
          "Coulomb Correction: -1 (neutral products), 0 (charge shift), 1 \
(neutral start)", 
           Style["", Italic], "", 
           Manipulate`Place[8]}, BaseStyle -> 10], ControlPlacement -> 
         Bottom]}, 
      "Options" :> {
       Alignment -> Left, ControlPlacement -> Left, SynchronousUpdating -> 
        False, Frame -> All}, "DefaultOptions" :> {ControllerLinking -> True}],
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->641216097,ExpressionUUID->"1840434a-aa53-4a8d-a4ce-bbc9427cfe63"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Details",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Details", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "This optional section is for a more detailed description of the \
Demonstration than the caption, but it should still be as concise as \
possible. This section may also include numbered snapshot captions (e.g., \
Snapshot 1: phrase or sentence without an initial capital and without a \
period, unless more than one sentence is used) and explanations of the ", 
          StyleBox["Manipulate", "MRbig"], 
          " control labels. Define any symbols undefined so far. Include only \
text in this section \[LongDash] no code, graphics, etc. Do not change the \
cell style or copy cells from other sections. \n\nA book reference uses this \
format: \n    L. D. Schmidt, ", 
          StyleBox[
          "The Engineering of Chemical Reactions", FontSlant -> "Italic"], 
          ", New York: Oxford University Press, 1998. \n\nAn article \
reference uses this format: \n    D. Pearson, \"A Polynomial-Time Algorithm \
for the Change-Making Problem,\" ", 
          StyleBox["Operations Research Letters", FontSlant -> "Italic"], 
          ", ", 
          StyleBox["33", FontWeight -> "Bold"], 
          "(3), 2005 pp. 231\[Dash]234."}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b42cafa3-93cc-45b2-9bce-00512b05ae14"]
}], "DetailsSection",
 CellTags->"Details",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa"],

Cell["\<\
Snapshot 1: Data on charge separation for the compound C60[11]DMA in \
benzonitrile as solvent. Normal region.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8456115064967422`*^9, 3.845611564835387*^9}, {
   3.845643267621779*^9, 3.845643271142377*^9}, 3.8456475282428007`*^9, {
   3.846083698731824*^9, 3.846083702288703*^9}, {3.850230448158432*^9, 
   3.850230468303061*^9}, {3.8502305008079433`*^9, 3.850230528098675*^9}},
 CellID->1916642021,ExpressionUUID->"4977feda-b2b2-4de6-9be5-bf9fca4c9bf0"],

Cell["\<\
Snapshot 2: Data on charge separation of the compound C60[3]TMPD in toluene \
as solvent. Optimal region.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8456116065695763`*^9, 3.845611701014373*^9}, {
   3.845612098076188*^9, 3.8456120986279507`*^9}, {3.8456121491502647`*^9, 
   3.845612171276599*^9}, {3.845612233256858*^9, 3.8456122497917347`*^9}, {
   3.845612359938695*^9, 3.845612361211669*^9}, {3.845643300359337*^9, 
   3.845643321802299*^9}, {3.845647569975853*^9, 3.8456475699768353`*^9}, {
   3.845650961244471*^9, 3.845650968727614*^9}, 3.8460836881768064`*^9, {
   3.8460891068940334`*^9, 3.846089107294937*^9}, {3.8502303687229958`*^9, 
   3.850230388717121*^9}, {3.850230490335397*^9, 3.850230498384964*^9}},
 CellID->834068748,ExpressionUUID->"c4720b07-c281-4b3b-9ee4-60e476ec560b"],

Cell["\<\
Snapshot 3: Data on charge shift reaction of Closs and Miller in \
methyl-tetrahydrofuran as solvent. Inverted region, in the Classical model.\
\>", "DetailNotes",
 CellChangeTimes->{{3.850722267079545*^9, 3.850722276819139*^9}, {
  3.850722315820387*^9, 3.850722365095186*^9}},
 CellID->935097753,ExpressionUUID->"30a84708-abee-4662-a38a-aed3982c9145"],

Cell["\<\
Snapshot 4: Data on charge recombination of the compound C60[3]TMPD in \
toluene as solvent. Inverted region, in the Classical model. Zero-zero energy \
adjusted to fit charge recombination.\
\>", "DetailNotes",
 CellChangeTimes->{{3.8507222686842623`*^9, 3.8507222739149513`*^9}, {
  3.8507223314210577`*^9, 3.8507223380609283`*^9}, {3.851653909986163*^9, 
  3.851653961715294*^9}},
 CellID->902605925,ExpressionUUID->"a35b875d-f2ca-467e-b14d-79a297c23be4"],

Cell["References:", "DetailNotes",
 CellChangeTimes->{{3.8516001901531305`*^9, 3.8516001927504077`*^9}},
 CellID->131803627,ExpressionUUID->"1a11787d-e290-47dc-973b-d41665549fef"],

Cell[TextData[{
 "[1] R. A. Marcus, \"Electron Transfer Reactions in Chemistry: Theory and \
Experiment (Nobel Lecture),\" ",
 StyleBox["Angewandte Chemie International Edition",
  FontSlant->"Italic"],
 ", ",
 StyleBox["32",
  FontWeight->"Bold"],
 "(8), 1993 pp. 1111\[Dash]1121. ",
 ButtonBox["doi:10.1002/anie.199311113",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1002/anie.199311113"], None},
  ButtonNote->"https://doi.org/10.1002/anie.199311113"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
   3.845486485563533*^9, 3.8454865155028973`*^9}, {3.845487592619128*^9, 
   3.8454876364889593`*^9}, {3.845487667796479*^9, 3.8454876737310143`*^9}, {
   3.845487788050535*^9, 3.8454878088794947`*^9}, {3.845487859066869*^9, 
   3.8454878996227083`*^9}, 3.8454879903912582`*^9, {3.845488646583804*^9, 
   3.845488646849061*^9}, {3.845643465159183*^9, 3.8456434782941628`*^9}, {
   3.845643763608822*^9, 3.845643772552966*^9}, {3.8460839528897514`*^9, 
   3.8460839544787807`*^9}},
 CellID->1044342058,ExpressionUUID->"afc7318a-6966-4035-9369-bd9caf5c2c80"],

Cell[TextData[{
 "[2] S. Chaudhuri, S. Hedstr\[ODoubleDot]m, D. D. M\[EAcute]ndez-Hern\
\[AAcute]ndez, H. P. Hendrickson, K. A. Jung, J. Ho and V. S. Batista, \
\"Electron Transfer Assisted by Vibronic Coupling from Multiple Modes,\" ",
 StyleBox["Journal of Chemical Theory and Computation",
  FontSlant->"Italic"],
 ", ",
 StyleBox["13",
  FontWeight->"Bold"],
 "(12), 2017 pp. 6000\[Dash]6009. ",
 ButtonBox["doi:10.1021/acs.jctc.7b00513.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/acs.jctc.7b00513"], None},
  ButtonNote->"https://doi.org/10.1021/acs.jctc.7b00513"]
}], "DetailNotes",
 CellChangeTimes->{{3.845468526413287*^9, 3.845468528071273*^9}, {
  3.845486485563533*^9, 3.845486494542997*^9}, {3.845487520953878*^9, 
  3.845487520958171*^9}},
 CellID->2075423495,ExpressionUUID->"28ce494b-4125-48f3-945d-07b47fe326af"],

Cell[TextData[{
 "[3] P. F. Barbara, T. J. Meyer, M. A. Ratner, \"Contemporary Issues in \
Electron Transfer Research\", ",
 StyleBox["Journal of Physical Chemistry",
  FontSlant->"Italic"],
 ", ",
 StyleBox["100",
  FontWeight->"Bold"],
 "(31), 1996 pp. 13148\[Dash]13168. ",
 ButtonBox["doi:10.1021/jp9605663",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1021/jp9605663"], None},
  ButtonNote->"https://doi.org/10.1021/jp9605663"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845487945501761*^9, 3.845487945501944*^9}, {
  3.845488000437199*^9, 3.845488004909089*^9}, {3.8454884267223167`*^9, 
  3.8454884287459173`*^9}, {3.8454884770455217`*^9, 3.8454885081092777`*^9}, {
  3.8454885599836283`*^9, 3.8454885807988997`*^9}, {3.845488614203888*^9, 
  3.8454886412650547`*^9}, {3.845488675008108*^9, 3.845488703037126*^9}, {
  3.8456439141278267`*^9, 3.845643929079504*^9}},
 CellID->1362205661,ExpressionUUID->"ef437f8e-181d-4f46-a792-79c75513a845"],

Cell[TextData[{
 "[4] G. L. Closs and J. R. Miller, \"Intramolecular Long-Distance Electron \
Transfer in Organic Molecules,\" ",
 StyleBox["Science",
  FontSlant->"Italic"],
 ", ",
 StyleBox["240",
  FontWeight->"Bold"],
 "(4851), 1988 pp. 440\[Dash]447. ",
 ButtonBox["doi:10.1126/science.240.4851.440",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1126/science.240.4851.440"], None},
  ButtonNote->"https://doi.org/10.1126/science.240.4851.440"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.845488847135751*^9, 3.845488847936137*^9}, 
   3.84548892908597*^9, {3.8454889707375813`*^9, 3.845488986639029*^9}, {
   3.845489962649474*^9, 3.8454900049219027`*^9}, {3.845490036544503*^9, 
   3.8454900669925137`*^9}, {3.845490162753018*^9, 3.845490169252675*^9}, {
   3.8454901999758673`*^9, 3.845490199979129*^9}, {3.845529422901569*^9, 
   3.845529423364011*^9}, {3.845643995119815*^9, 3.845644017491386*^9}},
 CellID->267383760,ExpressionUUID->"fcdb7a77-9580-46d5-8cc1-957caef38812"],

Cell[TextData[{
 "[5] P. Hudhomme and R. M. Williams, \"Energy and Electron Transfer in \
Photo- and Electro-active Fullerene Dyads,\" ",
 StyleBox["Handbook of Carbon Nano Materials",
  FontSlant->"Italic"],
 " (F. D'Souza and K. M. Kadish, eds.), Hackensack, NJ: World Scientific, \
2011 pp. 545\[Dash]591. ",
 ButtonBox["doi:10.1142/9789814327824_0017",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1142/9789814327824_0017"], None},
  ButtonNote->"https://doi.org/10.1142/9789814327824_0017"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8454685041663237`*^9, 3.8454685192133703`*^9}, {
   3.8454879287150793`*^9, 3.845487937930896*^9}, 3.8454889355990353`*^9, {
   3.845488975277957*^9, 3.8454889821674137`*^9}, {3.845489063987767*^9, 
   3.845489146995013*^9}, {3.845489195356243*^9, 3.8454891953597*^9}, {
   3.845529189934093*^9, 3.845529213918605*^9}, {3.845529391166643*^9, 
   3.8455294155160303`*^9}, {3.845529450779456*^9, 3.8455294536519737`*^9}, {
   3.845529669926862*^9, 3.845529735627886*^9}, {3.8455298100216913`*^9, 
   3.845529810024806*^9}, {3.845644090038953*^9, 3.8456440975309877`*^9}, {
   3.845644135546042*^9, 3.845644164110743*^9}, {3.8456442064346952`*^9, 
   3.8456442778070173`*^9}, {3.8456443227864027`*^9, 3.845644326352326*^9}, {
   3.845645904073799*^9, 3.845645904314596*^9}},
 CellID->240524787,ExpressionUUID->"11651ffb-3c4e-46a8-8c74-463a53a0c230"],

Cell[TextData[{
 StyleBox["[6] ",
  FontSize->12],
 "R. M. Williams. \"Introduction to Electron Transfer,\" (Nov 11, 2021) ",
 ButtonBox["doi:10.13140/RG.2.2.16547.30244",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.13140/RG.2.2.16547.30244"], None},
  ButtonNote->"http://dx.doi.org/10.13140/RG.2.2.16547.30244"],
 StyleBox[".",
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685041663237`*^9, 3.8454685192133703`*^9}, {
   3.8454879287150793`*^9, 3.845487937930896*^9}, 3.8454889355990353`*^9, {
   3.845488975277957*^9, 3.8454889821674137`*^9}, {3.845489063987767*^9, 
   3.845489146995013*^9}, {3.845489195356243*^9, 3.8454891953597*^9}, {
   3.845529189934093*^9, 3.845529190429112*^9}, {3.845644345129858*^9, 
   3.845644401336515*^9}, {3.846086978538337*^9, 3.846086989377143*^9}, {
   3.846087101643921*^9, 3.8460871065877995`*^9}, {3.84608726893346*^9, 
   3.8460872696295996`*^9}, {3.846087339892658*^9, 3.8460873405009985`*^9}},
 CellID->207080162,ExpressionUUID->"021524ac-18f3-4221-b730-f67bfa4edc76"],

Cell[TextData[{
 StyleBox["[7] R. M. Williams. ",
  FontSize->12],
 StyleBox["Photoinduced Electron Transfer - The Classical Marcus Theory",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[" [Video]. (Nov 11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["youtu.be/YFzeMMOvhl0.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/YFzeMMOvhl0"], None},
  ButtonNote->"https://youtu.be/YFzeMMOvhl0"],
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525743612856*^9, 
   3.845525748675395*^9}, {3.845525805979796*^9, 3.845525811505554*^9}, {
   3.8455291931505547`*^9, 3.845529193581238*^9}, {3.845568465269396*^9, 
   3.845568471122637*^9}, 3.845568562033774*^9, {3.8455686095676327`*^9, 
   3.8455686095709*^9}, {3.8455757747280197`*^9, 3.8455758492973747`*^9}, 
   3.845575934939269*^9, {3.845644455407284*^9, 3.845644502295288*^9}, {
   3.845644545217039*^9, 3.845644568012081*^9}, 3.8460871822998037`*^9},
 CellID->197499548,ExpressionUUID->"549ac30b-576e-4300-91c8-ae3759afbb92"],

Cell[TextData[{
 "[8] R. M. Williams. ",
 StyleBox["Photoinduced Electron Transfer - The Semi-classical \
Marcus\[Dash]Levich\[Dash]Jortner Theory",
  FontSlant->"Italic"],
 " [Video]. (Nov 11, 2021) ",
 ButtonBox["youtu.be/GnPIbH6nM9o",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://youtu.be/GnPIbH6nM9o"], None},
  ButtonNote->"https://youtu.be/GnPIbH6nM9o"],
 "."
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525743612856*^9, 
   3.845525751479699*^9}, {3.845525863247136*^9, 3.8455258691488123`*^9}, {
   3.845529195627624*^9, 3.8455291961570797`*^9}, {3.8455682980810432`*^9, 
   3.845568307911862*^9}, 3.845568351711124*^9, {3.845568383495428*^9, 
   3.845568410984956*^9}, {3.84556844741706*^9, 3.845568447420724*^9}, 
   3.845575765263617*^9, {3.845575801398431*^9, 3.84557582464923*^9}, {
   3.8455758561374407`*^9, 3.845575870098317*^9}, {3.845644596969239*^9, 
   3.84564465818088*^9}, {3.846087195092207*^9, 3.8460872087805185`*^9}},
 CellID->1811878752,ExpressionUUID->"95470747-76ab-415c-9398-bc57821742a6"],

Cell[TextData[{
 StyleBox["[9] R. M. Williams. University of Amsterdam. (Nov 11, 2021) ",
  FontSize->12],
 StyleBox[ButtonBox["www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html"], 
    None},
  ButtonNote->
   "https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html"],
  FontSize->12],
 StyleBox[".",
  FontSize->12]
}], "DetailNotes",
 CellChangeTimes->{{3.8454685076775274`*^9, 3.84546852345658*^9}, 
   3.845487185205503*^9, {3.8454879199790897`*^9, 3.845487926289955*^9}, {
   3.8454889108887653`*^9, 3.845488939110854*^9}, {3.845525754345191*^9, 
   3.8455257548248997`*^9}, {3.845529199062029*^9, 3.845529199475919*^9}, {
   3.845568650686081*^9, 3.845568674871126*^9}, {3.8455687135594*^9, 
   3.845568713562624*^9}, {3.8455759013240013`*^9, 3.845575902270748*^9}, {
   3.8456447049949293`*^9, 3.8456447390402117`*^9}, {3.845644780968061*^9, 
   3.8456447889895372`*^9}},
 CellID->367075982,ExpressionUUID->"823513da-4d56-45a3-883c-24400a7c868d"],

Cell[TextData[{
 "[10] Test Data and assignments are available at:  ",
 ButtonBox["doi.org/10.21942/uva.17912015",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.21942/uva.17912015"], None},
  ButtonNote->"https://doi.org/10.21942/uva.17912015"]
}], "DetailNotes",
 CellChangeTimes->{
  3.85023056264368*^9, {3.8504517205605583`*^9, 3.850451749114053*^9}},
 CellID->480053374,ExpressionUUID->"d185ff42-fc99-409a-8b5c-9d8d2605fcb9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Control Suggestions",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Control Suggestions", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Check the boxes beside items that are appropriate control \
suggestions for this Demonstration. For more information, see the ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          " page.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "f1fe398c-f37e-4aca-9161-633bae63965a"]
}], "ControlSuggestionsSection",
 CellTags->
  "Control Suggestions",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-\
9fec786547ab"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Resize Images",ExpressionUUID->"fcee1195-e255-4dbd-8863-4af840debdbd"]}],
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\""]], "ControlSuggestions",
 CellChangeTimes->{{3.8516831818659134`*^9, 3.851683181990204*^9}},
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "df0b52c8-7325-4803-bb1e-958545cedfd1"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" on Mac) and drag up and down to zoom.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"61b2b2a8-69c4-4012-b6da-8923112012e2"]}],
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "8e06b60e-3149-4a23-ab31-0a8ab2f5ceaf"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"98a81657-e34e-4dab-ac86-\
717d7eff050a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[
   " Slider Zoom",ExpressionUUID->"c8d377e3-56fc-4adc-88e3-cf7642fb3181"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" to make ever finer adjustments.\""}]]], "ControlSuggestions",
 CellChangeTimes->{{3.8516001951250515`*^9, 3.851600195259692*^9}},
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "1fbb5ded-9a1c-4ba0-a087-0d1c0be219ce"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\""]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ec8a5240-77b9-42a0-8b9e-365efb47dfeb"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "5bdb2812-7da3-4bb1-a7fc-436054c40542"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Search Terms",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Search Terms", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide words and phrases that people might search for, with each \
one in a separate cell. Categories are added after the Demonstration is \
submitted, so the best things to enter here are terms (including any \
synonyms) that refer to specific parts of the Demonstration. Do not \
capitalize words unless they are proper names or proper adjectives.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b8b4550c-a7c1-4c5e-acf4-64f68ac8ea51"]
}], "SearchTermsSection",
 CellTags->
  "Search Terms",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b"],

Cell["charge separation", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634545063831*^9}},
 CellID->2129058965,ExpressionUUID->"bb295b74-9fbb-426e-8bfe-e83b08955214"],

Cell["charge recombination", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.8456345498627834`*^9}},
 CellID->309789228,ExpressionUUID->"8a73aa7b-abd0-452e-b1e3-c91aab6b34c2"],

Cell["photo-induced electron transfer", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.8456345553917937`*^9}},
 CellID->292502039,ExpressionUUID->"783831a5-ebc9-4d8b-8265-23f9ca3c5b89"],

Cell["Rudolph Marcus", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634560437248*^9}},
 CellID->116661474,ExpressionUUID->"5141b560-14e4-4826-ba8f-e5811ca568a7"],

Cell["electron transfer theory", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}, {3.845527905046464*^9, 
  3.8455279110836554`*^9}, {3.845634544548535*^9, 3.845634577528832*^9}, {
  3.850229916430519*^9, 3.850229923157675*^9}},
 CellID->262018152,ExpressionUUID->"8302ef2e-eec9-43a2-90be-76bbde8afb08"],

Cell["Gibbs free energy", "SearchTerms",
 CellChangeTimes->{{3.850229957536067*^9, 3.850229973359745*^9}, {
  3.8502300147406597`*^9, 3.8502300169131517`*^9}},
 CellID->191013139,ExpressionUUID->"1cf594bb-441f-4ba1-bc11-4121c2d7baa0"],

Cell["solvent reorganization energy", "SearchTerms",
 CellChangeTimes->{{3.850229980737179*^9, 3.850230009577086*^9}},
 CellID->921134898,ExpressionUUID->"075883d3-27f5-463c-b71b-f81925e6c03d"],

Cell["activation energy", "SearchTerms",
 CellChangeTimes->{{3.8502299822160788`*^9, 3.850230002808785*^9}},
 CellID->304619463,ExpressionUUID->"316b3838-f617-4a7c-afe9-898abdf96f81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Related Links",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Related Links", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide hyperlinks (not just bare URLs) to any relevant wolfram.com \
pages, with the page title as the linked text. Links to ", 
          ButtonBox[
          "NKS | Online", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://www.wolframscience.com/nks"], None}], 
          " should use the section title, not a page number. Links to \
non-Wolfram sites go in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d5b26c0d-c135-41cd-9d97-dc9003b05c57"]
}], "RelatedLinksSection",
 CellTags->
  "Related Links",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe"],

Cell[TextData[ButtonBox["Marcus Theory of Electron Transfer 1: Classical \
versus Semi-classical Models",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransfer1ClassicalVersusSemiClassicalM/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransfer1ClassicalVersusSemiClassicalM/"]], \
"RelatedLinks",
 CellChangeTimes->{{3.846441508275496*^9, 3.846441508279381*^9}},
 CellID->1413542048,ExpressionUUID->"b5ea7684-a9e8-4d5f-80ed-f7cdbf35722f"],

Cell[TextData[ButtonBox["Marcus Theory of Electron Transfer 2: Semiclassical \
Marcus Equation in Three Dimensions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransfer2SemiclassicalMarcusEquationIn/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransfer2SemiclassicalMarcusEquationIn/"]], \
"RelatedLinks",
 CellChangeTimes->{3.8502298392096024`*^9},
 CellID->719653999,ExpressionUUID->"18b4a113-e76f-43e4-9eda-cf7e95243dcf"],

Cell[TextData[ButtonBox["Marcus Theory of Electron-Transfer Reactions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryOfElectronTransferReactions/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/MarcusTheoryOfElectronTransferReactions/\
"]], "RelatedLinks",
 CellChangeTimes->{{3.8454684380554533`*^9, 3.8454684380554533`*^9}},
 CellID->2070922,ExpressionUUID->"31da11c2-e034-4dbe-8f8a-59fed4ed95f3"],

Cell[TextData[ButtonBox["Marcus Theory for Electron Transfer in Photosystem \
II",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
MarcusTheoryForElectronTransferInPhotosystemII/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
MarcusTheoryForElectronTransferInPhotosystemII/"]], "RelatedLinks",
 CellChangeTimes->{{3.845468460694504*^9, 3.845468460694504*^9}},
 CellID->261318040,ExpressionUUID->"47276cc6-f90d-4370-9908-c28175685e79"],

Cell[TextData[ButtonBox["Quantum Harmonic Oscillator Tunneling into \
Classically Forbidden Regions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
QuantumHarmonicOscillatorTunnelingIntoClassicallyForbiddenRe/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
QuantumHarmonicOscillatorTunnelingIntoClassicallyForbiddenRe/"]], \
"RelatedLinks",
 CellChangeTimes->{{3.8455692825477*^9, 3.845569282548484*^9}, 
   3.845569402798053*^9, {3.8455694420813303`*^9, 3.845569442085705*^9}},
 CellID->1621482253,ExpressionUUID->"1d6b168d-aff7-48ce-a866-08ed66513b5d"],

Cell[TextData[ButtonBox["Franck-Condon Principle in Vibronic Transitions",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://demonstrations.wolfram.com/\
FranckCondonPrincipleInVibronicTransitions/"], None},
 ButtonNote->
  "https://demonstrations.wolfram.com/\
FranckCondonPrincipleInVibronicTransitions/"]], "RelatedLinks",
 CellChangeTimes->{
  3.8455694768741217`*^9, {3.8455695138231163`*^9, 3.8455695138271093`*^9}},
 CellID->684745741,ExpressionUUID->"63f8b3c9-cd2a-497a-97c3-a927931d12e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Authoring Information",
 Cell[BoxData[
  TemplateBox[{"Authoring Information", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "'Contributed by: John Smith' for single authors; 'Contributed by: \
John Smith, Robert Ford, and Jane Doe' for multiple authors. To credit people \
other than Demonstrations authors, please see the detailed ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "990970f3-a922-4bea-919a-d6fa2da1f6d5"]
}], "AuthorSection",
 CellTags->
  "Authoring \
Information",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a"],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Ren\[EAcute] M. Williams",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://demonstrations.wolfram.com/author.html?author=Ren%C3%A9+M.+\
Williams"], None},
  ButtonNote->
   "https://demonstrations.wolfram.com/author.html?author=Ren%C3%A9+M.+\
Williams"]
}], "Author",
 CellChangeTimes->{{3.847889654013073*^9, 3.847889654013073*^9}},
 CellID->428421749,ExpressionUUID->"2a4a3dbc-7b65-4d9b-b08c-4e4786fb52cf"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"DemonstrationSource",
WindowSize->{1440, 855},
WindowMargins->{{-1721, Automatic}, {69, Automatic}},
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.10.2121", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3, "$ApplicationName" -> "Pubs", "$LinkBase" -> "Pubs", 
    "$ApplicationDirectory" -> "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\Documentation\\English\\", 
    "$UseNewPageDialog" -> "False", "$CondensedBlogMenus" -> "True"}, 
  "PresenterSettings" -> {
   "OutlineThumbnails" -> {"1" -> "Thumbnail"}, 
    "OutlinePalette" -> {"Thumbnails" -> {}, "ThumbnailMagnification" -> 0.8},
     "SideNotesPalette" -> {"PaletteNumber" -> 0}}, "BlogsDirectory" -> 
  "\\\\wrisync02.wri.wolfram.com\\backup$\\jayw\\My \
Documents\\jaywstasks\\BlogTools\\Blogs\\", "ChatNotebookID" -> 
  "fef9786d-4748-42a0-a328-5496e837f205", "Originator" -> 
  "chatframework@wolfram.com", "ScreenName" -> "", "ChatCreationDate" -> 
  "DateObject[{2018, 6, 18, 13, 5, 54.5673134}, Instant, Gregorian, -5.]", 
  "CustomWindowTitle" -> "None", "ChatNotebookDate" -> "18 Jun 2018 13:05:54",
   "ChatNotebookWindowTitle" -> "chatframework's Chat - (18 Jun 2018 13:05)", 
  "Participants" -> {"chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "AllParticipants" -> {
   "chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "Contacts" -> {
   "andre@wolfram.com", "bradym@wolfram.com", "brianv@wolfram.com", 
    "jayw@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "EmailListData" -> {0, 0, 0, 0, 1}, "ScrollLock" -> False, "Terminated" -> 
  True, "QuestionState" -> "Timeup", 
  "AttachedCells" -> {
   "Initialization Code" -> None, "Manipulate" -> None, "Caption" -> None, 
    "Snapshots" -> None, "Details" -> None, "Related Links" -> None, 
    "Search Terms" -> None, "Control Suggestions" -> None, "Thumbnail" -> 
    None, "Authoring Information" -> None}},
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (June 19, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"e654ef06-5887-41cc-a31c-3b83a4bfa37e"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initialization Code"->{
  Cell[979, 32, 1833, 39, 67, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
   CellTags->"Initialization Code"]},
 "Manipulate"->{
  Cell[2837, 75, 1524, 30, 67, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
   CellTags->"Manipulate"]},
 "Caption"->{
  Cell[55868, 1155, 1138, 24, 67, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
   CellTags->"Caption"]},
 "Thumbnail"->{
  Cell[64654, 1329, 1005, 22, 67, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
   CellTags->"Thumbnail"]},
 "Snapshots"->{
  Cell[79709, 1646, 1018, 22, 67, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
   CellTags->"Snapshots"]},
 "Details"->{
  Cell[136962, 2831, 1796, 36, 67, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
   CellTags->"Details"]},
 "Control Suggestions"->{
  Cell[151546, 3149, 1131, 28, 67, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
   CellTags->"Control Suggestions"]},
 "ResizeImages"->{
  Cell[152680, 3179, 474, 10, 22, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[153157, 3191, 783, 19, 22, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[153943, 3212, 435, 12, 22, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[154381, 3226, 739, 18, 22, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[155123, 3246, 1011, 24, 22, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[156137, 3272, 469, 11, 22, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[156609, 3285, 1564, 33, 22, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[158176, 3320, 1008, 23, 22, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
   CellTags->"BookmarkAnimation"]},
 "Search Terms"->{
  Cell[159221, 3348, 1073, 24, 67, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
   CellTags->"Search Terms"]},
 "Related Links"->{
  Cell[162675, 3421, 1191, 28, 67, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
   CellTags->"Related Links"]},
 "Authoring Information"->{
  Cell[167059, 3529, 1158, 28, 67, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
   CellTags->"Authoring Information"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initialization Code", 171067, 3620},
 {"Manipulate", 171232, 3623},
 {"Caption", 171382, 3626},
 {"Thumbnail", 171541, 3629},
 {"Snapshots", 171694, 3632},
 {"Details", 171845, 3635},
 {"Control Suggestions", 172005, 3638},
 {"ResizeImages", 172181, 3641},
 {"RotateAndZoomIn3D", 172347, 3644},
 {"DragLocators", 172513, 3647},
 {"CreateAndDeleteLocators", 172685, 3650},
 {"SliderZoom", 172855, 3653},
 {"GamepadControls", 173018, 3656},
 {"AutomaticAnimation", 173188, 3659},
 {"BookmarkAnimation", 173361, 3662},
 {"Search Terms", 173528, 3665},
 {"Related Links", 173691, 3668},
 {"Authoring Information", 173864, 3671}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 396, 8, 156, "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],
Cell[979, 32, 1833, 39, 67, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
 CellTags->"Initialization Code"],
Cell[CellGroupData[{
Cell[2837, 75, 1524, 30, 67, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
 CellTags->"Manipulate"],
Cell[CellGroupData[{
Cell[4386, 109, 37420, 750, 1234, "Input",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"],
Cell[41809, 861, 14010, 288, 36, "Output",ExpressionUUID->"ae693cb6-ba72-450e-b1ca-422daa82eaaa",
 CellID->527730449]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55868, 1155, 1138, 24, 67, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
 CellTags->"Caption"],
Cell[57009, 1181, 2328, 40, 114, "ManipulateCaption",ExpressionUUID->"71921e4e-c8c2-4f05-96e3-4e3047349e9a"],
Cell[59340, 1223, 1246, 19, 52, "ManipulateCaption",ExpressionUUID->"81ac6df1-7eef-434b-9bf0-af390dcf1f23",
 CellID->1123106709],
Cell[60589, 1244, 798, 13, 37, "ManipulateCaption",ExpressionUUID->"3e6b90b7-a201-4bda-9d78-01770128f898",
 CellID->701360872],
Cell[61390, 1259, 1359, 29, 39, "ManipulateCaption",ExpressionUUID->"e01ac0e0-26df-411d-b86a-d3a66a83e8b7",
 CellID->1512240980],
Cell[62752, 1290, 848, 14, 52, "ManipulateCaption",ExpressionUUID->"9628a6cc-021b-4224-a426-d4ed28d0f1d4",
 CellID->1422814127],
Cell[63603, 1306, 501, 8, 22, "ManipulateCaption",ExpressionUUID->"3f3c28f5-4bb6-4462-80f5-687f5dcfee71",
 CellID->467106557],
Cell[64107, 1316, 510, 8, 37, "ManipulateCaption",ExpressionUUID->"497148e1-3681-40c5-b1c8-58b7405ebc7c",
 CellID->1350886619]
}, Open  ]],
Cell[CellGroupData[{
Cell[64654, 1329, 1005, 22, 67, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
 CellTags->"Thumbnail"],
Cell[65662, 1353, 14010, 288, 36, "Output",ExpressionUUID->"ea6c80b7-7be3-4c89-8ca7-7de6dd32d2bf",
 CellID->349667646]
}, Open  ]],
Cell[CellGroupData[{
Cell[79709, 1646, 1018, 22, 67, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
 CellTags->"Snapshots"],
Cell[80730, 1670, 14002, 287, 36, "Output",ExpressionUUID->"d007968d-da8b-4dfe-abbf-2efbd7e29b99",
 CellID->189306603],
Cell[94735, 1959, 14009, 287, 36, "Output",ExpressionUUID->"5f141c5f-8e9b-46b8-bffc-af3b877c7c74",
 CellID->572002538],
Cell[108747, 2248, 14126, 289, 36, "Output",ExpressionUUID->"39f83618-199e-4e7b-8f76-a775b8c12772",
 CellID->724378501],
Cell[122876, 2539, 14049, 287, 36, "Output",ExpressionUUID->"1840434a-aa53-4a8d-a4ce-bbc9427cfe63",
 CellID->641216097]
}, Open  ]],
Cell[CellGroupData[{
Cell[136962, 2831, 1796, 36, 67, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
 CellTags->"Details"],
Cell[138761, 2869, 507, 8, 22, "DetailNotes",ExpressionUUID->"4977feda-b2b2-4de6-9be5-bf9fca4c9bf0",
 CellID->1916642021],
Cell[139271, 2879, 803, 12, 22, "DetailNotes",ExpressionUUID->"c4720b07-c281-4b3b-9ee4-60e476ec560b",
 CellID->834068748],
Cell[140077, 2893, 363, 6, 22, "DetailNotes",ExpressionUUID->"30a84708-abee-4662-a38a-aed3982c9145",
 CellID->935097753],
Cell[140443, 2901, 468, 8, 22, "DetailNotes",ExpressionUUID->"a35b875d-f2ca-467e-b14d-79a297c23be4",
 CellID->902605925],
Cell[140914, 2911, 179, 2, 22, "DetailNotes",ExpressionUUID->"1a11787d-e290-47dc-973b-d41665549fef",
 CellID->131803627],
Cell[141096, 2915, 1130, 24, 22, "DetailNotes",ExpressionUUID->"afc7318a-6966-4035-9369-bd9caf5c2c80",
 CellID->1044342058],
Cell[142229, 2941, 862, 19, 37, "DetailNotes",ExpressionUUID->"28ce494b-4125-48f3-945d-07b47fe326af",
 CellID->2075423495],
Cell[143094, 2962, 978, 22, 22, "DetailNotes",ExpressionUUID->"ef437f8e-181d-4f46-a792-79c75513a845",
 CellID->1362205661],
Cell[144075, 2986, 1010, 22, 22, "DetailNotes",ExpressionUUID->"fcdb7a77-9580-46d5-8cc1-957caef38812",
 CellID->267383760],
Cell[145088, 3010, 1414, 25, 37, "DetailNotes",ExpressionUUID->"11651ffb-3c4e-46a8-8c74-463a53a0c230",
 CellID->240524787],
Cell[146505, 3037, 1056, 20, 22, "DetailNotes",ExpressionUUID->"021524ac-18f3-4221-b730-f67bfa4edc76",
 CellID->207080162],
Cell[147564, 3059, 1187, 24, 22, "DetailNotes",ExpressionUUID->"549ac30b-576e-4300-91c8-ae3759afbb92",
 CellID->197499548],
Cell[148754, 3085, 1206, 23, 22, "DetailNotes",ExpressionUUID->"95470747-76ab-415c-9398-bc57821742a6",
 CellID->1811878752],
Cell[149963, 3110, 1089, 22, 22, "DetailNotes",ExpressionUUID->"823513da-4d56-45a3-883c-24400a7c868d",
 CellID->367075982],
Cell[151055, 3134, 454, 10, 22, "DetailNotes",ExpressionUUID->"d185ff42-fc99-409a-8b5c-9d8d2605fcb9",
 CellID->480053374]
}, Open  ]],
Cell[CellGroupData[{
Cell[151546, 3149, 1131, 28, 67, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
 CellTags->"Control Suggestions"],
Cell[152680, 3179, 474, 10, 22, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
 CellTags->"ResizeImages"],
Cell[153157, 3191, 783, 19, 22, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
 CellTags->"RotateAndZoomIn3D"],
Cell[153943, 3212, 435, 12, 22, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
 CellTags->"DragLocators"],
Cell[154381, 3226, 739, 18, 22, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
 CellTags->"CreateAndDeleteLocators"],
Cell[155123, 3246, 1011, 24, 22, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
 CellTags->"SliderZoom"],
Cell[156137, 3272, 469, 11, 22, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
 CellTags->"GamepadControls"],
Cell[156609, 3285, 1564, 33, 22, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
 CellTags->"AutomaticAnimation"],
Cell[158176, 3320, 1008, 23, 22, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159221, 3348, 1073, 24, 67, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
 CellTags->"Search Terms"],
Cell[160297, 3374, 328, 4, 22, "SearchTerms",ExpressionUUID->"bb295b74-9fbb-426e-8bfe-e83b08955214",
 CellID->2129058965],
Cell[160628, 3380, 332, 4, 22, "SearchTerms",ExpressionUUID->"8a73aa7b-abd0-452e-b1e3-c91aab6b34c2",
 CellID->309789228],
Cell[160963, 3386, 343, 4, 22, "SearchTerms",ExpressionUUID->"783831a5-ebc9-4d8b-8265-23f9ca3c5b89",
 CellID->292502039],
Cell[161309, 3392, 324, 4, 22, "SearchTerms",ExpressionUUID->"5141b560-14e4-4826-ba8f-e5811ca568a7",
 CellID->116661474],
Cell[161636, 3398, 383, 5, 22, "SearchTerms",ExpressionUUID->"8302ef2e-eec9-43a2-90be-76bbde8afb08",
 CellID->262018152],
Cell[162022, 3405, 234, 3, 22, "SearchTerms",ExpressionUUID->"1cf594bb-441f-4ba1-bc11-4121c2d7baa0",
 CellID->191013139],
Cell[162259, 3410, 193, 2, 22, "SearchTerms",ExpressionUUID->"075883d3-27f5-463c-b71b-f81925e6c03d",
 CellID->921134898],
Cell[162455, 3414, 183, 2, 22, "SearchTerms",ExpressionUUID->"316b3838-f617-4a7c-afe9-898abdf96f81",
 CellID->304619463]
}, Open  ]],
Cell[CellGroupData[{
Cell[162675, 3421, 1191, 28, 67, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
 CellTags->"Related Links"],
Cell[163869, 3451, 542, 11, 22, "RelatedLinks",ExpressionUUID->"b5ea7684-a9e8-4d5f-80ed-f7cdbf35722f",
 CellID->1413542048],
Cell[164414, 3464, 530, 11, 22, "RelatedLinks",ExpressionUUID->"18b4a113-e76f-43e4-9eda-cf7e95243dcf",
 CellID->719653999],
Cell[164947, 3477, 465, 9, 22, "RelatedLinks",ExpressionUUID->"31da11c2-e034-4dbe-8f8a-59fed4ed95f3",
 CellID->2070922],
Cell[165415, 3488, 488, 10, 22, "RelatedLinks",ExpressionUUID->"47276cc6-f90d-4370-9908-c28175685e79",
 CellID->261318040],
Cell[165906, 3500, 610, 12, 22, "RelatedLinks",ExpressionUUID->"1d6b168d-aff7-48ce-a866-08ed66513b5d",
 CellID->1621482253],
Cell[166519, 3514, 503, 10, 22, "RelatedLinks",ExpressionUUID->"63f8b3c9-cd2a-497a-97c3-a927931d12e0",
 CellID->684745741]
}, Open  ]],
Cell[CellGroupData[{
Cell[167059, 3529, 1158, 28, 67, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
 CellTags->"Authoring Information"],
Cell[168220, 3559, 468, 12, 22, "Author",ExpressionUUID->"2a4a3dbc-7b65-4d9b-b08c-4e4786fb52cf",
 CellID->428421749]
}, Open  ]]
}, Open  ]]
}
]
*)

